@@ -75,10 +75,6 @@ class ANALYSIS_EXPORT DualEdgeTriangulation: public Triangulation
     virtual double getYMin() const override { return yMin; }
     /** Returns the number of points*/
     virtual int getNumberOfPoints() const override;
-    /** Removes the line with number i from the triangulation*/
-    void removeLine( int i );
-    /** Removes the point with the number i from the triangulation*/
-    void removePoint( int i );
     /** Sets the behaviour of the triangulation in case of crossing forced lines*/
     virtual void setForcedCrossBehaviour( Triangulation::forcedCrossBehaviour b ) override;
     /** Sets the color of the normal edges*/
@@ -146,7 +142,7 @@ class ANALYSIS_EXPORT DualEdgeTriangulation: public Triangulation
     const static int nBaseOfRuns = 300000;
     /** Returns the number of an edge which points to the point with number 'point' or -1 if there is an error*/
     int baseEdgeOfPoint( int point );
-    /** Returns the number of a HalfEdge from a triangle in which 'point' is in. If the number -10 is returned, this means, that 'point' is outside the convex hull. If -5 is returned, then numerical problems with the leftOfTest occured (and the value of the possible edge is stored in the variable 'mUnstableEdge'. -20 means, that the inserted point is exactly on an edge (the number is stored in the variable 'mEdgeWithPoint'). -25 means, that the point is already in the triangulation (the number of the point is stored in the member 'mTwiceInsPoint'. If -100 is returned, this means that something else went wrong*/
+    /** Returns the number of a HalfEdge from a triangle in which 'point' is in. If the number -10 is returned, this means, that 'point' is outside the convex hull. If -5 is returned, then numerical problems with the leftOfTest occurred (and the value of the possible edge is stored in the variable 'mUnstableEdge'. -20 means, that the inserted point is exactly on an edge (the number is stored in the variable 'mEdgeWithPoint'). -25 means, that the point is already in the triangulation (the number of the point is stored in the member 'mTwiceInsPoint'. If -100 is returned, this means that something else went wrong*/
     int baseEdgeOfTriangle( Point3D* point );
     /** Checks, if 'edge' has to be swapped because of the empty circle criterion. If so, doSwap(...) is called.*/
     bool checkSwap( unsigned int edge, unsigned int recursiveDeep );
@@ -185,7 +181,7 @@ inline DualEdgeTriangulation::DualEdgeTriangulation()
     , xMin( 0 )
     , yMax( 0 )
     , yMin( 0 )
-    , mTriangleInterpolator( 0 )
+    , mTriangleInterpolator( nullptr )
     , mForcedCrossBehaviour( Triangulation::DELETE_FIRST )
     , mEdgeColor( 0, 255, 0 )
     , mForcedEdgeColor( 0, 0, 255 )
@@ -206,7 +202,7 @@ inline DualEdgeTriangulation::DualEdgeTriangulation( int nop, Triangulation* dec
     , xMin( 0 )
     , yMax( 0 )
     , yMin( 0 )
-    , mTriangleInterpolator( 0 )
+    , mTriangleInterpolator( nullptr )
     , mForcedCrossBehaviour( Triangulation::DELETE_FIRST )
     , mEdgeColor( 0, 255, 0 )
     , mForcedEdgeColor( 0, 0, 255 )
@@ -224,7 +220,7 @@ inline DualEdgeTriangulation::DualEdgeTriangulation( int nop, Triangulation* dec
 
 inline int DualEdgeTriangulation::getNumberOfPoints() const
 {
-  return (( int )( mPointVector.count() ) );
+  return mPointVector.count();
 }
 
 inline Point3D* DualEdgeTriangulation::getPoint( unsigned int i ) const
