@@ -53,7 +53,8 @@ class CORE_EXPORT QGis
     //! Used for symbology operations
     // Feature types
     // @deprecated use QgsWKBTypes::Type
-    /* Q_DECL_DEPRECATED */ enum WkbType
+    /* Q_DECL_DEPRECATED */
+    enum WkbType
     {
       WKBUnknown = 0,
       WKBPoint = 1,
@@ -73,32 +74,38 @@ class CORE_EXPORT QGis
 
     //! Map multi to single type
     // @deprecated use QgsWKBTypes::singleType
-    /* Q_DECL_DEPRECATED */ static WkbType singleType( WkbType type );
+    /* Q_DECL_DEPRECATED */
+    static WkbType singleType( WkbType type );
 
     //! Map single to multitype type
     // @deprecated use QgsWKBTypes::multiType
-    /* Q_DECL_DEPRECATED */ static WkbType multiType( WkbType type );
+    /* Q_DECL_DEPRECATED */
+    static WkbType multiType( WkbType type );
 
     //! Map 2d+ to 2d type
     // @deprecated use QgsWKBTypes::flatType
-    /* Q_DECL_DEPRECATED */ static WkbType flatType( WkbType type );
+    /* Q_DECL_DEPRECATED */
+    static WkbType flatType( WkbType type );
 
     //! Return if type is a single type
     // @deprecated use QgsWKBTypes::isSingleType
-    /* Q_DECL_DEPRECATED */ static bool isSingleType( WkbType type );
+    /* Q_DECL_DEPRECATED */
+    static bool isSingleType( WkbType type );
 
     //! Return if type is a multi type
     // @deprecated use QgsWKBTypes::isMultiType
-    /* Q_DECL_DEPRECATED */ static bool isMultiType( WkbType type );
+    /* Q_DECL_DEPRECATED */
+    static bool isMultiType( WkbType type );
 
     // get dimension of points
-    // @deprecated use QgsWKBTypes::hasZ() and QgsWKBTypes::hasM()
-    /* Q_DECL_DEPRECATED */ static int wkbDimensions( WkbType type );
+    // @deprecated use QgsWKBTypes::coordDimensions()
+    /* Q_DECL_DEPRECATED */
+    static int wkbDimensions( WkbType type );
 
-    //! Converts from old (pre 2.10) WKB type to new WKB type
+    //! Converts from old (pre 2.10) WKB type (OGR) to new WKB type
     static QgsWKBTypes::Type fromOldWkbType( QGis::WkbType type );
 
-    //! Converts from new (post 2.10) WKB type to old WKB type
+    //! Converts from new (post 2.10) WKB type (OGC) to old WKB type
     static QGis::WkbType fromNewWkbType( QgsWKBTypes::Type type );
 
     enum GeometryType
@@ -144,6 +151,7 @@ class CORE_EXPORT QGis
      * @note that QGIS < 1.4 api had only Meters, Feet, Degrees and UnknownUnit
      * @note and QGIS >1.8 returns to that
      */
+    //TODO QGIS 3.0 - clean up and move to QgsUnitTypes and rename to DistanceUnit
     enum UnitType
     {
       Meters = 0,
@@ -159,15 +167,24 @@ class CORE_EXPORT QGis
     };
 
     //! Provides the canonical name of the type value
-    static QString toLiteral( QGis::UnitType unit );
+    //! @deprecated use QgsUnitTypes::encodeUnit() instead
+    Q_DECL_DEPRECATED static QString toLiteral( QGis::UnitType unit );
+
     //! Converts from the canonical name to the type value
-    static UnitType fromLiteral( const QString& literal, QGis::UnitType defaultType = UnknownUnit );
+    //! @deprecated use QgsUnitTypes::decodeDistanceUnit() instead
+    Q_DECL_DEPRECATED static UnitType fromLiteral( const QString& literal, QGis::UnitType defaultType = UnknownUnit );
+
     //! Provides translated version of the type value
-    static QString tr( QGis::UnitType unit );
+    //! @deprecated use QgsUnitTypes::toString() instead
+    Q_DECL_DEPRECATED static QString tr( QGis::UnitType unit );
+
     //! Provides type value from translated version
-    static UnitType fromTr( const QString& literal, QGis::UnitType defaultType = UnknownUnit );
+    //! @deprecated use QgsUnitTypes::stringToDistanceUnit() instead
+    Q_DECL_DEPRECATED static UnitType fromTr( const QString& literal, QGis::UnitType defaultType = UnknownUnit );
+
     //! Returns the conversion factor between the specified units
-    static double fromUnitToUnitFactor( QGis::UnitType fromUnit, QGis::UnitType toUnit );
+    //! @deprecated use QgsUnitTyoes::fromUnitToUnitFactor() instead
+    Q_DECL_DEPRECATED static double fromUnitToUnitFactor( QGis::UnitType fromUnit, QGis::UnitType toUnit );
 
     /** Converts a string to a double in a permissive way, eg allowing for incorrect
      * numbers of digits between thousand separators
@@ -203,7 +220,7 @@ class CORE_EXPORT QGis
 
     /** Old search radius in % of canvas width
      *  @deprecated since 2.3, use DEFAULT_SEARCH_RADIUS_MM */
-    static const double DEFAULT_IDENTIFY_RADIUS;
+    Q_DECL_DEPRECATED static const double DEFAULT_IDENTIFY_RADIUS;
 
     /** Identify search radius in mm
      *  @note added in 2.3 */
@@ -254,7 +271,7 @@ inline void ( *cast_to_fptr( void *p ) )()
 //
 // return a string representation of a double
 //
-inline QString qgsDoubleToString( const double &a, const int &precision = 17 )
+inline QString qgsDoubleToString( double a, int precision = 17 )
 {
   if ( precision )
     return QString::number( a, 'f', precision ).remove( QRegExp( "\\.?0+$" ) );
@@ -297,9 +314,17 @@ inline double qgsRound( double x )
   return x < 0.0 ? std::ceil( x - 0.5 ) : std::floor( x + 0.5 );
 }
 
-bool qgsVariantLessThan( const QVariant& lhs, const QVariant& rhs );
+//! Compares two QVariant values and returns whether the first is less than the second.
+//! Useful for sorting lists of variants, correctly handling sorting of the various
+//! QVariant data types (such as strings, numeric values, dates and times)
+//! @see qgsVariantGreaterThan()
+CORE_EXPORT bool qgsVariantLessThan( const QVariant& lhs, const QVariant& rhs );
 
-bool qgsVariantGreaterThan( const QVariant& lhs, const QVariant& rhs );
+//! Compares two QVariant values and returns whether the first is greater than the second.
+//! Useful for sorting lists of variants, correctly handling sorting of the various
+//! QVariant data types (such as strings, numeric values, dates and times)
+//! @see qgsVariantLessThan()
+CORE_EXPORT bool qgsVariantGreaterThan( const QVariant& lhs, const QVariant& rhs );
 
 CORE_EXPORT QString qgsVsiPrefix( const QString& path );
 
@@ -407,3 +432,9 @@ typedef unsigned long long qgssize;
 #endif
 #endif
 #endif
+
+#if defined(__clang__)
+#define FALLTHROUGH [[clang::fallthrough]]
+#else
+#define FALLTHROUGH
+#endif
