@@ -20,12 +20,15 @@
 
 #include "qgseditorconfigwidget.h"
 
+/** \class QgsCheckBoxConfigDlg
+ * \note not available in Python bindings
+ */
 class GUI_EXPORT QgsCheckBoxConfigDlg : public QgsEditorConfigWidget, private Ui::QgsCheckBoxConfigDlgBase
 {
     Q_OBJECT
 
   public:
-    explicit QgsCheckBoxConfigDlg( QgsVectorLayer* vl, int fieldIdx, QWidget *parent = 0 );
+    explicit QgsCheckBoxConfigDlg( QgsVectorLayer* vl, int fieldIdx, QWidget *parent = nullptr );
 
     // QgsEditorConfigWidget interface
   public:
