@@ -34,7 +34,7 @@ class GUI_EXPORT QgsGroupBoxCollapseButton : public QToolButton
     Q_OBJECT
 
   public:
-    QgsGroupBoxCollapseButton( QWidget *parent = 0 )
+    QgsGroupBoxCollapseButton( QWidget *parent = nullptr )
         : QToolButton( parent ), mAltDown( false ), mShiftDown( false ) {}
 
     ~QgsGroupBoxCollapseButton() {}
@@ -91,8 +91,8 @@ class GUI_EXPORT QgsCollapsibleGroupBoxBasic : public QGroupBox
     Q_PROPERTY( bool scrollOnExpand READ scrollOnExpand WRITE setScrollOnExpand )
 
   public:
-    QgsCollapsibleGroupBoxBasic( QWidget *parent = 0 );
-    QgsCollapsibleGroupBoxBasic( const QString &title, QWidget *parent = 0 );
+    QgsCollapsibleGroupBoxBasic( QWidget *parent = nullptr );
+    QgsCollapsibleGroupBoxBasic( const QString &title, QWidget *parent = nullptr );
     ~QgsCollapsibleGroupBoxBasic();
 
     /**
@@ -189,8 +189,8 @@ class GUI_EXPORT QgsCollapsibleGroupBox : public QgsCollapsibleGroupBoxBasic
     Q_PROPERTY( bool saveCheckedState READ saveCheckedState WRITE setSaveCheckedState )
 
   public:
-    QgsCollapsibleGroupBox( QWidget *parent = 0, QSettings* settings = 0 );
-    QgsCollapsibleGroupBox( const QString &title, QWidget *parent = 0, QSettings* settings = 0 );
+    QgsCollapsibleGroupBox( QWidget *parent = nullptr, QSettings* settings = nullptr );
+    QgsCollapsibleGroupBox( const QString &title, QWidget *parent = nullptr, QSettings* settings = nullptr );
     ~QgsCollapsibleGroupBox();
 
     // set custom QSettings pointer if group box was already created from QtDesigner promotion
