@@ -16,6 +16,7 @@
 #ifndef QGSCOLORWIDGETS_H
 #define QGSCOLORWIDGETS_H
 
+#include <QWidgetAction>
 #include <QWidget>
 
 class QColor;
@@ -56,7 +57,7 @@ class GUI_EXPORT QgsColorWidget : public QWidget
      * @param parent parent QWidget for the widget
      * @param component color component the widget alters
      */
-    QgsColorWidget( QWidget* parent = 0, const ColorComponent component = Multiple );
+    QgsColorWidget( QWidget* parent = nullptr, const ColorComponent component = Multiple );
 
     virtual ~QgsColorWidget();
 
@@ -117,6 +118,11 @@ class GUI_EXPORT QgsColorWidget : public QWidget
      */
     void colorChanged( const QColor &color );
 
+    /** Emitted when mouse hovers over widget.
+     * @note added in QGIS 2.14
+     */
+    void hovered();
+
   protected:
 
     QColor mCurrentColor;
@@ -125,7 +131,7 @@ class GUI_EXPORT QgsColorWidget : public QWidget
 
     /** QColor wipes the hue information when it is ambiguous (eg, for saturation = 0). So
      * the hue is stored in mExplicit hue to keep it around, as it is useful when modifying colors
-    */
+     */
     int mExplicitHue;
 
     /** Returns the range of valid values for the color widget's component
@@ -170,9 +176,83 @@ class GUI_EXPORT QgsColorWidget : public QWidget
 
     //Reimplemented to accept dropped colors
     void dropEvent( QDropEvent *e ) override;
+
+    void mouseMoveEvent( QMouseEvent* e ) override;
+    void mousePressEvent( QMouseEvent* e ) override;
+    void mouseReleaseEvent( QMouseEvent* e ) override;
 };
 
 
+/** \ingroup gui
+ * \class QgsColorWidgetAction
+ * An action containing a color widget, which can be embedded into a menu.
+ * @see QgsColorWidget
+ * @note introduced in QGIS 2.14
+ */
+
+class GUI_EXPORT QgsColorWidgetAction: public QWidgetAction
+{
+    Q_OBJECT
+
+  public:
+
+    /** Construct a new color widget action.
+     * @param colorWidget QgsColorWidget to show in action
+     * @param menu parent menu
+     * @param parent parent widget
+     */
+    QgsColorWidgetAction( QgsColorWidget* colorWidget, QMenu* menu = nullptr, QWidget *parent = nullptr );
+
+    virtual ~QgsColorWidgetAction();
+
+    /** Returns the color widget contained in the widget action.
+     */
+    QgsColorWidget* colorWidget() { return mColorWidget; }
+
+    /** Sets whether the parent menu should be dismissed and closed when a color is selected
+     * from the action's color widget.
+     * @param dismiss set to true (default) to immediately close the menu when a color is selected
+     * from the widget. If set to false, the colorChanged signal will be emitted but the menu will
+     * stay open.
+     * @see dismissOnColorSelection()
+     */
+    void setDismissOnColorSelection( bool dismiss ) { mDismissOnColorSelection = dismiss; }
+
+    /** Returns whether the parent menu will be dismissed after a color is selected from the
+     * action's color widget.
+     * @see setDismissOnColorSelection
+     */
+    bool dismissOnColorSelection() const { return mDismissOnColorSelection; }
+
+  signals:
+
+    /** Emitted when a color has been selected from the widget
+     * @param color selected color
+     */
+    void colorChanged( const QColor &color );
+
+  private:
+    QMenu* mMenu;
+    QgsColorWidget* mColorWidget;
+
+    //used to suppress recursion with hover events
+    bool mSuppressRecurse;
+
+    bool mDismissOnColorSelection;
+
+  private slots:
+
+    /** Handles setting the active action for the menu when cursor hovers over color widget
+     */
+    void onHover();
+
+    /** Emits color changed signal and closes parent menu
+     */
+    void setColor( const QColor &color );
+};
+
+
+
 /** \ingroup gui
  * \class QgsColorWheel
  * A color wheel widget. This widget consists of an outer ring which allows for hue selection, and an
@@ -189,10 +269,11 @@ class GUI_EXPORT QgsColorWheel : public QgsColorWidget
     /** Constructs a new color wheel widget.
      * @param parent parent QWidget for the widget
      */
-    QgsColorWheel( QWidget* parent = 0 );
+    QgsColorWheel( QWidget* parent = nullptr );
 
     virtual ~QgsColorWheel();
 
+    virtual QSize sizeHint() const override;
     void paintEvent( QPaintEvent* event ) override;
 
   public slots:
@@ -244,7 +325,7 @@ class GUI_EXPORT QgsColorWheel : public QgsColorWidget
 
     /** Creates cache images for specified widget size
      * @param size widget size for images
-    */
+     */
     void createImages( const QSizeF size );
 
     /** Creates the hue wheel image*/
@@ -255,7 +336,7 @@ class GUI_EXPORT QgsColorWheel : public QgsColorWidget
 
     /** Sets the widget color based on a point in the widget
      * @param pos position for color
-    */
+     */
     void setColorFromPos( const QPointF pos );
 
 };
@@ -281,7 +362,7 @@ class GUI_EXPORT QgsColorBox : public QgsColorWidget
      * which vary along the horizontal and vertical axis are automatically assigned
      * based on this constant color component.
      */
-    QgsColorBox( QWidget* parent = 0, const ColorComponent component = Value );
+    QgsColorBox( QWidget* parent = nullptr, const ColorComponent component = Value );
 
     virtual ~QgsColorBox();
 
@@ -311,39 +392,39 @@ class GUI_EXPORT QgsColorBox : public QgsColorWidget
     bool mDirty;
 
     /** Creates the color box background cached image
-    */
+     */
     void createBox();
 
     /** Returns the range of permissible values along the x axis
      * @returns maximum color component value for x axis
-    */
+     */
     int valueRangeX() const;
 
     /** Returns the range of permissible values along the y axis
      * @returns maximum color component value for y axis
-    */
+     */
     int valueRangeY() const;
 
     /** Returns the color component which varies along the y axis
-    */
+     */
     QgsColorWidget::ColorComponent yComponent() const;
 
     /** Returns the value of the color component which varies along the y axis
-    */
+     */
     int yComponentValue() const;
 
     /** Returns the color component which varies along the x axis
-    */
+     */
     QgsColorWidget::ColorComponent xComponent() const;
 
     /** Returns the value of the color component which varies along the x axis
-    */
+     */
     int xComponentValue() const;
 
     /** Updates the widget's color based on a point within the widget
      * @param point point within the widget
-    */
-    void setColorFromPoint( const QPoint& point );
+     */
+    void setColorFromPoint( QPoint point );
 
 };
 
@@ -374,7 +455,7 @@ class GUI_EXPORT QgsColorRampWidget : public QgsColorWidget
      * @param component color component which varies along the ramp
      * @param orientation orientation for widget
      */
-    QgsColorRampWidget( QWidget* parent = 0,
+    QgsColorRampWidget( QWidget* parent = nullptr,
                         const ColorComponent component = QgsColorWidget::Red,
                         const Orientation orientation = QgsColorRampWidget::Horizontal );
 
@@ -456,8 +537,8 @@ class GUI_EXPORT QgsColorRampWidget : public QgsColorWidget
 
     /** Updates the widget's color based on a point within the widget
      * @param point point within the widget
-    */
-    void setColorFromPoint( const QPointF &point );
+     */
+    void setColorFromPoint( QPointF point );
 
 };
 
@@ -478,7 +559,7 @@ class GUI_EXPORT QgsColorSliderWidget : public QgsColorWidget
      * @param parent parent QWidget for the widget
      * @param component color component which is controlled by the slider
      */
-    QgsColorSliderWidget( QWidget* parent = 0, const ColorComponent component = QgsColorWidget::Red );
+    QgsColorSliderWidget( QWidget* parent = nullptr, const ColorComponent component = QgsColorWidget::Red );
 
     virtual ~QgsColorSliderWidget();
 
@@ -499,28 +580,28 @@ class GUI_EXPORT QgsColorSliderWidget : public QgsColorWidget
      * @param realValue actual value of the color component
      * @returns display value of color component
      * @see convertDisplayToReal
-    */
+     */
     int convertRealToDisplay( const int realValue ) const;
 
     /** Converts the display value of a color component to a real value.
      * @param displayValue friendly display value of the color component
      * @returns real value of color component
      * @see convertRealToDisplay
-    */
+     */
     int convertDisplayToReal( const int displayValue ) const;
 
   private slots:
 
     /** Called when the color for the ramp changes
-    */
+     */
     void rampColorChanged( const QColor &color );
 
     /** Called when the value of the spin box changes
-    */
+     */
     void spinChanged( int value );
 
     /** Called when the value for the ramp changes
-    */
+     */
     void rampChanged( int value );
 
 };
@@ -542,7 +623,7 @@ class GUI_EXPORT QgsColorTextWidget : public QgsColorWidget
     /** Construct a new color line edit widget.
      * @param parent parent QWidget for the widget
      */
-    QgsColorTextWidget( QWidget* parent = 0 );
+    QgsColorTextWidget( QWidget* parent = nullptr );
 
     virtual ~QgsColorTextWidget();
 
@@ -572,17 +653,17 @@ class GUI_EXPORT QgsColorTextWidget : public QgsColorWidget
     ColorTextFormat mFormat;
 
     /** Updates the text based on the current color
-    */
+     */
     void updateText();
 
   private slots:
 
     /** Called when the user enters text into the widget
-    */
+     */
     void textChanged();
 
     /** Called when the dropdown arrow is clicked to show the format selection menu
-    */
+     */
     void showMenu();
 };
 
@@ -602,11 +683,12 @@ class GUI_EXPORT QgsColorPreviewWidget : public QgsColorWidget
     /** Construct a new color preview widget.
      * @param parent parent QWidget for the widget
      */
-    QgsColorPreviewWidget( QWidget* parent = 0 );
+    QgsColorPreviewWidget( QWidget* parent = nullptr );
 
     virtual ~QgsColorPreviewWidget();
 
     void paintEvent( QPaintEvent* event ) override;
+    virtual QSize sizeHint() const override;
 
     /** Returns the secondary color for the widget
      * @returns secondary widget color, or an invalid color if the widget
@@ -649,7 +731,7 @@ class GUI_EXPORT QgsColorPreviewWidget : public QgsColorWidget
      * @param rect rect to draw color in
      * @param painter destination painter
      */
-    void drawColor( const QColor& color, const QRect& rect, QPainter &painter );
+    void drawColor( const QColor& color, QRect rect, QPainter &painter );
 };
 
 #endif // #ifndef QGSCOLORWIDGETS_H
