@@ -28,6 +28,7 @@ class QgsComposition;
 class QgsComposerItem;
 class QgsAtlasComposition;
 class QgsMapSettings;
+class QgsSymbolV2;
 
 /** \ingroup core
  * \class QgsScopedExpressionFunction
@@ -240,7 +241,7 @@ class CORE_EXPORT QgsExpressionContext
 {
   public:
 
-    QgsExpressionContext( ) {}
+    QgsExpressionContext() {}
 
     /** Copy constructor
      */
@@ -296,6 +297,7 @@ class CORE_EXPORT QgsExpressionContext
      * scope which contains a matching variable.
      * @param name variable name
      * @returns matching scope containing variable, or null if none found
+     * @note not available in python bindings
      */
     const QgsExpressionContextScope* activeScopeForVariable( const QString& name ) const;
 
@@ -378,6 +380,11 @@ class CORE_EXPORT QgsExpressionContext
      */
     void appendScope( QgsExpressionContextScope* scope );
 
+    /**
+     * Removes the last scope from the expression context and return it.
+     */
+    QgsExpressionContextScope* popScope();
+
     /** Appends a scope to the end of the context. This scope will override
      * any matching variables or functions provided by existing scopes within the
      * context. Ownership of the scope is transferred to the stack.
@@ -417,9 +424,20 @@ class CORE_EXPORT QgsExpressionContext
      */
     void setOriginalValueVariable( const QVariant& value );
 
+    //! Inbuilt variable name for fields storage
     static const QString EXPR_FIELDS;
+    //! Inbuilt variable name for feature storage
     static const QString EXPR_FEATURE;
+    //! Inbuilt variable name for value original value variable
     static const QString EXPR_ORIGINAL_VALUE;
+    //! Inbuilt variable name for symbol color variable
+    static const QString EXPR_SYMBOL_COLOR;
+    //! Inbuilt variable name for symbol angle variable
+    static const QString EXPR_SYMBOL_ANGLE;
+    //! Inbuilt variable name for geometry part count variable
+    static const QString EXPR_GEOMETRY_PART_COUNT;
+    //! Inbuilt variable name for geometry part number variable
+    static const QString EXPR_GEOMETRY_PART_NUM;
 
   private:
 
@@ -514,6 +532,14 @@ class CORE_EXPORT QgsExpressionContextUtils
      */
     static QgsExpressionContextScope* mapSettingsScope( const QgsMapSettings &mapSettings );
 
+    /**
+     * Updates a symbol scope related to a QgsSymbolV2 to an expression context.
+     * @param symbol symbol to extract properties from
+     * @param symbolScope pointer to an existing scope to update
+     * @note added in QGIS 2.14
+     */
+    static QgsExpressionContextScope* updateSymbolScope( const QgsSymbolV2* symbol, QgsExpressionContextScope* symbolScope = nullptr );
+
     /** Creates a new scope which contains variables and functions relating to a QgsComposition.
      * For instance, number of pages and page sizes.
      * @param composition source composition
