@@ -25,6 +25,7 @@ class QgsAttributeTableFilterModel;
 class QgsFeatureListModel;
 class QgsFeatureSelectionModel;
 class QgsAttributeTableModel;
+class QgsIFeatureSelectionManager;
 class QgsVectorLayer;
 class QgsVectorLayerCache;
 class QgsFeatureListViewDelegate;
@@ -48,7 +49,7 @@ class GUI_EXPORT QgsFeatureListView : public QListView
      *
      * @param parent   owner
      */
-    explicit QgsFeatureListView( QWidget* parent = 0 );
+    explicit QgsFeatureListView( QWidget* parent = nullptr );
 
     /**
      * Destructor
@@ -114,6 +115,11 @@ class GUI_EXPORT QgsFeatureListView : public QListView
      */
     void setCurrentFeatureEdited( bool state );
 
+    /**
+     * @brief setFeatureSelectionManager
+     * @param featureSelectionManager We will take ownership
+     */
+    void setFeatureSelectionManager( QgsIFeatureSelectionManager* featureSelectionManager );
   protected:
     virtual void mouseMoveEvent( QMouseEvent *event ) override;
     virtual void mousePressEvent( QMouseEvent *event ) override;
@@ -133,8 +139,9 @@ class GUI_EXPORT QgsFeatureListView : public QListView
      * Is emitted, whenever the display expression is successfully changed
      * @param expression The expression that was applied
      */
-    void displayExpressionChanged( const QString expression );
+    void displayExpressionChanged( const QString& expression );
 
+    //! @note not available in Python bindings
     void aboutToChangeEditSelection( bool& ok );
 
   public slots:
@@ -162,7 +169,7 @@ class GUI_EXPORT QgsFeatureListView : public QListView
     void repaintRequested();
 
   private slots:
-    void editSelectionChanged( QItemSelection deselected, QItemSelection selected );
+    void editSelectionChanged( const QItemSelection& deselected, const QItemSelection& selected );
 
   private:
     void selectRow( const QModelIndex &index, bool anchor );
@@ -170,6 +177,7 @@ class GUI_EXPORT QgsFeatureListView : public QListView
     QgsFeatureListModel *mModel;
     QItemSelectionModel* mCurrentEditSelectionModel;
     QgsFeatureSelectionModel* mFeatureSelectionModel;
+    QgsIFeatureSelectionManager* mFeatureSelectionManager;
     QgsFeatureListViewDelegate* mItemDelegate;
     bool mEditSelectionDrag; // Is set to true when the user initiated a left button click over an edit button and still keeps pressing /**< TODO */
     int mRowAnchor;
