@@ -25,10 +25,21 @@ class GUI_EXPORT QgsFeatureSelectionDlg : public QDialog, private Ui::QgsFeature
     Q_OBJECT
 
   public:
-    explicit QgsFeatureSelectionDlg( QgsVectorLayer* vl, QWidget *parent = 0 );
+    explicit QgsFeatureSelectionDlg( QgsVectorLayer* vl, QgsAttributeEditorContext &context, QWidget *parent = nullptr );
 
+    /**
+     * Get the selected features
+     *
+     * @return The selected feature ids
+     */
     const QgsFeatureIds& selectedFeatures();
 
+    /**
+     * Set the selected features
+     * @param ids The feature ids to select
+     */
+    void setSelectedFeatures( const QgsFeatureIds& ids );
+
   private:
     QgsGenericFeatureSelectionManager* mFeatureSelection;
     QgsVectorLayer* mVectorLayer;
