@@ -58,7 +58,7 @@ class CORE_EXPORT QgsSimpleFillSymbolLayerV2 : public QgsFillSymbolLayerV2
 
     QgsStringMap properties() const override;
 
-    QgsSymbolLayerV2* clone() const override;
+    QgsSimpleFillSymbolLayerV2* clone() const override;
 
     void toSld( QDomDocument &doc, QDomElement &element, const QgsStringMap& props ) const override;
 
@@ -202,7 +202,7 @@ class CORE_EXPORT QgsGradientFillSymbolLayerV2 : public QgsFillSymbolLayerV2
 
     QgsStringMap properties() const override;
 
-    QgsSymbolLayerV2* clone() const override;
+    QgsGradientFillSymbolLayerV2* clone() const override;
 
     double estimateMaxBleed() const override;
 
@@ -290,12 +290,12 @@ class CORE_EXPORT QgsGradientFillSymbolLayerV2 : public QgsFillSymbolLayerV2
 
     /** Applies the gradient to a brush*/
     void applyGradient( const QgsSymbolV2RenderContext& context, QBrush& brush, const QColor& color, const QColor& color2,
-                        const GradientColorType &gradientColorType, QgsVectorColorRampV2 *gradientRamp, const GradientType &gradientType,
-                        const GradientCoordinateMode &coordinateMode, const GradientSpread &gradientSpread,
-                        const QPointF &referencePoint1, const QPointF &referencePoint2, const double angle );
+                        GradientColorType gradientColorType, QgsVectorColorRampV2 *gradientRamp, GradientType gradientType,
+                        GradientCoordinateMode coordinateMode, GradientSpread gradientSpread,
+                        QPointF referencePoint1, QPointF referencePoint2, const double angle );
 
     /** Rotates a reference point by a specified angle around the point (0.5, 0.5)*/
-    QPointF rotateReferencePoint( const QPointF & refPoint, double angle );
+    QPointF rotateReferencePoint( QPointF refPoint, double angle );
 };
 
 class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
@@ -330,7 +330,7 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
 
     QgsStringMap properties() const override;
 
-    QgsSymbolLayerV2* clone() const override;
+    QgsShapeburstFillSymbolLayerV2* clone() const override;
 
     double estimateMaxBleed() const override;
 
@@ -338,13 +338,13 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
      * @param blurRadius Radius for fill blur. Values between 0 - 17 are valid, where higher values results in a stronger blur. Set to 0 to disable blur.
      * @note added in 2.3
      * @see blurRadius
-    */
+     */
     void setBlurRadius( int blurRadius ) { mBlurRadius = blurRadius; }
     /** Returns the blur radius, which controls the amount of blurring applied to the fill.
      * @returns Integer representing the radius for fill blur. Higher values indicate a stronger blur. A 0 value indicates that blurring is disabled.
      * @note added in 2.3
      * @see setBlurRadius
-    */
+     */
     int blurRadius() const { return mBlurRadius; }
 
     /** Sets whether the shapeburst fill should be drawn using the entire shape.
@@ -353,14 +353,14 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
      * @note added in 2.3
      * @see useWholeShape
      * @see setMaxDistance
-    */
+     */
     void setUseWholeShape( bool useWholeShape ) { mUseWholeShape = useWholeShape; }
     /** Returns whether the shapeburst fill is set to cover the entire shape.
      * @returns True if shapeburst fill will cover the entire shape. If false, shapeburst is drawn to a distance of maxDistance from the polygon's boundary.
      * @note added in 2.3
      * @see setUseWholeShape
      * @see maxDistance
-    */
+     */
     bool useWholeShape() const { return mUseWholeShape; }
 
     /** Sets the maximum distance to shape inside of the shape from the polygon's boundary.
@@ -369,7 +369,7 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
      * @see maxDistance
      * @see setUseWholeShape
      * @see setDistanceUnit
-    */
+     */
     void setMaxDistance( double maxDistance ) { mMaxDistance = maxDistance; }
     /** Returns the maximum distance from the shape's boundary which is shaded. This parameter is only effective if useWholeShape is false.
      * @returns the maximum distance from the polygon's boundary which is shaded. Distance units are indicated by distanceUnit.
@@ -377,7 +377,7 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
      * @see useWholeShape
      * @see setMaxDistance
      * @see distanceUnit
-    */
+     */
     double maxDistance() const { return mMaxDistance; }
 
     /** Sets the unit for the maximum distance to shade inside of the shape from the polygon's boundary.
@@ -385,14 +385,14 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
      * @note added in 2.3
      * @see setMaxDistance
      * @see distanceUnit
-    */
+     */
     void setDistanceUnit( QgsSymbolV2::OutputUnit unit ) { mDistanceUnit = unit; }
     /** Returns the unit for the maximum distance to shade inside of the shape from the polygon's boundary.
      * @returns distance unit for the maximum distance
      * @note added in 2.3
      * @see maxDistance
      * @see setDistanceUnit
-    */
+     */
     QgsSymbolV2::OutputUnit distanceUnit() const { return mDistanceUnit; }
 
     void setDistanceMapUnitScale( const QgsMapUnitScale& scale ) { mDistanceMapUnitScale = scale; }
@@ -406,7 +406,7 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
      * @see setColor
      * @see setColor2
      * @see setColorRamp
-    */
+     */
     void setColorType( ShapeburstColorType colorType ) { mColorType = colorType; }
     /** Returns the color mode used for the shapeburst fill. Shapeburst can either be drawn using a QgsVectorColorRampV2 color ramp
      * or by simply specificing a start and end color.
@@ -416,7 +416,7 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
      * @see color
      * @see color2
      * @see colorRamp
-    */
+     */
     ShapeburstColorType colorType() const { return mColorType; }
 
     /** Sets the color ramp used to draw the shapeburst fill. Color ramps are only used if setColorType is set ShapeburstColorType::ColorRamp.
@@ -424,14 +424,14 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
      * @note added in 2.3
      * @see setColorType
      * @see colorRamp
-    */
+     */
     void setColorRamp( QgsVectorColorRampV2* ramp );
     /** Returns the color ramp used for the shapeburst fill. The color ramp is only used if the colorType is set to ShapeburstColorType::ColorRamp
      * @returns a QgsVectorColorRampV2 color ramp
      * @note added in 2.3
      * @see setColorRamp
      * @see colorType
-    */
+     */
     QgsVectorColorRampV2* colorRamp() { return mGradientRamp; }
 
     /** Sets the color for the endpoint of the shapeburst fill. This color is only used if setColorType is set ShapeburstColorType::SimpleTwoColor.
@@ -439,14 +439,14 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
      * @note added in 2.3
      * @see setColorType
      * @see color2
-    */
+     */
     void setColor2( const QColor& color2 ) { mColor2 = color2; }
     /** Returns the color used for the endpoint of the shapeburst fill. This color is only used if the colorType is set to ShapeburstColorType::SimpleTwoColor
      * @returns a QColor indicating the color of the endpoint of the gradient
      * @note added in 2.3
      * @see setColor2
      * @see colorType
-    */
+     */
     QColor color2() const { return mColor2; }
 
     /** Sets whether the shapeburst fill should ignore polygon rings when calculating
@@ -454,13 +454,13 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
      * @param ignoreRings Set to true if buffers should ignore interior rings for polygons.
      * @note added in 2.3
      * @see ignoreRings
-    */
+     */
     void setIgnoreRings( bool ignoreRings ) { mIgnoreRings = ignoreRings; }
     /** Returns whether the shapeburst fill is set to ignore polygon interior rings.
      * @returns True if the shapeburst fill will ignore interior rings when calculating buffered shading.
      * @note added in 2.3
      * @see setIgnoreRings
-    */
+     */
     bool ignoreRings() const { return mIgnoreRings; }
 
     /** Sets the offset for the shapeburst fill.
@@ -468,14 +468,14 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
      * @note added in 2.3
      * @see offset
      * @see setOffsetUnit
-    */
+     */
     void setOffset( QPointF offset ) { mOffset = offset; }
     /** Returns the offset for the shapeburst fill.
      * @returns a QPointF indicating the horizontal/vertical offset amount
      * @note added in 2.3
      * @see setOffset
      * @see offsetUnit
-    */
+     */
     QPointF offset() const { return mOffset; }
 
     /** Sets the units used for the offset for the shapeburst fill.
@@ -483,14 +483,14 @@ class CORE_EXPORT QgsShapeburstFillSymbolLayerV2 : public QgsFillSymbolLayerV2
      * @note added in 2.3
      * @see setOffset
      * @see offsetUnit
-    */
+     */
     void setOffsetUnit( QgsSymbolV2::OutputUnit unit ) { mOffsetUnit = unit; }
     /** Returns the units used for the offset of the shapeburst fill.
      * @returns units used for the fill offset
      * @note added in 2.3
      * @see offset
      * @see setOffsetUnit
-    */
+     */
     QgsSymbolV2::OutputUnit offsetUnit() const { return mOffsetUnit; }
 
     void setOffsetMapUnitScale( const QgsMapUnitScale& scale ) { mOffsetMapUnitScale = scale; }
@@ -614,46 +614,46 @@ class CORE_EXPORT QgsRasterFillSymbolLayer: public QgsImageFillSymbolLayer
     void startRender( QgsSymbolV2RenderContext& context ) override;
     void stopRender( QgsSymbolV2RenderContext& context ) override;
     QgsStringMap properties() const override;
-    QgsSymbolLayerV2* clone() const override;
+    QgsRasterFillSymbolLayer* clone() const override;
     virtual double estimateMaxBleed() const override;
 
     //override QgsImageFillSymbolLayer's support for sub symbols
-    virtual QgsSymbolV2* subSymbol() override { return 0; }
+    virtual QgsSymbolV2* subSymbol() override { return nullptr; }
     virtual bool setSubSymbol( QgsSymbolV2* symbol ) override;
 
     /** Sets the path to the raster image used for the fill.
      * @param imagePath path to image file
      * @see imageFilePath
-    */
+     */
     void setImageFilePath( const QString& imagePath );
     /** The path to the raster image used for the fill.
      * @returns path to image file
      * @see setImageFilePath
-    */
+     */
     QString imageFilePath() const { return mImageFilePath; }
 
     /** Set the coordinate mode for fill. Controls how the top left corner of the image
      * fill is positioned relative to the feature.
      * @param mode coordinate mode
      * @see coordinateMode
-    */
+     */
     void setCoordinateMode( const FillCoordinateMode mode );
     /** Coordinate mode for fill. Controls how the top left corner of the image
      * fill is positioned relative to the feature.
      * @returns coordinate mode
      * @see setCoordinateMode
-    */
+     */
     FillCoordinateMode coordinateMode() const { return mCoordinateMode; }
 
     /** Sets the opacity for the raster image used in the fill.
      * @param alpha opacity value between 0 (fully transparent) and 1 (fully opaque)
      * @see alpha
-    */
+     */
     void setAlpha( const double alpha );
     /** The opacity for the raster image used in the fill.
      * @returns opacity value between 0 (fully transparent) and 1 (fully opaque)
      * @see setAlpha
-    */
+     */
     double alpha() const { return mAlpha; }
 
     /** Sets the offset for the fill.
@@ -661,14 +661,14 @@ class CORE_EXPORT QgsRasterFillSymbolLayer: public QgsImageFillSymbolLayer
      * @see offset
      * @see setOffsetUnit
      * @see setOffsetMapUnitScale
-    */
-    void setOffset( const QPointF& offset ) { mOffset = offset; }
+     */
+    void setOffset( QPointF offset ) { mOffset = offset; }
     /** Returns the offset for the fill.
      * @returns offset for fill
      * @see setOffset
      * @see offsetUnit
      * @see offsetMapUnitScale
-    */
+     */
     QPointF offset() const { return mOffset; }
 
     /** Sets the units for the fill's offset.
@@ -676,14 +676,14 @@ class CORE_EXPORT QgsRasterFillSymbolLayer: public QgsImageFillSymbolLayer
      * @see offsetUnit
      * @see setOffset
      * @see setOffsetMapUnitScale
-    */
+     */
     void setOffsetUnit( const QgsSymbolV2::OutputUnit unit ) { mOffsetUnit = unit; }
     /** Returns the units for the fill's offset.
      * @returns units for offset
      * @see setOffsetUnit
      * @see offset
      * @see offsetMapUnitScale
-    */
+     */
     QgsSymbolV2::OutputUnit offsetUnit() const { return mOffsetUnit; }
 
     /** Sets the map unit scale for the fill's offset.
@@ -691,14 +691,14 @@ class CORE_EXPORT QgsRasterFillSymbolLayer: public QgsImageFillSymbolLayer
      * @see offsetMapUnitScale
      * @see setOffset
      * @see setOffsetUnit
-    */
+     */
     void setOffsetMapUnitScale( const QgsMapUnitScale& scale ) { mOffsetMapUnitScale = scale; }
     /** Returns the map unit scale for the fill's offset.
      * @returns map unit scale for offset
      * @see setOffsetMapUnitScale
      * @see offset
      * @see offsetUnit
-    */
+     */
     const QgsMapUnitScale& offsetMapUnitScale() const { return mOffsetMapUnitScale; }
 
     /** Sets the width for scaling the image used in the fill. The image's height will also be
@@ -707,7 +707,7 @@ class CORE_EXPORT QgsRasterFillSymbolLayer: public QgsImageFillSymbolLayer
      * @see width
      * @see setWidthUnit
      * @see setWidthMapUnitScale
-    */
+     */
     void setWidth( const double width ) { mWidth = width; }
     /** Returns the width used for scaling the image used in the fill. The image's height is
      * scaled to maintain the image's aspect ratio.
@@ -715,7 +715,7 @@ class CORE_EXPORT QgsRasterFillSymbolLayer: public QgsImageFillSymbolLayer
      * @see setWidth
      * @see widthUnit
      * @see widthMapUnitScale
-    */
+     */
     double width() const { return mWidth; }
 
     /** Sets the units for the image's width.
@@ -723,14 +723,14 @@ class CORE_EXPORT QgsRasterFillSymbolLayer: public QgsImageFillSymbolLayer
      * @see widthUnit
      * @see setWidth
      * @see setWidthMapUnitScale
-    */
+     */
     void setWidthUnit( const QgsSymbolV2::OutputUnit unit ) { mWidthUnit = unit; }
     /** Returns the units for the image's width.
      * @returns units for width
      * @see setWidthUnit
      * @see width
      * @see widthMapUnitScale
-    */
+     */
     QgsSymbolV2::OutputUnit widthUnit() const { return mWidthUnit; }
 
     /** Sets the map unit scale for the image's width.
@@ -738,14 +738,14 @@ class CORE_EXPORT QgsRasterFillSymbolLayer: public QgsImageFillSymbolLayer
      * @see widthMapUnitScale
      * @see setWidth
      * @see setWidthUnit
-    */
+     */
     void setWidthMapUnitScale( const QgsMapUnitScale& scale ) { mWidthMapUnitScale = scale; }
     /** Returns the map unit scale for the image's width.
      * @returns map unit scale for width
      * @see setWidthMapUnitScale
      * @see width
      * @see widthUnit
-    */
+     */
     const QgsMapUnitScale& widthMapUnitScale() const { return mWidthMapUnitScale; }
 
   protected:
@@ -793,7 +793,7 @@ class CORE_EXPORT QgsSVGFillSymbolLayer: public QgsImageFillSymbolLayer
 
     QgsStringMap properties() const override;
 
-    QgsSymbolLayerV2* clone() const override;
+    QgsSVGFillSymbolLayer* clone() const override;
 
     void toSld( QDomDocument &doc, QDomElement &element, const QgsStringMap& props ) const override;
 
@@ -880,7 +880,7 @@ class CORE_EXPORT QgsLinePatternFillSymbolLayer: public QgsImageFillSymbolLayer
 
     QgsStringMap properties() const override;
 
-    QgsSymbolLayerV2* clone() const override;
+    QgsLinePatternFillSymbolLayer* clone() const override;
 
     void toSld( QDomDocument &doc, QDomElement &element, const QgsStringMap& props ) const override;
 
@@ -896,7 +896,7 @@ class CORE_EXPORT QgsLinePatternFillSymbolLayer: public QgsImageFillSymbolLayer
     void setLineWidth( double w );
     double lineWidth() const { return mLineWidth; }
     void setColor( const QColor& c ) override;
-    QColor color() const override { return mColor; }
+    QColor color() const override;
     void setOffset( double offset ) { mOffset = offset; }
     double offset() const { return mOffset; }
 
@@ -973,7 +973,7 @@ class CORE_EXPORT QgsPointPatternFillSymbolLayer: public QgsImageFillSymbolLayer
 
     QgsStringMap properties() const override;
 
-    QgsSymbolLayerV2* clone() const override;
+    QgsPointPatternFillSymbolLayer* clone() const override;
 
     void toSld( QDomDocument &doc, QDomElement &element, const QgsStringMap& props ) const override;
 
@@ -1026,6 +1026,8 @@ class CORE_EXPORT QgsPointPatternFillSymbolLayer: public QgsImageFillSymbolLayer
     QgsMapUnitScale mapUnitScale() const override;
 
     virtual QSet<QString> usedAttributes() const override;
+    void setColor( const QColor& c ) override;
+    virtual QColor color() const override;
 
   protected:
     QgsMarkerSymbolV2* mMarkerSymbol;
@@ -1072,11 +1074,12 @@ class CORE_EXPORT QgsCentroidFillSymbolLayerV2 : public QgsFillSymbolLayerV2
 
     QgsStringMap properties() const override;
 
-    QgsSymbolLayerV2* clone() const override;
+    QgsCentroidFillSymbolLayerV2* clone() const override;
 
     void toSld( QDomDocument &doc, QDomElement &element, const QgsStringMap& props ) const override;
 
     void setColor( const QColor& color ) override;
+    QColor color() const override;
 
     QgsSymbolV2* subSymbol() override;
     bool setSubSymbol( QgsSymbolV2* symbol ) override;
