@@ -22,6 +22,7 @@ class QgsLayerTreeGroup;
 class QgsLayerTreeLayer;
 class QgsLayerTreeModel;
 class QgsLayerTreeNode;
+class QgsLayerTreeModelLegendNode;
 class QgsLayerTreeViewDefaultActions;
 class QgsLayerTreeViewMenuProvider;
 class QgsMapLayer;
@@ -45,7 +46,7 @@ class GUI_EXPORT QgsLayerTreeView : public QTreeView
 {
     Q_OBJECT
   public:
-    explicit QgsLayerTreeView( QWidget *parent = 0 );
+    explicit QgsLayerTreeView( QWidget *parent = nullptr );
     ~QgsLayerTreeView();
 
     //! Overridden setModel() from base class. Only QgsLayerTreeModel is an acceptable model.
@@ -72,6 +73,11 @@ class GUI_EXPORT QgsLayerTreeView : public QTreeView
     //! Get current group node. If a layer is current node, the function will return parent group. May be null.
     QgsLayerTreeGroup* currentGroupNode() const;
 
+    /** Get current legend node. May be null if current node is not a legend node.
+     * @note added in QGIS 2.14
+     */
+    QgsLayerTreeModelLegendNode* currentLegendNode() const;
+
     //! Return list of selected nodes
     //! @arg skipInternal If true, will ignore nodes which have an ancestor in the selection
     QList<QgsLayerTreeNode*> selectedNodes( bool skipInternal = false ) const;
