@@ -73,22 +73,63 @@ class CORE_EXPORT QgsPalLayerSettings
     //! @note added in 2.4
     static QgsPalLayerSettings fromLayer( QgsVectorLayer* layer );
 
+    /** Placement modes which determine how label candidates are generated for a feature.
+     */
+    //TODO QGIS 3.0 - move to QgsLabelingEngineV2
     enum Placement
     {
-      AroundPoint, // Point / Polygon
-      OverPoint, // Point / Polygon
-      Line, // Line / Polygon
-      Curved, // Line
-      Horizontal, // Polygon
-      Free // Polygon
+      AroundPoint, /**< Arranges candidates in a circle around a point (or centroid of a polygon). Applies to point or polygon layers only.*/
+      OverPoint, /**  Arranges candidates over a point (or centroid of a polygon), or at a preset offset from the point. Applies to point or polygon layers only.*/
+      Line, /**< Arranges candidates parallel to a generalised line representing the feature or parallel to a polygon's perimeter. Applies to line or polygon layers only. */
+      Curved, /** Arranges candidates following the curvature of a line feature. Applies to line layers only.*/
+      Horizontal, /**< Arranges horizontal candidates scattered throughout a polygon feature. Applies to polygon layers only.*/
+      Free, /**< Arranges candidates scattered throughout a polygon feature. Candidates are rotated to respect the polygon's orientation. Applies to polygon layers only.*/
+      OrderedPositionsAroundPoint, /**< Candidates are placed in predefined positions around a point. Peference is given to positions with greatest cartographic appeal, eg top right, bottom right, etc. Applies to point layers only.*/
     };
 
+    //! Positions for labels when using the QgsPalLabeling::OrderedPositionsAroundPoint placement mode
+    //TODO QGIS 3.0 - move to QgsLabelingEngineV2
+    enum PredefinedPointPosition
+    {
+      TopLeft, //!< Label on top-left of point
+      TopSlightlyLeft, //! Label on top of point, slightly left of center
+      TopMiddle, //!< Label directly above point
+      TopSlightlyRight, //! Label on top of point, slightly right of center
+      TopRight, //!< Label on top-right of point
+      MiddleLeft, //!< Label on left of point
+      MiddleRight, //!< Label on right of point
+      BottomLeft, //!< Label on bottom-left of point
+      BottomSlightlyLeft, //! Label below point, slightly left of center
+      BottomMiddle, //!< Label directly below point
+      BottomSlightlyRight, //! Label below point, slightly right of center
+      BottomRight, //!< Label on bottom right of point
+    };
+
+    //! Behaviour modifier for label offset and distance, only applies in some
+    //! label placement modes.
+    //TODO QGIS 3.0 - move to QgsLabelingEngineV2
+    enum OffsetType
+    {
+      FromPoint, //!< Offset distance applies from point geometry
+      FromSymbolBounds, //!< Offset distance applies from rendered symbol bounds
+    };
+
+    /** Line placement flags, which control how candidates are generated for a linear feature.
+     */
+    //TODO QGIS 3.0 - move to QgsLabelingEngineV2, rename to LinePlacementFlag, use Q_DECLARE_FLAGS to make
+    //LinePlacementFlags type, and replace use of pal::LineArrangementFlag
     enum LinePlacementFlags
     {
-      OnLine    = 1,
-      AboveLine = 2,
-      BelowLine = 4,
-      MapOrientation = 8
+      OnLine    = 1,      /**< Labels can be placed directly over a line feature.*/
+      AboveLine = 2,      /**< Labels can be placed above a line feature. Unless MapOrientation is also specified this mode
+                               respects the direction of the line feature, so a line from right to left labels will have labels
+                               placed placed below the line feature. */
+      BelowLine = 4,      /**< Labels can be placed below a line feature. Unless MapOrientation is also specified this mode
+                               respects the direction of the line feature, so a line from right to left labels will have labels
+                               placed placed above the line feature. */
+      MapOrientation = 8, /**< Signifies that the AboveLine and BelowLine flags should respect the map's orientation rather
+                               than the feature's orientation. Eg, AboveLine will always result in label's being placed
+                               above a line, regardless of the line's direction. */
     };
 
     enum QuadrantPosition
@@ -130,12 +171,17 @@ class CORE_EXPORT QgsPalLayerSettings
     /** Valid obstacle types, which affect how features within the layer will act as obstacles
      * for labels.
      */
+    //TODO QGIS 3.0 - Move to QgsLabelingEngineV2
     enum ObstacleType
     {
       PolygonInterior, /*!< avoid placing labels over interior of polygon (prefer placing labels totally
        outside or just slightly inside polygon) */
-      PolygonBoundary /*!< avoid placing labels over boundary of polygon (prefer placing outside or
+      PolygonBoundary, /*!< avoid placing labels over boundary of polygon (prefer placing outside or
        completely inside polygon) */
+      PolygonWhole /*!< avoid placing labels over ANY part of polygon. Where PolygonInterior will prefer
+       to place labels with the smallest area of intersection between the label and the polygon,
+       PolygonWhole will penalise any label which intersects with the polygon by an equal amount, so that
+       placing labels over any part of the polygon is avoided.*/
     };
 
     enum ShapeType
@@ -272,6 +318,7 @@ class CORE_EXPORT QgsPalLayerSettings
       RepeatDistance = 84,
       RepeatDistanceUnit = 86,
       Priority = 87,
+      PredefinedPositionOrder = 91,
 
       // rendering
       ScaleVisibility = 23,
@@ -282,6 +329,7 @@ class CORE_EXPORT QgsPalLayerSettings
       FontMaxPixel = 26,
       IsObstacle = 88,
       ObstacleFactor = 89,
+      ZIndex = 90,
 
       // (data defined only)
       Show = 15,
@@ -404,12 +452,21 @@ class CORE_EXPORT QgsPalLayerSettings
     bool centroidWhole; // whether centroid calculated from whole or visible polygon
     bool centroidInside; // whether centroid-point calculated must be inside polygon
 
+    /** Ordered list of predefined label positions for points. Positions earlier
+     * in the list will be prioritised over later positions. Only used when the placement
+     * is set to QgsPalLayerSettings::OrderedPositionsAroundPoint.
+     * @note not available in Python bindings
+     */
+    QVector< PredefinedPointPosition > predefinedPositionOrder;
+
     /** True if only labels which completely fit within a polygon are allowed.
      */
     bool fitInPolygonOnly;
     double dist; // distance from the feature (in mm)
     bool distInMapUnits; //true if distance is in map units (otherwise in mm)
     QgsMapUnitScale distMapUnitScale;
+    //! Offset type for layer (only applies in certain placement modes)
+    OffsetType offsetType;
 
     double repeatDistance;
     SizeUnit repeatDistanceUnit;
@@ -462,21 +519,30 @@ class CORE_EXPORT QgsPalLayerSettings
      */
     ObstacleType obstacleType;
 
+    //! Z-Index of label, where labels with a higher z-index are rendered on top of labels with a lower z-index
+    double zIndex;
+
     //-- scale factors
     double vectorScaleFactor; //scale factor painter units->pixels
     double rasterCompressFactor; //pixel resolution scale factor
 
     // called from register feature hook
-    void calculateLabelSize( const QFontMetricsF* fm, QString text, double& labelX, double& labelY, QgsFeature* f = 0, QgsRenderContext* context = 0 );
+    void calculateLabelSize( const QFontMetricsF* fm, QString text, double& labelX, double& labelY, QgsFeature* f = nullptr, QgsRenderContext* context = nullptr );
 
     /** Register a feature for labelling.
      * @param f feature to label
      * @param context render context. The QgsExpressionContext contained within the render context
      * must have already had the feature and fields sets prior to calling this method.
      * @param dxfLayer dxfLayer name
-     * @param labelFeature if using QgsLabelingEngineV2, this will receive the label feature
+     * @param labelFeature if using QgsLabelingEngineV2, this will receive the label feature. Not available
+     * in Python bindings.
+     * @param obstacleGeometry optional obstacle geometry, if a different geometry to the feature's geometry
+     * should be used as an obstacle for labels (eg, if the feature has been rendered with an offset point
+     * symbol, the obstacle geometry should represent the bounds of the offset symbol). If not set,
+     * the feature's original geometry will be used as an obstacle for labels. Not available
+     * in Python bindings.
      */
-    void registerFeature( QgsFeature& f, QgsRenderContext& context, const QString& dxfLayer, QgsLabelFeature** labelFeature = 0 );
+    void registerFeature( QgsFeature& f, QgsRenderContext& context, const QString& dxfLayer, QgsLabelFeature** labelFeature = nullptr, QgsGeometry* obstacleGeometry = nullptr );
 
     void readFromLayer( QgsVectorLayer* layer );
     void writeToLayer( QgsVectorLayer* layer );
@@ -525,13 +591,13 @@ class CORE_EXPORT QgsPalLayerSettings
      * @note not available in python bindings
      */
     QVariant dataDefinedValue( QgsPalLayerSettings::DataDefinedProperties p, QgsFeature& f, const QgsFields& fields,
-                               const QgsExpressionContext* context = 0 ) const;
+                               const QgsExpressionContext* context = nullptr ) const;
 
     /** Get data defined property value from expression string or attribute field name
      * @returns true/false whether result is null or invalid
      * @note not available in python bindings
      */
-    bool dataDefinedEvaluate( QgsPalLayerSettings::DataDefinedProperties p, QVariant& exprVal, QgsExpressionContext* context = 0, const QVariant& originalValue = QVariant() ) const;
+    bool dataDefinedEvaluate( QgsPalLayerSettings::DataDefinedProperties p, QVariant& exprVal, QgsExpressionContext* context = nullptr, const QVariant& originalValue = QVariant() ) const;
 
     /** Whether data definition is active
      */
@@ -580,7 +646,9 @@ class CORE_EXPORT QgsPalLayerSettings
     int fieldIndex;
     const QgsMapToPixel* xform;
     const QgsCoordinateTransform* ct;
-    QgsPoint ptZero, ptOne;
+
+    QgsPoint ptZero;
+    QgsPoint ptOne;
     QgsGeometry* extentGeom;
     int mFeaturesToLabel; // total features that will probably be labeled, may be less (figured before PAL)
     int mFeatsSendingToPal; // total features tested for sending into PAL (relative to maxNumLabels)
@@ -644,13 +712,15 @@ class CORE_EXPORT QgsPalLayerSettings
 
     /** Registers a feature as an obstacle only (no label rendered)
      */
-    void registerObstacleFeature( QgsFeature &f, QgsRenderContext &context, const QString& dxfLayer, QgsLabelFeature** obstacleFeature );
+    void registerObstacleFeature( QgsFeature &f, QgsRenderContext &context, const QString& dxfLayer, QgsLabelFeature** obstacleFeature, QgsGeometry* obstacleGeometry = nullptr );
 
     QMap<DataDefinedProperties, QVariant> dataDefinedValues;
     QgsExpression* expression;
     QMap<QgsPalLayerSettings::DataDefinedProperties, QPair<QString, int> > mDataDefinedNames;
 
     QFontDatabase mFontDB;
+
+    static QVector< PredefinedPointPosition > DEFAULT_PLACEMENT_ORDER;
 };
 
 class CORE_EXPORT QgsLabelCandidate
@@ -680,14 +750,14 @@ class CORE_EXPORT QgsLabelComponent
         , mUseCenter( false )
         , mSize( QgsPoint() )
         , mOffset( QgsPoint() )
-        , mPicture( 0 )
+        , mPicture( nullptr )
         , mPictureBuffer( 0.0 )
         , mDpiRatio( 1.0 )
     {}
 
     // methods
 
-    const QString& text() const { return mText; }
+    QString text() const { return mText; }
     void setText( const QString& text ) { mText = text; }
 
     const QgsPoint& origin() const { return mOrigin; }
@@ -776,7 +846,8 @@ class CORE_EXPORT QgsLabelingResults
     QList<QgsLabelPosition> labelsWithinRect( const QgsRectangle& r ) const;
 
   private:
-    QgsLabelingResults( const QgsLabelingResults& ) {} // no copying allowed
+    QgsLabelingResults( const QgsLabelingResults& ); // no copying allowed
+    QgsLabelingResults& operator=( const QgsLabelingResults& rh );
 
     QgsLabelSearchTree* mLabelSearchTree;
 
@@ -900,10 +971,10 @@ class CORE_EXPORT QgsPalLabeling : public QgsLabelingEngineInterface
     QgsLabelingResults* takeResults();
 
     //! called when passing engine among map renderers
-    virtual QgsLabelingEngineInterface* clone() override;
+    virtual QgsPalLabeling* clone() override;
 
     //! @note not available in python bindings
-    static void drawLabelCandidateRect( pal::LabelPosition* lp, QPainter* painter, const QgsMapToPixel* xform, QList<QgsLabelCandidate>* candidates = 0 );
+    static void drawLabelCandidateRect( pal::LabelPosition* lp, QPainter* painter, const QgsMapToPixel* xform, QList<QgsLabelCandidate>* candidates = nullptr );
 
     static void drawLabelBuffer( QgsRenderContext& context,
                                  const QgsLabelComponent &component,
@@ -934,7 +1005,7 @@ class CORE_EXPORT QgsPalLabeling : public QgsLabelingEngineInterface
      * @returns prepared geometry, the caller takes ownership
      * @note added in QGIS 2.9
      */
-    static QgsGeometry* prepareGeometry( const QgsGeometry *geometry, QgsRenderContext &context, const QgsCoordinateTransform *ct, QgsGeometry *clipGeometry = 0 );
+    static QgsGeometry* prepareGeometry( const QgsGeometry *geometry, QgsRenderContext &context, const QgsCoordinateTransform *ct, QgsGeometry *clipGeometry = nullptr );
 
     /** Checks whether a geometry requires preparation before registration with PAL
      * @param geometry geometry to prepare
@@ -944,7 +1015,7 @@ class CORE_EXPORT QgsPalLabeling : public QgsLabelingEngineInterface
      * @returns true if geometry requires preparation
      * @note added in QGIS 2.9
      */
-    static bool geometryRequiresPreparation( const QgsGeometry *geometry, QgsRenderContext &context, const QgsCoordinateTransform *ct, QgsGeometry *clipGeometry = 0 );
+    static bool geometryRequiresPreparation( const QgsGeometry *geometry, QgsRenderContext &context, const QgsCoordinateTransform *ct, QgsGeometry *clipGeometry = nullptr );
 
     /** Splits a text string to a list of separate lines, using a specified wrap character.
      * The text string will be split on either newline characters or the wrap character.
