@@ -55,10 +55,9 @@ class CORE_EXPORT QgsProperty
     {}
 
     /** Dumps out the keys and values
-
-    @param tabs is number of tabs to print; used for pretty-printing
-    hierarchy
-    */
+     *
+     * @param tabs is number of tabs to print; used for pretty-printing hierarchy
+     */
     virtual void dump( int tabs = 0 ) const = 0;
 
     /** Returns true if is a QgsPropertyKey */
@@ -68,42 +67,42 @@ class CORE_EXPORT QgsProperty
     virtual bool isValue() const = 0;
 
     /** Returns true if a leaf node
-
-    A leaf node is a key node that has either no value or a single value.
-    A non-leaf node would be a key node with key sub-nodes.
-
-    This is used for entryList() and subkeyList() implementation.
-    */
+     *
+     * A leaf node is a key node that has either no value or a single value.
+     * A non-leaf node would be a key node with key sub-nodes.
+     *
+     * This is used for entryList() and subkeyList() implementation.
+     */
     virtual bool isLeaf() const = 0;
 
     /**
-       restores property hierarchy to given Dom node
-
-       Used for restoring properties from project file
-    */
+     * restores property hierarchy to given Dom node
+     *
+     *  Used for restoring properties from project file
+     */
     virtual bool readXML( QDomNode & keyNode ) = 0;
 
     /**
-       adds property hierarchy to given Dom element
-
-       Used for saving properties to project file.
-
-       @param nodeName the tag name associated with this element
-       @param element the parent (or encompassing) property element
-       @param document the overall project file Dom document
-    */
+     * adds property hierarchy to given Dom element
+     *
+     * Used for saving properties to project file.
+     *
+     * @param nodeName the tag name associated with this element
+     * @param element the parent (or encompassing) property element
+     * @param document the overall project file Dom document
+     */
     virtual bool writeXML( const QString & nodeName,
                            QDomElement   & element,
                            QDomDocument  & document ) = 0;
 
     /** Return the node's value
-
-       For QgsPropertyValue nodes, this is straightforward -- just return the
-       embedded QVariant, _value.  For QgsPropertyKey, this means returning
-       the QgsPropertyValue _value that is keyed by its name, if it exists;
-       i.e., QgsPropertyKey "foo" will return the property value mapped to its
-       name, "foo", in its QHash of QProperties.
-
+     *
+     * For QgsPropertyValue nodes, this is straightforward -- just return the
+     * embedded QVariant, _value.  For QgsPropertyKey, this means returning
+     * the QgsPropertyValue _value that is keyed by its name, if it exists;
+     * i.e., QgsPropertyKey "foo" will return the property value mapped to its
+     * name, "foo", in its QHash of QProperties.
+     *
      */
     virtual QVariant value() const = 0;
 
@@ -136,10 +135,10 @@ class CORE_EXPORT QgsPropertyValue : public QgsProperty
     QVariant value() const override { return value_; }
 
     /** Returns true if is a leaf node
-
-    @note I suppose, in a way, value nodes can also be qualified as leaf
-    nodes even though we're only counting key nodes.
-    */
+     *
+     * @note I suppose, in a way, value nodes can also be qualified as leaf
+     * nodes even though we're only counting key nodes.
+     */
     bool isLeaf() const override { return true; }
 
     void dump( int tabs = 0 ) const override;
@@ -153,17 +152,16 @@ class CORE_EXPORT QgsPropertyValue : public QgsProperty
     int count() const { return 0; }
 
     /** Return keys that do not contain other keys
-
-    Since QgsPropertyValue isn't a key, don't do anything.
-    */
+     * Since QgsPropertyValue isn't a key, don't do anything.
+     */
     void entryList( QStringList & keyName, QStringList & entries ) const
     { Q_UNUSED( keyName ); Q_UNUSED( entries ); /* NOP */ }
 
   private:
 
     /** We use QVariant as it's very handy to keep multiple types and provides
-        type conversions
-    */
+     * type conversions
+     */
     QVariant value_;
 
 }; // class QgsPropertyValue
@@ -195,7 +193,8 @@ class CORE_EXPORT QgsPropertyKey : public QgsProperty
 
     /// every key has a name
     // @{
-    const QString &name() const { return mName; }
+    // @note not available in python bindings
+    QString name() const { return mName; }
 
     QString &name() { return mName; }
     // @}
@@ -224,10 +223,10 @@ class CORE_EXPORT QgsPropertyKey : public QgsProperty
     }
 
     /** Set the value associated with this key
-        @param name is the key name
-        @param value is the value to set
-    @return pointer to property value
-    */
+     * @param name is the key name
+     * @param value is the value to set
+     * @return pointer to property value
+     */
     QgsPropertyValue * setValue( const QString & name, const QVariant & value )
     {
       delete mProperties.take( name );
@@ -237,17 +236,16 @@ class CORE_EXPORT QgsPropertyKey : public QgsProperty
     }
 
     /** Set the value associated with this key
-
-    @note that the single value node associated with each key is always
-    stored keyed by the current key name
-    */
+     *
+     * @note that the single value node associated with each key is always
+     * stored keyed by the current key name
+     */
     QgsPropertyValue * setValue( const QVariant & value )
     {
       return setValue( name(), value );
     }
 
 
-
     void dump( int tabs = 0 ) const override;
 
     bool readXML( QDomNode & keyNode ) override;
@@ -273,10 +271,9 @@ class CORE_EXPORT QgsPropertyKey : public QgsProperty
     void subkeyList( QStringList & entries ) const;
 
     /** Returns true if a leaf node
-
-    A leaf node is a key node that has either no value or a single value.  A
-    non-leaf node would be a key node with key sub-nodes.
-    */
+     * A leaf node is a key node that has either no value or a single value.
+     * A non-leaf node would be a key node with key sub-nodes.
+     */
     bool isLeaf() const override;
 
     /// reset the QgsProperty key to prestine state
