@@ -34,23 +34,23 @@
  * <li><b>Max</b> <i>The maximal allowed value</i></li>
  * <li><b>Step</b> <i>The step size when incrementing/decrementing the value</i></li>
  * </ul>
- *
+ * \note not available in Python bindings
  */
 
 class GUI_EXPORT QgsRangeWidgetWrapper : public QgsEditorWidgetWrapper
 {
     Q_OBJECT
   public:
-    explicit QgsRangeWidgetWrapper( QgsVectorLayer* vl, int fieldIdx, QWidget* editor, QWidget* parent = 0 );
+    explicit QgsRangeWidgetWrapper( QgsVectorLayer* vl, int fieldIdx, QWidget* editor, QWidget* parent = nullptr );
 
     // QgsEditorWidgetWrapper interface
   public:
-    virtual QVariant value() override;
+    virtual QVariant value() const override;
 
   protected:
     virtual QWidget* createWidget( QWidget* parent ) override;
     virtual void initWidget( QWidget* editor ) override;
-    bool valid() override;
+    bool valid() const override;
 
   public slots:
     virtual void setValue( const QVariant& value ) override;
