@@ -41,6 +41,17 @@ class ANALYSIS_EXPORT QgsRasterCalculator
 {
   public:
 
+    //! Result of the calculation
+    enum Result
+    {
+      Success = 0, /*!< Calculation sucessful */
+      CreateOutputError = 1, /*!< Error creating output data file */
+      InputLayerError = 2, /*!< Error reading input layer */
+      Cancelled = 3, /*!< User cancelled calculation */
+      ParserError = 4, /*!< Error parsing formula */
+      MemoryError = 5, /*!< Error allocating memory for result */
+    };
+
     /** QgsRasterCalculator constructor.
      * @param formulaString formula for raster calculation
      * @param outputFile output file path
@@ -67,23 +78,22 @@ class ANALYSIS_EXPORT QgsRasterCalculator
     QgsRasterCalculator( const QString& formulaString, const QString& outputFile, const QString& outputFormat,
                          const QgsRectangle& outputExtent, const QgsCoordinateReferenceSystem& outputCrs, int nOutputColumns, int nOutputRows, const QVector<QgsRasterCalculatorEntry>& rasterEntries );
 
-    ~QgsRasterCalculator();
-
     /** Starts the calculation and writes new raster
       @param p progress bar (or 0 if called from non-gui code)
       @return 0 in case of success*/
-    int processCalculation( QProgressDialog* p = 0 );
+    //TODO QGIS 3.0 - return QgsRasterCalculator::Result
+    int processCalculation( QProgressDialog* p = nullptr );
 
   private:
     //default constructor forbidden. We need formula, output file, output format and output raster resolution obligatory
     QgsRasterCalculator();
 
     /** Opens the output driver and tests if it supports the creation of a new dataset
-      @return NULL on error and the driver handle on success*/
+      @return nullptr on error and the driver handle on success*/
     GDALDriverH openOutputDriver();
 
     /** Opens the output file and sets the same geotransform and CRS as the input data
-      @return the output dataset or NULL in case of error*/
+      @return the output dataset or nullptr in case of error*/
     GDALDatasetH openOutputFile( GDALDriverH outputDriver );
 
     /** Sets gdal 6 parameters array from mOutputRectangle, mNumOutputColumns, mNumOutputRows
