@@ -44,12 +44,12 @@ class GUI_EXPORT QgsRelationReferenceWidgetWrapper : public QgsEditorWidgetWrapp
         QWidget* editor,
         QgsMapCanvas* canvas,
         QgsMessageBar* messageBar,
-        QWidget* parent = 0 );
+        QWidget* parent = nullptr );
 
     virtual QWidget* createWidget( QWidget* parent ) override;
     virtual void initWidget( QWidget* editor ) override;
-    virtual QVariant value() override;
-    bool valid() override;
+    virtual QVariant value() const override;
+    bool valid() const override;
 
   public slots:
     virtual void setValue( const QVariant& value ) override;
