@@ -20,6 +20,8 @@
 #include "qgsrectangle.h"
 #include "qgsrendercontext.h"
 #include "qgssymbolv2.h"
+#include "qgsfield.h"
+#include "qgsfeaturerequest.h"
 
 #include <QList>
 #include <QString>
@@ -30,7 +32,6 @@
 #include <QDomElement>
 
 class QgsFeature;
-class QgsFields;
 class QgsVectorLayer;
 class QgsPaintEffect;
 
@@ -82,12 +83,17 @@ class CORE_EXPORT QgsFeatureRendererV2
     QString type() const { return mType; }
 
     /** To be overridden
+     *
+     * Must be called between startRender() and stopRender() calls.
      * @param feature feature
      * @return returns pointer to symbol or 0 if symbol was not found
+     * @deprecated use symbolForFeature( QgsFeature& feature, QgsRenderContext& context ) instead
      */
     Q_DECL_DEPRECATED virtual QgsSymbolV2* symbolForFeature( QgsFeature& feature );
 
     /** To be overridden
+     *
+     * Must be called between startRender() and stopRender() calls.
      * @param feature feature
      * @param context render context
      * @return returns pointer to symbol or 0 if symbol was not found
@@ -103,6 +109,7 @@ class CORE_EXPORT QgsFeatureRendererV2
      * symbol which can be used as an identifier for renderer's rule - the former may return a temporary replacement
      * of a symbol for use in rendering.
      * @note added in 2.6
+     * @deprecated use originalSymbolForFeature( QgsFeature& feature, QgsRenderContext& context ) instead
      */
     Q_DECL_DEPRECATED virtual QgsSymbolV2* originalSymbolForFeature( QgsFeature& feature );
 
@@ -116,6 +123,12 @@ class CORE_EXPORT QgsFeatureRendererV2
     //TODO - QGIS 3.0 change PyName to originalSymbolForFeature when deprecated method is removed
     virtual QgsSymbolV2* originalSymbolForFeature( QgsFeature& feature, QgsRenderContext& context );
 
+    /**
+     * Return legend keys matching a specified feature.
+     * @note added in 2.14
+     */
+    virtual QSet< QString > legendKeysForFeature( QgsFeature& feature, QgsRenderContext& context );
+
     /**
      * Needs to be called when a new render cycle is started
      *
@@ -128,6 +141,9 @@ class CORE_EXPORT QgsFeatureRendererV2
     //! @deprecated since 2.4 - not using QgsVectorLayer directly anymore
     Q_DECL_DEPRECATED virtual void startRender( QgsRenderContext& context, const QgsVectorLayer* vlayer );
 
+    /**
+     * Needs to be called when a render cycle has finished to clean up.
+     */
     virtual void stopRender( QgsRenderContext& context ) = 0;
 
     /**
@@ -141,14 +157,29 @@ class CORE_EXPORT QgsFeatureRendererV2
      *
      * @return An expression used as where clause
      */
-    virtual QString filter() { return QString::null; }
+    virtual QString filter( const QgsFields& fields = QgsFields() ) { Q_UNUSED( fields ); return QString::null; }
 
+    /**
+     * Returns a set of attributes required for this renderer.
+     *
+     * TODO QGIS3: Change QList to QSet
+     */
     virtual QList<QString> usedAttributes() = 0;
 
     virtual ~QgsFeatureRendererV2();
 
     virtual QgsFeatureRendererV2* clone() const = 0;
 
+    /**
+     * Render a feature using this renderer in the given context.
+     * Must be called between startRender() and stopRender() calls.
+     * Default implementation renders a symbol as determined by symbolForFeature() call.
+     * Returns true if the feature has been returned (this is used for example
+     * to determine whether the feature may be labelled).
+     *
+     * If layer is not -1, the renderer should draw only a particula layer from symbols
+     * (in order to support symbol level rendering).
+     */
     virtual bool renderFeature( QgsFeature& feature, QgsRenderContext& context, int layer = -1, bool selected = false, bool drawVertexMarker = false );
 
     //! for debugging
@@ -166,7 +197,9 @@ class CORE_EXPORT QgsFeatureRendererV2
     //! returns bitwise OR-ed capabilities of the renderer
     virtual int capabilities() { return 0; }
 
-    //! for symbol levels
+    /** For symbol levels
+     * @deprecated use symbols( QgsRenderContext& context ) instead
+     */
     Q_DECL_DEPRECATED virtual QgsSymbolV2List symbols();
 
     /** Returns list of symbols used by the renderer.
@@ -224,6 +257,13 @@ class CORE_EXPORT QgsFeatureRendererV2
     //! @note added in 2.5
     virtual void checkLegendSymbolItem( const QString& key, bool state = true );
 
+    /** Sets the symbol to be used for a legend symbol item.
+     * @param key rule key for legend symbol
+     * @param symbol new symbol for legend item. Ownership is transferred to renderer.
+     * @note added in QGIS 2.14
+     */
+    virtual void setLegendSymbolItem( const QString& key, QgsSymbolV2* symbol );
+
     //! return a list of item text / symbol
     //! @note not available in python bindings
     virtual QgsLegendSymbolList legendSymbolItems( double scaleDenominator = -1, const QString& rule = "" );
@@ -248,9 +288,11 @@ class CORE_EXPORT QgsFeatureRendererV2
     //! @deprecated use the symbol's methods instead
     Q_DECL_DEPRECATED virtual void setRotationField( const QString& fieldName ) { Q_UNUSED( fieldName ); }
 
-    //! return whether the renderer will render a feature or not.
-    //! Must be called between startRender() and stopRender() calls.
-    //! Default implementation uses symbolForFeature().
+    /** Returns whether the renderer will render a feature or not.
+     * Must be called between startRender() and stopRender() calls.
+     * Default implementation uses symbolForFeature().
+     * @deprecated use willRenderFeature( QgsFeature& feat, QgsRenderContext& context ) instead
+     */
     Q_DECL_DEPRECATED virtual bool willRenderFeature( QgsFeature& feat );
 
     /** Returns whether the renderer will render a feature or not.
@@ -262,9 +304,11 @@ class CORE_EXPORT QgsFeatureRendererV2
     //TODO - QGIS 3.0 change PyName to willRenderFeature when deprecated method is removed
     virtual bool willRenderFeature( QgsFeature& feat, QgsRenderContext& context );
 
-    //! return list of symbols used for rendering the feature.
-    //! For renderers that do not support MoreSymbolsPerFeature it is more efficient
-    //! to use symbolForFeature()
+    /** Returns list of symbols used for rendering the feature.
+     * For renderers that do not support MoreSymbolsPerFeature it is more efficient
+     * to use symbolForFeature()
+     * @deprecated use symbolsForFeature( QgsFeature& feat, QgsRenderContext& context ) instead
+     */
     Q_DECL_DEPRECATED virtual QgsSymbolV2List symbolsForFeature( QgsFeature& feat );
 
     /** Returns list of symbols used for rendering the feature.
@@ -272,20 +316,22 @@ class CORE_EXPORT QgsFeatureRendererV2
      * to use symbolForFeature()
      * @note added in QGIS 2.12
      * @note available in Python bindings as symbolsForFeature2
-    */
+     */
     //TODO - QGIS 3.0 change PyName to symbolsForFeature when deprecated method is removed
     virtual QgsSymbolV2List symbolsForFeature( QgsFeature& feat, QgsRenderContext& context );
 
-    //! Equivalent of originalSymbolsForFeature() call
-    //! extended to support renderers that may use more symbols per feature - similar to symbolsForFeature()
-    //! @note added in 2.6
+    /** Equivalent of originalSymbolsForFeature() call
+     * extended to support renderers that may use more symbols per feature - similar to symbolsForFeature()
+     * @note added in 2.6
+     * @deprecated use originalSymbolsForFeature( QgsFeature& feat, QgsRenderContext& context ) instead
+     */
     Q_DECL_DEPRECATED virtual QgsSymbolV2List originalSymbolsForFeature( QgsFeature& feat );
 
     /** Equivalent of originalSymbolsForFeature() call
      * extended to support renderers that may use more symbols per feature - similar to symbolsForFeature()
      * @note added in 2.12
      * @note available in Python bindings as originalSymbolsForFeature2
-    */
+     */
     //TODO - QGIS 3.0 change PyName to symbolsForFeature when deprecated method is removed
     virtual QgsSymbolV2List originalSymbolsForFeature( QgsFeature& feat, QgsRenderContext& context );
 
@@ -326,6 +372,39 @@ class CORE_EXPORT QgsFeatureRendererV2
      */
     void setForceRasterRender( bool forceRaster ) { mForceRaster = forceRaster; }
 
+    /**
+     * Get the order in which features shall be processed by this renderer.
+     * @note added in QGIS 2.14
+     * @note this property has no effect if orderByEnabled() is false
+     * @see orderByEnabled()
+     */
+    QgsFeatureRequest::OrderBy orderBy() const;
+
+    /**
+     * Define the order in which features shall be processed by this renderer.
+     * @note this property has no effect if orderByEnabled() is false
+     * @note added in QGIS 2.14
+     * @see setOrderByEnabled()
+     */
+    void setOrderBy( const QgsFeatureRequest::OrderBy& orderBy );
+
+    /**
+     * Returns whether custom ordering will be applied before features are processed by this renderer.
+     * @note added in QGIS 2.14
+     * @see orderBy()
+     * @see setOrderByEnabled()
+     */
+    bool orderByEnabled() const;
+
+    /**
+     * Sets whether custom ordering should be applied before features are processed by this renderer.
+     * @param enabled set to true to enable custom feature ordering
+     * @note added in QGIS 2.14
+     * @see setOrderBy()
+     * @see orderByEnabled()
+     */
+    void setOrderByEnabled( bool enabled );
+
   protected:
     QgsFeatureRendererV2( const QString& type );
 
@@ -337,22 +416,33 @@ class CORE_EXPORT QgsFeatureRendererV2
                                   bool drawVertexMarker );
 
     //! render editing vertex marker at specified point
-    void renderVertexMarker( const QPointF& pt, QgsRenderContext& context );
+    void renderVertexMarker( QPointF pt, QgsRenderContext& context );
     //! render editing vertex marker for a polyline
     void renderVertexMarkerPolyline( QPolygonF& pts, QgsRenderContext& context );
     //! render editing vertex marker for a polygon
     void renderVertexMarkerPolygon( QPolygonF& pts, QList<QPolygonF>* rings, QgsRenderContext& context );
 
-    static const unsigned char* _getPoint( QPointF& pt, QgsRenderContext& context, const unsigned char* wkb );
-    static const unsigned char* _getLineString( QPolygonF& pts, QgsRenderContext& context, const unsigned char* wkb, bool clipToExtent = true );
-    static const unsigned char* _getPolygon( QPolygonF& pts, QList<QPolygonF>& holes, QgsRenderContext& context, const unsigned char* wkb, bool clipToExtent = true );
+    static QgsConstWkbPtr _getPoint( QPointF& pt, QgsRenderContext& context, QgsConstWkbPtr wkb );
+    static QgsConstWkbPtr _getLineString( QPolygonF& pts, QgsRenderContext& context, QgsConstWkbPtr wkb, bool clipToExtent = true );
+    static QgsConstWkbPtr _getPolygon( QPolygonF& pts, QList<QPolygonF>& holes, QgsRenderContext& context, QgsConstWkbPtr wkb, bool clipToExtent = true );
 
     void setScaleMethodToSymbol( QgsSymbolV2* symbol, int scaleMethod );
 
-    /** Copies paint effect of this renderer to another renderer
+    /**
+     * Clones generic renderer data to another renderer.
+     * Currently clones
+     *  * Order By
+     *  * Paint Effect
+     *
      * @param destRenderer destination renderer for copied effect
      */
-    void copyPaintEffect( QgsFeatureRendererV2 *destRenderer ) const;
+    void copyRendererData( QgsFeatureRendererV2 *destRenderer ) const;
+
+    /** Copies paint effect of this renderer to another renderer
+     * @param destRenderer destination renderer for copied effect
+     * @deprecated use copyRendererData instead
+     */
+    Q_DECL_DEPRECATED void copyPaintEffect( QgsFeatureRendererV2 *destRenderer ) const;
 
     QString mType;
 
@@ -376,6 +466,10 @@ class CORE_EXPORT QgsFeatureRendererV2
      */
     static void convertSymbolRotation( QgsSymbolV2 * symbol, const QString & field );
 
+    QgsFeatureRequest::OrderBy mOrderBy;
+
+    bool mOrderByEnabled;
+
   private:
     Q_DISABLE_COPY( QgsFeatureRendererV2 )
 };
