@@ -50,8 +50,13 @@ class CORE_EXPORT QgsSymbolLayerV2
 
     virtual ~QgsSymbolLayerV2();
 
-    // not necessarily supported by all symbol layers...
+    /**
+     * The fill color.
+     */
     virtual QColor color() const { return mColor; }
+    /**
+     * The fill color.
+     */
     virtual void setColor( const QColor& color ) { mColor = color; }
 
     /** Set outline color. Supported by marker and fill layers.
@@ -70,11 +75,18 @@ class CORE_EXPORT QgsSymbolLayerV2
      * @note added in 2.1 */
     virtual QColor fillColor() const { return QColor(); }
 
+    /**
+     * Returns a string that represents this layer type. Used for serialization.
+     * Should match with the string used to register this symbol layer in the registry.
+     */
     virtual QString layerType() const = 0;
 
     virtual void startRender( QgsSymbolV2RenderContext& context ) = 0;
     virtual void stopRender( QgsSymbolV2RenderContext& context ) = 0;
 
+    /**
+     * Shall be reimplemented by subclasses to create a deep copy of the instance.
+     */
     virtual QgsSymbolLayerV2* clone() const = 0;
 
     virtual void toSld( QDomDocument &doc, QDomElement &element, const QgsStringMap& props ) const
@@ -82,16 +94,24 @@ class CORE_EXPORT QgsSymbolLayerV2
 
     virtual QString ogrFeatureStyle( double mmScaleFactor, double mapUnitScaleFactor ) const { Q_UNUSED( mmScaleFactor ); Q_UNUSED( mapUnitScaleFactor ); return QString(); }
 
+    /**
+     * Should be reimplemented by subclasses to return a string map that
+     * contains the configuration information for the symbol layer. This
+     * is used to serialize a symbol layer perstistently.
+     */
     virtual QgsStringMap properties() const = 0;
 
     virtual void drawPreviewIcon( QgsSymbolV2RenderContext& context, QSize size ) = 0;
 
-    virtual QgsSymbolV2* subSymbol() { return NULL; }
-    // set layer's subsymbol. takes ownership of the passed symbol
+    virtual QgsSymbolV2* subSymbol() { return nullptr; }
+    //! set layer's subsymbol. takes ownership of the passed symbol
     virtual bool setSubSymbol( QgsSymbolV2* symbol ) { delete symbol; return false; }
 
     QgsSymbolV2::SymbolType type() const { return mType; }
 
+    //! Returns if the layer can be used below the specified symbol
+    virtual bool isCompatibleWithSymbol( QgsSymbolV2* symbol ) const;
+
     void setLocked( bool locked ) { mLocked = locked; }
     bool isLocked() const { return mLocked; }
 
@@ -101,11 +121,11 @@ class CORE_EXPORT QgsSymbolLayerV2
       be affected by data defined symbology rules.*/
     virtual double estimateMaxBleed() const { return 0; }
 
-    virtual void setOutputUnit( QgsSymbolV2::OutputUnit unit ) { Q_UNUSED( unit ); } //= 0;
-    virtual QgsSymbolV2::OutputUnit outputUnit() const { return QgsSymbolV2::Mixed; } //= 0;
+    virtual void setOutputUnit( QgsSymbolV2::OutputUnit unit ) { Q_UNUSED( unit ); }
+    virtual QgsSymbolV2::OutputUnit outputUnit() const { return QgsSymbolV2::Mixed; }
 
-    virtual void setMapUnitScale( const QgsMapUnitScale& scale ) { Q_UNUSED( scale ); } //= 0;
-    virtual QgsMapUnitScale mapUnitScale() const { return QgsMapUnitScale(); } //= 0;
+    virtual void setMapUnitScale( const QgsMapUnitScale& scale ) { Q_UNUSED( scale ); }
+    virtual QgsMapUnitScale mapUnitScale() const { return QgsMapUnitScale(); }
 
     // used only with rending with symbol levels is turned on (0 = first pass, 1 = second, ...)
     void setRenderingPass( int renderingPass ) { mRenderingPass = renderingPass; }
@@ -142,10 +162,8 @@ class CORE_EXPORT QgsSymbolLayerV2
     virtual QgsDataDefined* getDataDefinedProperty( const QString& property ) const;
 
     /** Sets a data defined property for the layer.
-     * @param property unique property key. Any existing data defined with the same
-     * key will be deleted and overriden.
-     * @param dataDefined data defined object to associate with property key. Ownership
-     * is transferred to the layer.
+     * @param property unique property key. Any existing data defined with the same key will be deleted and overridden.
+     * @param dataDefined data defined object to associate with property key. Ownership is transferred to the layer.
      * @note added in QGIS 2.9
      * @see getDataDefinedProperty
      * @see removeDataDefinedProperty
@@ -198,8 +216,9 @@ class CORE_EXPORT QgsSymbolLayerV2
      * @see hasDataDefinedProperty
      * @see getDataDefinedProperty
      * @note added in QGIS 2.9
+     * @deprecated use variant which takes QgsSymbolV2RenderContext instead
      */
-    Q_DECL_DEPRECATED virtual QVariant evaluateDataDefinedProperty( const QString& property, const QgsFeature* feature, const QVariant& defaultVal = QVariant(), bool *ok = 0 ) const;
+    Q_DECL_DEPRECATED virtual QVariant evaluateDataDefinedProperty( const QString& property, const QgsFeature* feature, const QVariant& defaultVal = QVariant(), bool *ok = nullptr ) const;
 
     /** Evaluates the matching data defined property and returns the calculated
      * value. Prior to evaluation the data defined property must be prepared
@@ -214,14 +233,14 @@ class CORE_EXPORT QgsSymbolLayerV2
      * @see getDataDefinedProperty
      * @note added in QGIS 2.12
      */
-    virtual QVariant evaluateDataDefinedProperty( const QString& property, const QgsSymbolV2RenderContext& context, const QVariant& defaultVal = QVariant(), bool *ok = 0 ) const;
+    virtual QVariant evaluateDataDefinedProperty( const QString& property, const QgsSymbolV2RenderContext& context, const QVariant& defaultVal = QVariant(), bool *ok = nullptr ) const;
 
     virtual bool writeDxf( QgsDxfExport& e,
                            double mmMapUnitScaleFactor,
                            const QString& layerName,
                            QgsSymbolV2RenderContext* context,
                            const QgsFeature* f,
-                           const QPointF& shift = QPointF( 0.0, 0.0 ) ) const;
+                           QPointF shift = QPointF( 0.0, 0.0 ) ) const;
 
     virtual double dxfWidth( const QgsDxfExport& e, QgsSymbolV2RenderContext& context ) const;
     virtual double dxfOffset( const QgsDxfExport& e, QgsSymbolV2RenderContext& context ) const;
@@ -268,6 +287,7 @@ class CORE_EXPORT QgsSymbolLayerV2
      * be called prior to evaluating data defined properties.
      * @param fields associated layer fields
      * @param scale map scale
+     * @deprecated use variant which takes QgsSymbolV2RenderContext instead
      */
     Q_DECL_DEPRECATED virtual void prepareExpressions( const QgsFields* fields, double scale = -1.0 );
 
@@ -286,19 +306,19 @@ class CORE_EXPORT QgsSymbolLayerV2
     /** Saves all data defined properties to a string map.
      * @param stringMap destination string map
      * @see restoreDataDefinedProperties
-    */
+     */
     void saveDataDefinedProperties( QgsStringMap& stringMap ) const;
 
     /** Restores all data defined properties from string map.
      * @param stringMap source string map
      * @note added in QGIS 2.9
      * @see saveDataDefinedProperties
-    */
+     */
     void restoreDataDefinedProperties( const QgsStringMap& stringMap );
 
     /** Copies all data defined properties of this layer to another symbol layer.
      * @param destLayer destination layer
-    */
+     */
     void copyDataDefinedProperties( QgsSymbolLayerV2* destLayer ) const;
 
     /** Copies paint effect of this layer to another symbol layer
@@ -389,7 +409,7 @@ class CORE_EXPORT QgsMarkerSymbolLayerV2 : public QgsSymbolLayerV2
 
     void startRender( QgsSymbolV2RenderContext& context ) override;
 
-    virtual void renderPoint( const QPointF& point, QgsSymbolV2RenderContext& context ) = 0;
+    virtual void renderPoint( QPointF point, QgsSymbolV2RenderContext& context ) = 0;
 
     void drawPreviewIcon( QgsSymbolV2RenderContext& context, QSize size ) override;
 
@@ -401,7 +421,7 @@ class CORE_EXPORT QgsMarkerSymbolLayerV2 : public QgsSymbolLayerV2
      * is usually used for orienting symbols to match a line's angle.
      * @param lineAngle Angle in degrees, valid values are between 0 and 360
      * @note added in QGIS 2.9
-    */
+     */
     void setLineAngle( double lineAngle ) { mLineAngle = lineAngle; }
 
     void setSize( double size ) { mSize = size; }
@@ -442,6 +462,15 @@ class CORE_EXPORT QgsMarkerSymbolLayerV2 : public QgsSymbolLayerV2
     void setVerticalAnchorPoint( VerticalAnchorPoint v ) { mVerticalAnchorPoint = v; }
     VerticalAnchorPoint verticalAnchorPoint() const { return mVerticalAnchorPoint; }
 
+    /** Returns the approximate bounding box of the marker symbol layer, taking into account
+     * any data defined overrides and offsets which are set for the marker layer.
+     * @returns approximate symbol bounds, in painter units
+     * @note added in QGIS 2.14
+     * @note this method will become pure virtual in QGIS 3.0
+     */
+    //TODO QGIS 3.0 - make pure virtual
+    virtual QRectF bounds( QPointF point, QgsSymbolV2RenderContext& context ) { Q_UNUSED( context ); Q_UNUSED( point ); return QRectF(); }
+
   protected:
     QgsMarkerSymbolLayerV2( bool locked = false );
 
@@ -457,7 +486,7 @@ class CORE_EXPORT QgsMarkerSymbolLayerV2 : public QgsSymbolLayerV2
                        double& offsetX, double& offsetY,
                        const QgsMapUnitScale &widthMapUnitScale, const QgsMapUnitScale &heightMapUnitScale ) const;
 
-    static QPointF _rotatedOffset( const QPointF& offset, double angle );
+    static QPointF _rotatedOffset( QPointF offset, double angle );
 
     double mAngle;
     double mLineAngle;
