@@ -31,7 +31,7 @@ class GUI_EXPORT QgsMapUnitScaleDialog : public QDialog, private Ui::QgsMapUnitS
     Q_OBJECT
 
   public:
-    QgsMapUnitScaleDialog( QWidget* parent );
+    QgsMapUnitScaleDialog( QWidget* parent = nullptr );
 
     /** Returns the map unit scale */
     QgsMapUnitScale getMapUnitScale() const;
@@ -62,18 +62,18 @@ class GUI_EXPORT QgsUnitSelectionWidget : public QWidget, private Ui::QgsUnitSel
     int mMapUnitIdx;
 
   public:
-    QgsUnitSelectionWidget( QWidget* parent = 0 );
+    QgsUnitSelectionWidget( QWidget* parent = nullptr );
 
     /** Sets the units which the user can choose from in the combobox.
      * @param units list of strings for custom units to display in the widget
      * @param mapUnitIdx specifies which entry corresponds to the map units, or -1 if none
-    */
+     */
     void setUnits( const QStringList& units, int mapUnitIdx );
 
     /** Sets the units which the user can choose from in the combobox. Clears any existing units.
      * @param units list of valid units
      * @note added in QGIS 2.9
-    */
+     */
     void setUnits( const QgsSymbolV2::OutputUnitList& units );
 
     /** Get the selected unit index */
@@ -82,17 +82,18 @@ class GUI_EXPORT QgsUnitSelectionWidget : public QWidget, private Ui::QgsUnitSel
     /** Returns the current predefined selected unit (if applicable).
      * @returns selected output unit, or QgsSymbolV2::Mixed if the widget was populated with custom unit types
      * @note added in QGIS 2.9
-    */
+     */
     QgsSymbolV2::OutputUnit unit() const;
 
     /** Sets the selected unit index
      * @param unitIndex index of unit to set as current
-    */
+     * @note available in Python bindings as setUnitIndex
+     */
     void setUnit( int unitIndex );
 
     /** Sets the selected unit
      * @param unit predefined unit to set as current
-    */
+     */
     void setUnit( QgsSymbolV2::OutputUnit unit );
 
     /** Returns the map unit scale */
