@@ -61,42 +61,47 @@ class CORE_EXPORT QgsVectorDataProvider : public QgsDataProvider
     enum Capability
     {
       /** Provider has no capabilities */
-      NoCapabilities =                     0,
+      NoCapabilities =                              0,
       /** Allows adding features */
-      AddFeatures =                        1,
+      AddFeatures =                                 1,
       /** Allows deletion of features */
-      DeleteFeatures =               1 <<  1,
+      DeleteFeatures =                              1 <<  1,
       /** Allows modification of attribute values */
-      ChangeAttributeValues =        1 <<  2,
+      ChangeAttributeValues =                       1 <<  2,
       /** Allows addition of new attributes (fields) */
-      AddAttributes =                1 <<  3,
+      AddAttributes =                               1 <<  3,
       /** Allows deletion of attributes (fields) */
-      DeleteAttributes =             1 <<  4,
+      DeleteAttributes =                            1 <<  4,
       /** DEPRECATED - do not use */
-      SaveAsShapefile =              1 <<  5,
+      SaveAsShapefile =                             1 <<  5,
       /** Allows creation of spatial index */
-      CreateSpatialIndex =           1 <<  6,
+      CreateSpatialIndex =                          1 <<  6,
       /** Fast access to features using their ID */
-      SelectAtId =                   1 <<  7,
+      SelectAtId =                                  1 <<  7,
       /** Allows modifications of geometries */
-      ChangeGeometries =             1 <<  8,
+      ChangeGeometries =                            1 <<  8,
       /** DEPRECATED - do not use */
-      SelectGeometryAtId =           1 <<  9,
+      SelectGeometryAtId =                          1 <<  9,
       /** DEPRECATED - do not use */
-      RandomSelectGeometryAtId =     1 << 10,
+      RandomSelectGeometryAtId =                    1 << 10,
       /** DEPRECATED - do not use */
-      SequentialSelectGeometryAtId = 1 << 11,
-      CreateAttributeIndex =         1 << 12,
+      SequentialSelectGeometryAtId =                1 << 11,
+      /** DEPRECATED - do not use */
+      CreateAttributeIndex =                        1 << 12,
       /** Allows user to select encoding */
-      SelectEncoding =               1 << 13,
+      SelectEncoding =                              1 << 13,
       /** Supports simplification of geometries on provider side according to a distance tolerance */
-      SimplifyGeometries =           1 << 14,
+      SimplifyGeometries =                          1 << 14,
       /** Supports topological simplification of geometries on provider side according to a distance tolerance */
       SimplifyGeometriesWithTopologicalValidation = 1 << 15,
       /** Supports transactions*/
-      TransactionSupport = 1 << 16,
+      TransactionSupport =                          1 << 16,
       /** Supports circular geometry types (circularstring, compoundcurve, curvepolygon)*/
-      CircularGeometries = 1 << 17
+      CircularGeometries =                          1 << 17,
+      /** Supports joint updates for attributes and geometry
+       * Providers supporting this should still define ChangeGeometries | ChangeAttributeValues
+       */
+      ChangeFeatures =                              1 << 18
     };
 
     /** Bitmask of all provider's editing capabilities */
@@ -130,7 +135,7 @@ class CORE_EXPORT QgsVectorDataProvider : public QgsDataProvider
      * @note added in 2.4
      * @return new instance of QgsAbstractFeatureSource (caller is responsible for deleting it)
      */
-    virtual QgsAbstractFeatureSource* featureSource() const { Q_ASSERT( 0 && "All providers must support featureSource()" ); return 0; }
+    virtual QgsAbstractFeatureSource* featureSource() const { Q_ASSERT( 0 && "All providers must support featureSource()" ); return nullptr; }
 
     /**
      * Returns the permanent storage type for this layer as a friendly name.
@@ -239,6 +244,17 @@ class CORE_EXPORT QgsVectorDataProvider : public QgsDataProvider
      */
     virtual bool changeAttributeValues( const QgsChangedAttributesMap &attr_map );
 
+    /**
+     * Changes attribute values and geometries of existing features.
+     * @param attr_map a map containing changed attributes
+     * @param geometry_map   A QgsGeometryMap whose index contains the feature IDs
+     *                       that will have their geometries changed.
+     *                       The second map parameter being the new geometries themselves
+     * @return true in case of success and false in case of failure
+     */
+    virtual bool changeFeatures( const QgsChangedAttributesMap &attr_map,
+                                 const QgsGeometryMap &geometry_map );
+
     /**
      * Returns the default value for field specified by @c fieldId
      */
@@ -251,7 +267,7 @@ class CORE_EXPORT QgsVectorDataProvider : public QgsDataProvider
      *                       The second map parameter being the new geometries themselves
      * @return               True in case of success and false in case of failure
      */
-    virtual bool changeGeometryValues( QgsGeometryMap & geometry_map );
+    virtual bool changeGeometryValues( const QgsGeometryMap &geometry_map );
 
     /**
      * Creates a spatial index on the datasource (if supported by the provider type).
@@ -369,7 +385,7 @@ class CORE_EXPORT QgsVectorDataProvider : public QgsDataProvider
     /**
      * Returns the transaction this data provider is included in, if any.
      */
-    virtual QgsTransaction* transaction() const { return 0; }
+    virtual QgsTransaction* transaction() const { return nullptr; }
 
     /**
      * Forces a reload of the underlying datasource if the provider implements this
@@ -378,7 +394,19 @@ class CORE_EXPORT QgsVectorDataProvider : public QgsDataProvider
      * This forces QGIS to reopen a file or connection.
      * This can be required if the underlying file is replaced.
      */
-    virtual void forceReload() {}
+    virtual void forceReload()
+    {
+      emit dataChanged();
+    }
+
+    /**
+     * Get the list of layer ids on which this layer depends. This in particular determines the order of layer loading.
+     */
+    virtual QSet<QString> layerDependencies() const;
+
+  signals:
+    /** Signals an error in this provider */
+    void raiseError( const QString& msg );
 
   protected:
     void clearMinMaxCache();
