@@ -33,11 +33,9 @@ class QgsVectorLayer;
 class GUI_EXPORT QgsVectorLayerTools
 {
   public:
-    QgsVectorLayerTools()
-    {}
+    QgsVectorLayerTools() {}
 
-    virtual ~QgsVectorLayerTools()
-    {}
+    virtual ~QgsVectorLayerTools() {}
 
     /**
      * This method should/will be called, whenever a new feature will be added to the layer
@@ -45,10 +43,10 @@ class GUI_EXPORT QgsVectorLayerTools
      * @param layer           The layer to which the feature should be added
      * @param defaultValues   Default values for the feature to add
      * @param defaultGeometry A default geometry to add to the feature
+     * @param feature         Updated feature after adding will be written back to this
      * @return                True in case of success, False if the operation failed/was aborted
      */
-    virtual bool addFeature( QgsVectorLayer* layer, const QgsAttributeMap& defaultValues = QgsAttributeMap(), const QgsGeometry& defaultGeometry = QgsGeometry() ) const = 0;
-
+    virtual bool addFeature( QgsVectorLayer* layer, const QgsAttributeMap& defaultValues = QgsAttributeMap(), const QgsGeometry& defaultGeometry = QgsGeometry(), QgsFeature* feature = nullptr ) const = 0;
 
     /**
      * This will be called, whenever a vector layer should be switched to edit mode. Check the providers
