@@ -22,9 +22,11 @@ The content of this file is based on
  ***************************************************************************/
 """
 
+import functools
+
 from PyQt4.QtCore import QObject, Qt, QSettings, QByteArray, SIGNAL, QSize
 from PyQt4.QtGui import QMainWindow, QApplication, QMenu, QIcon, QTabWidget, QGridLayout, QSpacerItem, QSizePolicy, \
-    QDockWidget, QStatusBar, QMenuBar, QToolBar, QKeySequence
+    QDockWidget, QStatusBar, QMenuBar, QToolBar, QKeySequence, QTabBar
 
 from qgis.gui import QgsMessageBar
 from .info_viewer import InfoViewer
@@ -38,6 +40,7 @@ from .dlg_db_error import DlgDbError
 
 
 class DBManager(QMainWindow):
+
     def __init__(self, iface, parent=None):
         QMainWindow.__init__(self, parent)
         self.setAttribute(Qt.WA_DeleteOnClose)
@@ -53,9 +56,10 @@ class DBManager(QMainWindow):
         self.connect(self.tree, SIGNAL("selectedItemChanged"), self.itemChanged)
         self.itemChanged(None)
 
-
     def closeEvent(self, e):
         self.unregisterAllActions()
+        # clear preview, this will delete the layer in preview tab
+        self.preview.loadPreview(None)
 
         # save the window state
         settings = QSettings()
@@ -64,14 +68,13 @@ class DBManager(QMainWindow):
 
         QMainWindow.closeEvent(self, e)
 
-
     def refreshItem(self, item=None):
         QApplication.setOverrideCursor(Qt.WaitCursor)
         try:
             if item is None:
                 item = self.tree.currentItem()
             self.tree.refreshItem(item)  # refresh item children in the db tree
-        except BaseError, e:
+        except BaseError as e:
             DlgDbError.showError(e, self)
             return
         finally:
@@ -81,14 +84,15 @@ class DBManager(QMainWindow):
         QApplication.setOverrideCursor(Qt.WaitCursor)
         try:
             self.reloadButtons()
+            # clear preview, this will delete the layer in preview tab
+            self.preview.loadPreview(None)
             self.refreshTabs()
-        except BaseError, e:
+        except BaseError as e:
             DlgDbError.showError(e, self)
             return
         finally:
             QApplication.restoreOverrideCursor()
 
-
     def reloadButtons(self):
         db = self.tree.currentDatabase()
         if not hasattr(self, '_lastDb'):
@@ -106,18 +110,16 @@ class DBManager(QMainWindow):
         if self._lastDb is not None:
             self._lastDb.registerAllActions(self)
 
-
     def tabChanged(self, index):
         QApplication.setOverrideCursor(Qt.WaitCursor)
         try:
             self.refreshTabs()
-        except BaseError, e:
+        except BaseError as e:
             DlgDbError.showError(e, self)
             return
         finally:
             QApplication.restoreOverrideCursor()
 
-
     def refreshTabs(self):
         index = self.tabs.currentIndex()
         item = self.tree.currentItem()
@@ -139,7 +141,6 @@ class DBManager(QMainWindow):
         elif current_tab == self.preview:
             self.preview.loadPreview(item)
 
-
     def refreshActionSlot(self):
         self.info.setDirty()
         self.table.setDirty()
@@ -184,21 +185,29 @@ class DBManager(QMainWindow):
         if db is None:
             self.infoBar.pushMessage(self.tr("No database selected or you are not connected to it."),
                                      QgsMessageBar.INFO, self.iface.messageTimeout())
+            # force displaying of the message, it appears on the first tab (i.e. Info)
+            self.tabs.setCurrentIndex(0)
             return
 
         from dlg_sql_window import DlgSqlWindow
 
-        dlg = DlgSqlWindow(self.iface, db, self)
-        # refreshDb = lambda x: self.refreshItem( db.connection() ) # refresh the database tree
-        #self.connect( dlg, SIGNAL( "queryExecuted(const QString &)" ), refreshDb )
-        dlg.show()
-        dlg.exec_()
+        query = DlgSqlWindow(self.iface, db, self)
+        dbname = db.connection().connectionName()
+        tabname = self.tr("Query") + u" (%s)" % dbname
+        index = self.tabs.addTab(query, tabname)
+        self.tabs.setTabIcon(index, db.connection().icon())
+        self.tabs.setCurrentIndex(index)
+        query.nameChanged.connect(functools.partial(self.update_query_tab_name, index, dbname))
 
+    def update_query_tab_name(self, index, dbname, queryname):
+        if not queryname:
+            queryname = self.tr("Query")
+        tabname = u"%s (%s)" % (queryname, dbname)
+        self.tabs.setTabText(index, tabname)
 
     def showSystemTables(self):
         self.tree.showSystemTables(self.actionShowSystemTables.isChecked())
 
-
     def registerAction(self, action, menuName, callback=None):
         """ register an action to the manager's main menu """
         if not hasattr(self, '_registeredDbActions'):
@@ -265,8 +274,7 @@ class DBManager(QMainWindow):
 
         return True
 
-
-    def invokeCallback(self, callback, params=None):
+    def invokeCallback(self, callback, *params):
         """ Call a method passing the selected item in the database tree,
                 the sender (usually a QAction), the plugin mainWindow and
                 optionally additional parameters.
@@ -276,12 +284,9 @@ class DBManager(QMainWindow):
         """
         QApplication.setOverrideCursor(Qt.WaitCursor)
         try:
-            if params is None:
-                callback(self.tree.currentItem(), self.sender(), self)
-            else:
-                callback(self.tree.currentItem(), self.sender(), self, *params)
+            callback(self.tree.currentItem(), self.sender(), self, *params)
 
-        except BaseError, e:
+        except BaseError as e:
             # catch database errors and display the error dialog
             DlgDbError.showError(e, self)
             return
@@ -289,7 +294,6 @@ class DBManager(QMainWindow):
         finally:
             QApplication.restoreOverrideCursor()
 
-
     def unregisterAction(self, action, menuName):
         if not hasattr(self, '_registeredDbActions'):
             return
@@ -340,12 +344,18 @@ class DBManager(QMainWindow):
                 self.unregisterAction(action, menuName)
         del self._registeredDbActions
 
+    def close_tab(self, index):
+        widget = self.tabs.widget(index)
+        if widget not in [self.info, self.table, self.preview]:
+            self.tabs.removeTab(index)
+            widget.deleteLater()
+
     def setupUi(self):
         self.setWindowTitle(self.tr("DB Manager"))
         self.setWindowIcon(QIcon(":/db_manager/icon"))
         self.resize(QSize(700, 500).expandedTo(self.minimumSizeHint()))
 
-        # create central tab widget
+        # create central tab widget and add the first 3 tabs: info, table and preview
         self.tabs = QTabWidget()
         self.info = InfoViewer(self)
         self.tabs.addTab(self.info, self.tr("Info"))
@@ -355,6 +365,16 @@ class DBManager(QMainWindow):
         self.tabs.addTab(self.preview, self.tr("Preview"))
         self.setCentralWidget(self.tabs)
 
+        # display close button for all tabs but the first 3 ones, i.e.
+        # HACK: just hide the close button where not needed (GS)
+        self.tabs.setTabsClosable(True)
+        self.tabs.tabCloseRequested.connect(self.close_tab)
+        tabbar = self.tabs.tabBar()
+        for i in range(3):
+            btn = tabbar.tabButton(i, QTabBar.RightSide) if tabbar.tabButton(i, QTabBar.RightSide) else tabbar.tabButton(i, QTabBar.LeftSide)
+            btn.resize(0, 0)
+            btn.hide()
+
         # Creates layout for message bar
         self.layout = QGridLayout(self.info)
         self.layout.setContentsMargins(0, 0, 0, 0)
