@@ -23,7 +23,7 @@ email                : brush.tyler@gmail.com
 # this will disable the dbplugin if the connector raise an ImportError
 from .connector import PostGisDBConnector
 
-from PyQt4.QtCore import QSettings, Qt, QRegExp
+from PyQt4.QtCore import QSettings, Qt, QRegExp, SIGNAL
 from PyQt4.QtGui import QIcon, QAction, QApplication, QMessageBox
 from qgis.gui import QgsMessageBar
 
@@ -37,11 +37,13 @@ except ImportError:
 
 import re
 
+
 def classFactory():
     return PostGisDBPlugin
 
 
 class PostGisDBPlugin(DBPlugin):
+
     @classmethod
     def icon(self):
         return QIcon(":/db_manager/postgis/icon")
@@ -77,8 +79,8 @@ class PostGisDBPlugin(DBPlugin):
 
         uri = QgsDataSourceURI()
 
-        settingsList = ["service", "host", "port", "database", "username", "password"]
-        service, host, port, database, username, password = map(lambda x: settings.value(x, "", type=str), settingsList)
+        settingsList = ["service", "host", "port", "database", "username", "password", "authcfg"]
+        service, host, port, database, username, password, authcfg = map(lambda x: settings.value(x, "", type=str), settingsList)
 
         useEstimatedMetadata = settings.value("estimatedMetadata", False, type=bool)
         sslmode = settings.value("sslmode", QgsDataSourceURI.SSLprefer, type=int)
@@ -86,19 +88,20 @@ class PostGisDBPlugin(DBPlugin):
         settings.endGroup()
 
         if service:
-            uri.setConnection(service, database, username, password, sslmode)
+            uri.setConnection(service, database, username, password, sslmode, authcfg)
         else:
-            uri.setConnection(host, port, database, username, password, sslmode)
+            uri.setConnection(host, port, database, username, password, sslmode, authcfg)
 
         uri.setUseEstimatedMetadata(useEstimatedMetadata)
 
         try:
             return self.connectToUri(uri)
-        except ConnectionError, e:
+        except ConnectionError as e:
             return False
 
 
 class PGDatabase(Database):
+
     def __init__(self, connection, uri):
         Database.__init__(self, connection, uri)
 
@@ -122,7 +125,6 @@ class PGDatabase(Database):
 
         return PGSqlResultModel(self, sql, parent)
 
-
     def registerDatabaseActions(self, mainWindow):
         Database.registerDatabaseActions(self, mainWindow)
 
@@ -148,15 +150,18 @@ class PGDatabase(Database):
 
 
 class PGSchema(Schema):
+
     def __init__(self, row, db):
         Schema.__init__(self, db)
         self.oid, self.name, self.owner, self.perms, self.comment = row
 
 
 class PGTable(Table):
+
     def __init__(self, row, db, schema=None):
         Table.__init__(self, db, schema)
-        self.name, schema_name, self.isView, self.owner, self.estimatedRowCount, self.pages, self.comment = row
+        self.name, schema_name, self._relationType, self.owner, self.estimatedRowCount, self.pages, self.comment = row
+        self.isView = self._relationType in set(['v', 'm'])
         self.estimatedRowCount = int(self.estimatedRowCount)
 
     def runVacuumAnalyze(self):
@@ -222,8 +227,19 @@ class PGTable(Table):
 
         return PGTableDataModel(self, parent)
 
+    def delete(self):
+        self.aboutToChange()
+        if self.isView:
+            ret = self.database().connector.deleteView((self.schemaName(), self.name), self._relationType == 'm')
+        else:
+            ret = self.database().connector.deleteTable((self.schemaName(), self.name))
+        if ret is not False:
+            self.emit(SIGNAL('deleted'))
+        return ret
+
 
 class PGVectorTable(PGTable, VectorTable):
+
     def __init__(self, row, db, schema=None):
         PGTable.__init__(self, row[:-4], db, schema)
         VectorTable.__init__(self, db, schema)
@@ -241,6 +257,7 @@ class PGVectorTable(PGTable, VectorTable):
 
 
 class PGRasterTable(PGTable, RasterTable):
+
     def __init__(self, row, db, schema=None):
         PGTable.__init__(self, row[:-6], db, schema)
         RasterTable.__init__(self, db, schema)
@@ -252,14 +269,15 @@ class PGRasterTable(PGTable, RasterTable):
 
         return PGRasterTableInfo(self)
 
-    def gdalUri(self):
-        uri = self.database().uri()
-        schema = ( u'schema=%s' % self.schemaName() ) if self.schemaName() else ''
-        dbname = ( u'dbname=%s' % uri.database() ) if uri.database() else ''
-        host = ( u'host=%s' % uri.host() ) if uri.host() else ''
-        user = ( u'user=%s' % uri.username() ) if uri.username() else ''
-        passw = ( u'password=%s' % uri.password() ) if uri.password() else ''
-        port = ( u'port=%s' % uri.port() ) if uri.port() else ''
+    def gdalUri(self, uri=None):
+        if not uri:
+            uri = self.database().uri()
+        schema = (u'schema=%s' % self.schemaName()) if self.schemaName() else ''
+        dbname = (u'dbname=%s' % uri.database()) if uri.database() else ''
+        host = (u'host=%s' % uri.host()) if uri.host() else ''
+        user = (u'user=%s' % uri.username()) if uri.username() else ''
+        passw = (u'password=%s' % uri.password()) if uri.password() else ''
+        port = (u'port=%s' % uri.port()) if uri.port() else ''
 
         # Find first raster field
         col = ''
@@ -274,19 +292,37 @@ class PGRasterTable(PGTable, RasterTable):
         return gdalUri
 
     def mimeUri(self):
+        # QGIS has no provider for PGRasters, let's use GDAL
         uri = u"raster:gdal:%s:%s" % (self.name, re.sub(":", "\:", self.gdalUri()))
         return uri
 
     def toMapLayer(self):
-        from qgis.core import QgsRasterLayer, QgsContrastEnhancement
+        from qgis.core import QgsRasterLayer, QgsContrastEnhancement, QgsDataSourceURI, QgsCredentials
 
         rl = QgsRasterLayer(self.gdalUri(), self.name)
+        if not rl.isValid():
+            err = rl.error().summary()
+            uri = QgsDataSourceURI(self.database().uri())
+            conninfo = uri.connectionInfo(False)
+            username = uri.username()
+            password = uri.password()
+
+            for i in range(3):
+                (ok, username, password) = QgsCredentials.instance().get(conninfo, username, password, err)
+                if ok:
+                    uri.setUsername(username)
+                    uri.setPassword(password)
+                    rl = QgsRasterLayer(self.gdalUri(uri), self.name)
+                    if rl.isValid():
+                        break
+
         if rl.isValid():
             rl.setContrastEnhancement(QgsContrastEnhancement.StretchToMinimumMaximum)
         return rl
 
 
 class PGTableField(TableField):
+
     def __init__(self, row, table):
         TableField.__init__(self, table)
         self.num, self.name, self.dataType, self.charMaxLen, self.modifier, self.notNull, self.hasDefault, self.default, typeStr = row
@@ -309,6 +345,7 @@ class PGTableField(TableField):
 
 
 class PGTableConstraint(TableConstraint):
+
     def __init__(self, row, table):
         TableConstraint.__init__(self, table)
         self.name, constr_type_str, self.isDefferable, self.isDeffered, columns = row[:5]
@@ -330,6 +367,7 @@ class PGTableConstraint(TableConstraint):
 
 
 class PGTableIndex(TableIndex):
+
     def __init__(self, row, table):
         TableIndex.__init__(self, table)
         self.name, columns, self.isUnique = row
@@ -337,12 +375,14 @@ class PGTableIndex(TableIndex):
 
 
 class PGTableTrigger(TableTrigger):
+
     def __init__(self, row, table):
         TableTrigger.__init__(self, table)
         self.name, self.function, self.type, self.enabled = row
 
 
 class PGTableRule(TableRule):
+
     def __init__(self, row, table):
         TableRule.__init__(self, table)
         self.name, self.definition = row
