@@ -30,8 +30,8 @@ def load(dbplugin, mainwindow):
         if not os.path.isdir(os.path.join(current_dir, name)):
             continue
         try:
-            exec ( u"from .%s import load" % name  )
-        except ImportError, e:
+            exec (u"from .%s import load" % name)
+        except ImportError as e:
             continue
 
         load(dbplugin, mainwindow)
