@@ -108,6 +108,9 @@ class SpatiaLiteDBConnector(DBConnector):
             result = self._execute(None, sql).fetchone()[0] == 1
         except ConnectionError:
             result = False
+        except Exception as e:
+            # SpatiaLite < 4.2 does not have HasGeoPackage() function
+            result = False
 
         if result:
             try:
@@ -368,7 +371,14 @@ class SpatiaLiteDBConnector(DBConnector):
         indexes = c.fetchall()
 
         for i, idx in enumerate(indexes):
-            num, name, unique = idx
+            # sqlite has changed the number of columns returned by index_list since 3.8.9
+            # I am not using self.getInfo() here because this behaviour
+            # can be changed back without notice as done for index_info, see:
+            # http://repo.or.cz/sqlite.git/commit/53555d6da78e52a430b1884b5971fef33e9ccca4
+            if len(idx) == 3:
+                num, name, unique = idx
+            if len(idx) == 5:
+                num, name, unique, createdby, partial = idx
             sql = u"PRAGMA index_info(%s)" % (self.quoteId(name))
             self._execute(c, sql)
 
