@@ -54,6 +54,7 @@ class DlgSqlWindow(QWidget, Ui_Dialog):
         QWidget.__init__(self, parent)
         self.iface = iface
         self.db = db
+        self.filter = ""
         self.allowMultiColumnPk = isinstance(db, PGDatabase) # at the moment only PostgreSQL allows a primary key to span multiple columns, spatialite doesn't
         self.aliasSubQuery = isinstance(db, PGDatabase)	# only PostgreSQL requires subqueries to be aliases
         self.setupUi(self)
@@ -71,7 +72,7 @@ class DlgSqlWindow(QWidget, Ui_Dialog):
         self.editSql.setVerticalScrollBarPolicy(Qt.ScrollBarAsNeeded)
         self.initCompleter()
 
-        # allow to copy results
+        # allow copying results
         copyAction = QAction("copy", self)
         self.viewResult.addAction(copyAction)
         copyAction.setShortcuts(QKeySequence.Copy)
@@ -79,6 +80,7 @@ class DlgSqlWindow(QWidget, Ui_Dialog):
         copyAction.triggered.connect(self.copySelectedResults)
 
         self.btnExecute.clicked.connect(self.executeSql)
+        self.btnSetFilter.clicked.connect(self.setFilter)
         self.btnClear.clicked.connect(self.clearSql)
 
         self.presetStore.clicked.connect(self.storePreset)
@@ -168,6 +170,7 @@ class DlgSqlWindow(QWidget, Ui_Dialog):
     def clearSql(self):
         self.editSql.clear()
         self.editSql.setFocus()
+        self.filter = ""
 
     def executeSql(self):
 
@@ -207,7 +210,7 @@ class DlgSqlWindow(QWidget, Ui_Dialog):
         self.update()
         QApplication.restoreOverrideCursor()
 
-    def loadSqlLayer(self):
+    def _getSqlLayer(self, _filter):
         hasUniqueField = self.uniqueColumnCheck.checkState() == Qt.Checked
         if hasUniqueField:
             if self.allowMultiColumnPk:
@@ -230,14 +233,12 @@ class DlgSqlWindow(QWidget, Ui_Dialog):
 
         query = self._getSqlQuery()
         if query == "":
-            return
+            return None
 
         # remove a trailing ';' from query if present
         if query.strip().endswith(';'):
             query = query.strip()[:-1]
 
-        QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
-
         from qgis.core import QgsMapLayer, QgsMapLayerRegistry
 
         layerType = QgsMapLayer.VectorLayer if self.vectorRadio.isChecked() else QgsMapLayer.RasterLayer
@@ -258,11 +259,23 @@ class DlgSqlWindow(QWidget, Ui_Dialog):
 
         # create the layer
         layer = self.db.toSqlLayer(query, geomFieldName, uniqueFieldName, newLayerName, layerType,
-                                   self.avoidSelectById.isChecked())
+                                   self.avoidSelectById.isChecked(), _filter)
         if layer.isValid():
-            QgsMapLayerRegistry.instance().addMapLayers([layer], True)
+            return layer
+        else:
+            return None
 
-        QApplication.restoreOverrideCursor()
+    def loadSqlLayer(self):
+        QApplication.setOverrideCursor(QCursor(Qt.WaitCursor))
+        try:
+            layer = self._getSqlLayer(self.filter)
+            if layer == None:
+                return
+
+            from qgis.core import QgsMapLayerRegistry
+            QgsMapLayerRegistry.instance().addMapLayers([layer], True)
+        finally:
+            QApplication.restoreOverrideCursor()
 
     def fillColumnCombos(self):
         query = self._getSqlQuery()
@@ -447,3 +460,15 @@ class DlgSqlWindow(QWidget, Ui_Dialog):
         label = ", ".join(checkedItems)
         if text != label:
             self.uniqueCombo.setEditText(label)
+
+    def setFilter(self):
+        from qgis.gui import QgsQueryBuilder
+        layer = self._getSqlLayer("")
+        if not layer:
+            return
+
+        dlg = QgsQueryBuilder(layer)
+        dlg.setSql(self.filter)
+        if dlg.exec_():
+            self.filter = dlg.sql()
+        layer.deleteLater()
