@@ -1,53 +1,52 @@
-# -*- coding: utf-8 -*-
+
 #-----------------------------------------------------------
-# 
-# Create Point Distance Matrix
-#
-# A QGIS plugin for measuring distances between points. Measure 
-# distances between two point layers, and output the results
-# as: a) Standard distance matrix, b) Linear distance matrix
-# or c) Summary distance matrix
-#
-# Copyright (C) 2008  Carson Farmer
 #
+# fTools
+# Copyright (C) 2008-2011  Carson Farmer
 # EMAIL: carson.farmer (at) gmail.com
-# WEB  : www.geog.uvic.ca/spar/carson
+# WEB  : http://www.ftools.ca/fTools.html
+#
+# A collection of data management and analysis tools for vector data
 #
 #-----------------------------------------------------------
-# 
+#
 # licensed under the terms of GNU GPL 2
-# 
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License along
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-# 
+#
 #---------------------------------------------------------------------
 
-from PyQt4.QtCore import *
-from PyQt4.QtGui import *
+from PyQt4.QtCore import QObject, SIGNAL, QVariant, QFileInfo
+from PyQt4.QtGui import QDialog, QDialogButtonBox, QMessageBox, QFileDialog
+from qgis.core import QGis, QgsSpatialIndex, QgsFeature, QgsDistanceArea, QgsGeometry, QgsFeatureRequest
 
-from qgis.core import *
 from ui_frmPointDistance import Ui_Dialog
-import csv, codecs, cStringIO
+import csv
+import codecs
+import cStringIO
 import ftools_utils
-from math import *
+from math import sqrt
+
 
 class UnicodeWriter:
+
     """
     A CSV writer which will write rows to CSV file "f",
     which is encoded in the given encoding.
     Taken from http://docs.python.org/library/csv.html
-    to allow handling of nonascii output
+    to allow handling of non-ascii output
     """
 
     def __init__(self, f, dialect=csv.excel, encoding="utf-8", **kwds):
@@ -76,21 +75,22 @@ class UnicodeWriter:
         for row in rows:
             self.writerow(row)
 
+
 class Dialog(QDialog, Ui_Dialog):
+
     def __init__(self, iface):
-        QDialog.__init__(self)
+        QDialog.__init__(self, iface.mainWindow())
         self.iface = iface
         # Set up the user interface from Designer.
         self.setupUi(self)
         QObject.connect(self.btnFile, SIGNAL("clicked()"), self.saveFile)
         QObject.connect(self.inPoint1, SIGNAL("currentIndexChanged(QString)"), self.update1)
         QObject.connect(self.inPoint2, SIGNAL("currentIndexChanged(QString)"), self.update2)
-        self.buttonOk = self.buttonBox_2.button( QDialogButtonBox.Ok )
+        self.buttonOk = self.buttonBox_2.button(QDialogButtonBox.Ok)
         # populate layer list
         self.setWindowTitle(self.tr("Distance matrix"))
         self.progressBar.setValue(0)
-        mapCanvas = self.iface.mapCanvas()
-        layers = ftools_utils.getLayerNames( [ QGis.Point ] )
+        layers = ftools_utils.getLayerNames([QGis.Point])
         self.inPoint1.addItems(layers)
         self.inPoint2.addItems(layers)
 
@@ -98,22 +98,20 @@ class Dialog(QDialog, Ui_Dialog):
         self.inField1.clear()
         changedLayer = ftools_utils.getVectorLayerByName(unicode(inputLayer))
         changedField = ftools_utils.getFieldList(changedLayer)
-        for i in changedField:
-            if changedField[i].type() == QVariant.Int or \
-            changedField[i].type() == QVariant.String:
-                self.inField1.addItem(unicode(changedField[i].name()))
+        for f in changedField:
+            if f.type() == QVariant.Int or f.type() == QVariant.String:
+                self.inField1.addItem(unicode(f.name()))
 
     def update2(self, inputLayer):
         self.inField2.clear()
         changedLayer = ftools_utils.getVectorLayerByName(unicode(inputLayer))
         changedField = ftools_utils.getFieldList(changedLayer)
-        for i in changedField:
-            if changedField[i].type() == QVariant.Int or \
-            changedField[i].type() == QVariant.String:
-                self.inField2.addItem(unicode(changedField[i].name()))
+        for f in changedField:
+            if f.type() == QVariant.Int or f.type() == QVariant.String:
+                self.inField2.addItem(unicode(f.name()))
 
     def accept(self):
-        self.buttonOk.setEnabled( False )
+        self.buttonOk.setEnabled(False)
         if self.inPoint1.currentText() == "":
             QMessageBox.information(self, self.tr("Create Point Distance Matrix"), self.tr("Please specify input point layer"))
         elif self.outFile.text() == "":
@@ -130,60 +128,61 @@ class Dialog(QDialog, Ui_Dialog):
             field1 = self.inField1.currentText()
             field2 = self.inField2.currentText()
             outPath = self.outFile.text()
-            if self.rdoLinear.isChecked(): matType = "Linear"
-            elif self.rdoStandard.isChecked(): matType = "Standard"
-            else: matType = "Summary"
-            if self.chkNearest.isChecked(): nearest = self.spnNearest.value()
-            else: nearest = nearest = 0
-            if outPath.contains("\\"):
-                outName = outPath.right((outPath.length() - outPath.lastIndexOf("\\")) - 1)
+            if self.rdoLinear.isChecked():
+                matType = "Linear"
+            elif self.rdoStandard.isChecked():
+                matType = "Standard"
             else:
-                outName = outPath.right((outPath.length() - outPath.lastIndexOf("/")) - 1)
-            if outName.endsWith(".csv"):
-                outName = outName.left(outName.length() - 4)
+                matType = "Summary"
+            if self.chkNearest.isChecked():
+                nearest = self.spnNearest.value()
+            else:
+                nearest = 0
+            # outName = ftools_utils.getShapefileName(outPath,'.csv')
             self.outFile.clear()
             self.compute(point1, point2, field1, field2, outPath, matType, nearest, self.progressBar)
             self.progressBar.setValue(100)
-            addToTOC = QMessageBox.information(self, "Create Point Distance Matrix", self.tr("Created output matrix:\n") + outPath)
+            # addToTOC = QMessageBox.information(self, "Create Point Distance Matrix", self.tr("Created output matrix:\n") + outPath)
         self.progressBar.setValue(0)
-        self.buttonOk.setEnabled( True )
+        self.buttonOk.setEnabled(True)
 
     def saveFile(self):
         self.outFile.clear()
         fileDialog = QFileDialog()
-        outName = fileDialog.getSaveFileName(self, "Output Distance Matrix",".", "Delimited txt file (*.csv)")
-        fileCheck = QFile(outName)
+        outName = fileDialog.getSaveFileName(self, "Output Distance Matrix", ".", "Delimited txt file (*.csv)")
         filePath = QFileInfo(outName).absoluteFilePath()
-        if filePath.right(4) != ".csv": filePath = filePath + ".csv"
-        if not outName.isEmpty():
+        if filePath[-4:] != ".csv":
+            filePath = filePath + ".csv"
+        if outName:
             self.outFile.insert(filePath)
 
     def compute(self, line1, line2, field1, field2, outPath, matType, nearest, progressBar):
         layer1 = ftools_utils.getVectorLayerByName(line1)
         layer2 = ftools_utils.getVectorLayerByName(line2)
+        if layer1.id() == layer2.id():
+            if nearest > 0:
+                nearest = nearest + 1
         provider1 = layer1.dataProvider()
         provider2 = layer2.dataProvider()
-        allAttrs = provider1.attributeIndexes()
-        provider1.select(allAttrs)
-        allAttrs = provider2.attributeIndexes()
-        provider2.select(allAttrs)
         sindex = QgsSpatialIndex()
         inFeat = QgsFeature()
-        while provider2.nextFeature(inFeat):
+        fit2 = provider2.getFeatures()
+        while fit2.nextFeature(inFeat):
             sindex.insertFeature(inFeat)
-        provider2.rewind()
-        if nearest < 1: nearest = layer2.featureCount()
-        else: nearest = nearest + 1
+        if nearest < 1:
+            nearest = layer2.featureCount()
+        else:
+            nearest = nearest
         index1 = provider1.fieldNameIndex(field1)
         index2 = provider2.fieldNameIndex(field2)
-        sRs = provider1.crs()
         distArea = QgsDistanceArea()
         #use srs of the first layer (users should ensure that they are both in the same projection)
-        #distArea.setSourceSRS(sRs)
+        # sRs = provider1.crs()
+        # distArea.setSourceSRS(sRs)
 
         f = open(unicode(outPath), "wb")
         writer = UnicodeWriter(f)
-        if matType <> "Standard":
+        if matType != "Standard":
             if matType == "Linear":
                 writer.writerow(["InputID", "TargetID", "Distance"])
             else:
@@ -201,23 +200,24 @@ class Dialog(QDialog, Ui_Dialog):
         first = True
         start = 15.00
         add = 85.00 / provider1.featureCount()
-        while provider1.nextFeature(inFeat):
+        fit1 = provider1.getFeatures()
+        while fit1.nextFeature(inFeat):
             inGeom = inFeat.geometry()
-            inID = inFeat.attributeMap()[index1].toString()
+            inID = inFeat.attributes()[index1]
             if first:
                 featList = sindex.nearestNeighbor(inGeom.asPoint(), nearest)
                 first = False
                 data = ["ID"]
                 for i in featList:
-                    provider2.featureAtId(int(i), outFeat, True, [index2])
-                    data.append(unicode(outFeat.attributeMap()[index2].toString()))
+                    provider2.getFeatures(QgsFeatureRequest().setFilterFid(int(i)).setSubsetOfAttributes([index2])).nextFeature(outFeat)
+                    data.append(unicode(outFeat.attributes()[index2]))
                 writer.writerow(data)
             data = [unicode(inID)]
             for j in featList:
-                provider2.featureAtId(int(j), outFeat, True)
+                provider2.getFeatures(QgsFeatureRequest().setFilterFid(int(j))).nextFeature(outFeat)
                 outGeom = outFeat.geometry()
                 dist = distArea.measureLine(inGeom.asPoint(), outGeom.asPoint())
-                data.append(str(float(dist)))
+                data.append(unicode(float(dist)))
             writer.writerow(data)
             start = start + add
             progressBar.setValue(start)
@@ -230,26 +230,29 @@ class Dialog(QDialog, Ui_Dialog):
         outGeom = QgsGeometry()
         start = 15.00
         add = 85.00 / provider1.featureCount()
-        while provider1.nextFeature(inFeat):
+        fit1 = provider1.getFeatures()
+        while fit1.nextFeature(inFeat):
             inGeom = inFeat.geometry()
-            inID = inFeat.attributeMap()[index1].toString()
+            inID = inFeat.attributes()[index1]
             featList = sindex.nearestNeighbor(inGeom.asPoint(), nearest)
             distList = []
             vari = 0.00
             for i in featList:
-                provider2.featureAtId(int(i), outFeat, True, [index2])
-                outID = outFeat.attributeMap()[index2].toString()
+                provider2.getFeatures(QgsFeatureRequest().setFilterFid(int(i)).setSubsetOfAttributes([index2])).nextFeature(outFeat)
+                outID = outFeat.attributes()[index2]
                 outGeom = outFeat.geometry()
                 dist = distArea.measureLine(inGeom.asPoint(), outGeom.asPoint())
                 if dist > 0:
-                    if matType == "Linear": writer.writerow([unicode(inID), unicode(outID), str(dist)])
-                    else: distList.append(float(dist))
+                    if matType == "Linear":
+                        writer.writerow([unicode(inID), unicode(outID), unicode(dist)])
+                    else:
+                        distList.append(float(dist))
             if matType == "Summary":
                 mean = sum(distList) / len(distList)
                 for i in distList:
-                    vari = vari + ((i - mean)*(i - mean))
+                    vari = vari + ((i - mean) * (i - mean))
                 vari = sqrt(vari / len(distList))
-                writer.writerow([unicode(inID), str(mean), str(vari), str(min(distList)), str(max(distList))])
+                writer.writerow([unicode(inID), unicode(mean), unicode(vari), unicode(min(distList)), unicode(max(distList))])
             start = start + add
             progressBar.setValue(start)
         del writer
