@@ -180,7 +180,10 @@ class VisualDialog(QDialog, Ui_Dialog):
         else:
             self.tblUnique.setColumnCount(2)
             for rec in range(numRows):
-                tmp = result[rec].split(":")
+                if ":" not in result[rec]:
+                    tmp = result[rec].split(u"\uff1a")
+                else:
+                    tmp = result[rec].split(":")
                 item = QTableWidgetItem(tmp[0])
                 self.tblUnique.setItem(rec, 0, item)
                 item = QTableWidgetItem(tmp[1])
