@@ -54,23 +54,23 @@ class GridNearest(GdalAlgorithm):
         return "gdalogr:gridnearestneighbor"
 
     def defineCharacteristics(self):
-        self.name = 'Grid (Nearest neighbor)'
-        self.group = '[GDAL] Analysis'
+        self.name, self.i18n_name = self.trAlgorithm('Grid (Nearest neighbor)')
+        self.group, self.i18n_group = self.trAlgorithm('[GDAL] Analysis')
         self.addParameter(ParameterVector(self.INPUT,
-            self.tr('Input layer'), [ParameterVector.VECTOR_TYPE_POINT]))
+                                          self.tr('Input layer'), [ParameterVector.VECTOR_TYPE_POINT]))
         self.addParameter(ParameterTableField(self.Z_FIELD,
-            self.tr('Z field'), self.INPUT,
-            ParameterTableField.DATA_TYPE_NUMBER, True))
+                                              self.tr('Z field'), self.INPUT,
+                                              ParameterTableField.DATA_TYPE_NUMBER, True))
         self.addParameter(ParameterNumber(self.RADIUS_1,
-            self.tr('Radius 1'), 0.0, 99999999.999999, 0.0))
+                                          self.tr('Radius 1'), 0.0, 99999999.999999, 0.0))
         self.addParameter(ParameterNumber(self.RADIUS_2,
-            self.tr('Radius 2'), 0.0, 99999999.999999, 0.0))
+                                          self.tr('Radius 2'), 0.0, 99999999.999999, 0.0))
         self.addParameter(ParameterNumber(self.ANGLE,
-            self.tr('Angle'), 0.0, 359.0, 0.0))
+                                          self.tr('Angle'), 0.0, 359.0, 0.0))
         self.addParameter(ParameterNumber(self.NODATA,
-            self.tr('Nodata'), 0.0, 99999999.999999, 0.0))
+                                          self.tr('Nodata'), 0.0, 99999999.999999, 0.0))
         self.addParameter(ParameterSelection(self.RTYPE,
-            self.tr('Output raster type'), self.TYPE, 5))
+                                             self.tr('Output raster type'), self.TYPE, 5))
 
         self.addOutput(OutputRaster(self.OUTPUT, self.tr('Interpolated nearest neighbor')))
 
