@@ -92,7 +92,7 @@ class gdalcalc(GdalAlgorithm):
         self.addParameter(ParameterString(self.FORMULA,
                                           self.tr('Calculation in gdalnumeric syntax using +-/* or any numpy array functions (i.e. logical_and())'), 'A*2', optional=False))
         self.addParameter(ParameterString(self.NO_DATA,
-                                          self.tr('Set output nodata value'), '-9999'))
+                                          self.tr('Set output nodata value'), '', optional=True))
         self.addParameter(ParameterSelection(self.RTYPE,
                                              self.tr('Output raster type'), self.TYPE, 5))
         #self.addParameter(ParameterBoolean(
@@ -103,10 +103,14 @@ class gdalcalc(GdalAlgorithm):
 
     def getConsoleCommands(self):
         out = self.getOutputValue(self.OUTPUT)
-        extra = unicode(self.getParameterValue(self.EXTRA))
+        extra = self.getParameterValue(self.EXTRA)
+        if extra is not None:
+            extra = unicode(extra)
         #debug = self.getParameterValue(self.DEBUG)
         formula = self.getParameterValue(self.FORMULA)
-        noData = unicode(self.getParameterValue(self.NO_DATA))
+        noData = self.getParameterValue(self.NO_DATA)
+        if noData is not None:
+            noData = unicode(noData)
 
         arguments = []
         arguments.append('--calc')
@@ -115,10 +119,10 @@ class gdalcalc(GdalAlgorithm):
         arguments.append(GdalUtils.getFormatShortNameFromFilename(out))
         arguments.append('--type')
         arguments.append(self.TYPE[self.getParameterValue(self.RTYPE)])
-        if len(noData) > 0:
+        if noData and len(noData) > 0:
             arguments.append('--NoDataValue')
             arguments.append(noData)
-        if len(extra) > 0:
+        if extra and len(extra) > 0:
             arguments.append(extra)
         #if debug:
         #    arguments.append('--debug')
