@@ -43,16 +43,16 @@ class information(GdalAlgorithm):
         return "gdalorg:rasterinfo"
 
     def defineCharacteristics(self):
-        self.name = 'Information'
-        self.group = '[GDAL] Miscellaneous'
+        self.name, self.i18n_name = self.trAlgorithm('Information')
+        self.group, self.i18n_group = self.trAlgorithm('[GDAL] Miscellaneous')
         self.addParameter(ParameterRaster(information.INPUT,
-            self.tr('Input layer'), False))
+                                          self.tr('Input layer'), False))
         self.addParameter(ParameterBoolean(information.NOGCP,
-            self.tr('Suppress GCP info'), False))
+                                           self.tr('Suppress GCP info'), False))
         self.addParameter(ParameterBoolean(information.NOMETADATA,
-            self.tr('Suppress metadata info'), False))
+                                           self.tr('Suppress metadata info'), False))
         self.addOutput(OutputHTML(information.OUTPUT,
-            self.tr('Layer information')))
+                                  self.tr('Layer information')))
 
     def getConsoleCommands(self):
         arguments = []
