@@ -33,13 +33,14 @@ from processing.core.parameters import ParameterBoolean
 from processing.core.parameters import ParameterExtent
 from processing.core.parameters import ParameterTableField
 
-from processing.tools.system import isWindows
-
-from processing.algs.gdal.OgrAlgorithm import OgrAlgorithm
+from processing.algs.gdal.GdalAlgorithm import GdalAlgorithm
 from processing.algs.gdal.GdalUtils import GdalUtils
 
+from processing.tools.system import isWindows
+from processing.tools.vector import ogrConnectionString, ogrLayerName
 
-class Ogr2OgrToPostGis(OgrAlgorithm):
+
+class Ogr2OgrToPostGis(GdalAlgorithm):
 
     INPUT_LAYER = 'INPUT_LAYER'
     GTYPE = 'GTYPE'
@@ -83,11 +84,11 @@ class Ogr2OgrToPostGis(OgrAlgorithm):
         self.addParameter(ParameterSelection(self.GTYPE,
                                              self.tr('Output geometry type'), self.GEOMTYPE, 0))
         self.addParameter(ParameterCrs(self.A_SRS,
-                                       self.tr('Assign an output CRS'), ''))
+                                       self.tr('Assign an output CRS'), '', optional=True))
         self.addParameter(ParameterCrs(self.T_SRS,
-                                       self.tr('Reproject to this CRS on output '), ''))
+                                       self.tr('Reproject to this CRS on output '), '', optional=True))
         self.addParameter(ParameterCrs(self.S_SRS,
-                                       self.tr('Override source CRS'), ''))
+                                       self.tr('Override source CRS'), '', optional=True))
         self.addParameter(ParameterString(self.HOST,
                                           self.tr('Host'), 'localhost', optional=False))
         self.addParameter(ParameterString(self.PORT,
@@ -151,7 +152,7 @@ class Ogr2OgrToPostGis(OgrAlgorithm):
 
     def getConsoleCommands(self):
         inLayer = self.getParameterValue(self.INPUT_LAYER)
-        ogrLayer = self.ogrConnectionString(inLayer)[1:-1]
+        ogrLayer = ogrConnectionString(inLayer)[1:-1]
         ssrs = unicode(self.getParameterValue(self.S_SRS))
         tsrs = unicode(self.getParameterValue(self.T_SRS))
         asrs = unicode(self.getParameterValue(self.A_SRS))
@@ -206,7 +207,7 @@ class Ogr2OgrToPostGis(OgrAlgorithm):
         arguments.append('user=' + user + '"')
         arguments.append(dimstring)
         arguments.append(ogrLayer)
-        arguments.append(self.ogrLayerName(inLayer))
+        arguments.append(ogrLayerName(inLayer))
         if index:
             arguments.append(indexstring)
         if launder:
