@@ -36,13 +36,14 @@ from processing.core.parameters import ParameterBoolean
 from processing.core.parameters import ParameterExtent
 from processing.core.parameters import ParameterTableField
 
-from processing.tools.system import isWindows
-
-from processing.algs.gdal.OgrAlgorithm import OgrAlgorithm
+from processing.algs.gdal.GdalAlgorithm import GdalAlgorithm
 from processing.algs.gdal.GdalUtils import GdalUtils
 
+from processing.tools.system import isWindows
+from processing.tools.vector import ogrConnectionString, ogrLayerName
 
-class Ogr2OgrToPostGisList(OgrAlgorithm):
+
+class Ogr2OgrToPostGisList(GdalAlgorithm):
 
     DATABASE = 'DATABASE'
     INPUT_LAYER = 'INPUT_LAYER'
@@ -95,11 +96,11 @@ class Ogr2OgrToPostGisList(OgrAlgorithm):
         self.addParameter(ParameterSelection(self.GTYPE,
                                              self.tr('Output geometry type'), self.GEOMTYPE, 0))
         self.addParameter(ParameterCrs(self.A_SRS,
-                                       self.tr('Assign an output CRS'), ''))
+                                       self.tr('Assign an output CRS'), '', optional=True))
         self.addParameter(ParameterCrs(self.T_SRS,
-                                       self.tr('Reproject to this CRS on output '), ''))
+                                       self.tr('Reproject to this CRS on output '), '', optional=True))
         self.addParameter(ParameterCrs(self.S_SRS,
-                                       self.tr('Override source CRS'), ''))
+                                       self.tr('Override source CRS'), '', optional=True))
         self.addParameter(ParameterString(self.SCHEMA,
                                           self.tr('Schema name'), 'public', optional=True))
         self.addParameter(ParameterString(self.TABLE,
@@ -162,7 +163,7 @@ class Ogr2OgrToPostGisList(OgrAlgorithm):
         port = settings.value(mySettings + '/port')
         password = settings.value(mySettings + '/password')
         inLayer = self.getParameterValue(self.INPUT_LAYER)
-        ogrLayer = self.ogrConnectionString(inLayer)[1:-1]
+        ogrLayer = ogrConnectionString(inLayer)[1:-1]
         ssrs = unicode(self.getParameterValue(self.S_SRS))
         tsrs = unicode(self.getParameterValue(self.T_SRS))
         asrs = unicode(self.getParameterValue(self.A_SRS))
@@ -212,7 +213,7 @@ class Ogr2OgrToPostGisList(OgrAlgorithm):
         arguments.append('user=' + user + '"')
         arguments.append(dimstring)
         arguments.append(ogrLayer)
-        arguments.append(self.ogrLayerName(inLayer))
+        arguments.append(ogrLayerName(inLayer))
         if index:
             arguments.append(indexstring)
         if launder:
