@@ -44,12 +44,12 @@ class polygonize(GdalAlgorithm):
         return "gdalogr:polygonize"
 
     def defineCharacteristics(self):
-        self.name = 'Polygonize (raster to vector)'
-        self.group = '[GDAL] Conversion'
+        self.name, self.i18n_name = self.trAlgorithm('Polygonize (raster to vector)')
+        self.group, self.i18n_group = self.trAlgorithm('[GDAL] Conversion')
         self.addParameter(ParameterRaster(polygonize.INPUT,
-            self.tr('Input layer'), False))
+                                          self.tr('Input layer'), False))
         self.addParameter(ParameterString(polygonize.FIELD,
-            self.tr('Output field name'), 'DN'))
+                                          self.tr('Output field name'), 'DN'))
         self.addOutput(OutputVector(polygonize.OUTPUT, self.tr('Vectorized')))
 
     def getConsoleCommands(self):
