@@ -54,23 +54,23 @@ class proximity(GdalAlgorithm):
         return "gdalogr:proximity"
 
     def defineCharacteristics(self):
-        self.name = 'Proximity (raster distance)'
-        self.group = '[GDAL] Analysis'
+        self.name, self.i18n_name = self.trAlgorithm('Proximity (raster distance)')
+        self.group, self.i18n_group = self.trAlgorithm('[GDAL] Analysis')
         self.addParameter(ParameterRaster(self.INPUT,
-            self.tr('Input layer'), False))
+                                          self.tr('Input layer'), False))
         self.addParameter(ParameterString(self.VALUES,
-            self.tr('Values'), ''))
+                                          self.tr('Values'), ''))
         self.addParameter(ParameterSelection(self.UNITS,
-            self.tr('Distance units'), self.DISTUNITS, 0))
+                                             self.tr('Distance units'), self.DISTUNITS, 0))
         self.addParameter(ParameterNumber(self.MAX_DIST,
-            self.tr('Max distance (negative value to ignore)'), -1, 9999, -1))
+                                          self.tr('Max distance (negative value to ignore)'), -1, 9999, -1))
         self.addParameter(ParameterNumber(self.NODATA,
-            self.tr('Nodata (negative value to ignore)'), -1, 9999, -1))
+                                          self.tr('Nodata (negative value to ignore)'), -1, 9999, -1))
         self.addParameter(ParameterNumber(self.BUF_VAL,
-            self.tr('Fixed buf value (negative value to ignore)'),
-            -1, 9999, -1))
+                                          self.tr('Fixed buf value (negative value to ignore)'),
+                                          -1, 9999, -1))
         self.addParameter(ParameterSelection(self.RTYPE,
-            self.tr('Output raster type'), self.TYPE, 5))
+                                             self.tr('Output raster type'), self.TYPE, 5))
         self.addOutput(OutputRaster(self.OUTPUT, self.tr('Distance')))
 
     def getConsoleCommands(self):
@@ -93,17 +93,17 @@ class proximity(GdalAlgorithm):
             arguments.append('-values')
             arguments.append(values)
 
-        values = str(self.getParameterValue(self.MAX_DIST))
+        values = unicode(self.getParameterValue(self.MAX_DIST))
         if values < 0:
             arguments.append('-maxdist')
             arguments.append(values)
 
-        values = str(self.getParameterValue(self.NODATA))
+        values = unicode(self.getParameterValue(self.NODATA))
         if values < 0:
             arguments.append('-nodata')
             arguments.append(values)
 
-        values = str(self.getParameterValue(self.BUF_VAL))
+        values = unicode(self.getParameterValue(self.BUF_VAL))
         if values < 0:
             arguments.append('-fixed-buf-val')
             arguments.append(values)
