@@ -48,13 +48,13 @@ class sieve(GdalAlgorithm):
     PIXEL_CONNECTIONS = ['4', '8']
 
     def defineCharacteristics(self):
-        self.name = 'Sieve'
-        self.group = '[GDAL] Analysis'
+        self.name, self.i18n_name = self.trAlgorithm('Sieve')
+        self.group, self.i18n_group = self.trAlgorithm('[GDAL] Analysis')
         self.addParameter(ParameterRaster(self.INPUT, self.tr('Input layer'), False))
         self.addParameter(ParameterNumber(self.THRESHOLD,
-            self.tr('Threshold'), 0, 9999, 2))
+                                          self.tr('Threshold'), 0, 9999, 2))
         self.addParameter(ParameterSelection(self.CONNECTIONS,
-            self.tr('Pixel connection'), self.PIXEL_CONNECTIONS, 0))
+                                             self.tr('Pixel connection'), self.PIXEL_CONNECTIONS, 0))
 
         self.addOutput(OutputRaster(self.OUTPUT, self.tr('Sieved')))
 
@@ -63,11 +63,11 @@ class sieve(GdalAlgorithm):
 
         arguments = []
         arguments.append('-st')
-        arguments.append(str(self.getParameterValue(self.THRESHOLD)))
+        arguments.append(unicode(self.getParameterValue(self.THRESHOLD)))
 
         arguments.append('-' +
-            self.PIXEL_CONNECTIONS[self.getParameterValue(
-                self.CONNECTIONS)])
+                         self.PIXEL_CONNECTIONS[self.getParameterValue(
+                                                self.CONNECTIONS)])
 
         arguments.append('-of')
         arguments.append(GdalUtils.getFormatShortNameFromFilename(output))
