@@ -68,8 +68,7 @@ class translate(GdalAlgorithm):
     def defineCharacteristics(self):
         self.name, self.i18n_name = self.trAlgorithm('Translate (convert format)')
         self.group, self.i18n_group = self.trAlgorithm('[GDAL] Conversion')
-        self.addParameter(ParameterRaster(self.INPUT, self.tr('Input layer'),
-                          False))
+        self.addParameter(ParameterRaster(self.INPUT, self.tr('Input layer'), False))
         self.addParameter(ParameterNumber(self.OUTSIZE,
                                           self.tr('Set the size of the output file (In pixels or %)'),
                                           1, None, 100))
@@ -77,50 +76,61 @@ class translate(GdalAlgorithm):
                                            self.tr('Output size is a percentage of input size'), True))
         self.addParameter(ParameterString(self.NO_DATA,
                                           self.tr("Nodata value, leave blank to take the nodata value from input"),
-                                          ''))
+                                          '', optional=True))
         self.addParameter(ParameterSelection(self.EXPAND,
                                              self.tr('Expand'), ['none', 'gray', 'rgb', 'rgba']))
         self.addParameter(ParameterCrs(self.SRS,
-                                       self.tr('Output projection for output file [leave blank to use input projection]'), None))
+                                       self.tr('Output projection for output file [leave blank to use input projection]'), None, optional=True))
         self.addParameter(ParameterExtent(self.PROJWIN,
                                           self.tr('Subset based on georeferenced coordinates')))
         self.addParameter(ParameterBoolean(self.SDS,
                                            self.tr('Copy all subdatasets of this file to individual output files'),
                                            False))
-        self.addParameter(ParameterSelection(self.RTYPE,
-                                             self.tr('Output raster type'), self.TYPE, 5))
-        self.addParameter(ParameterSelection(self.COMPRESS,
-                                             self.tr('GeoTIFF options. Compression type:'), self.COMPRESSTYPE, 4))
-        self.addParameter(ParameterNumber(self.JPEGCOMPRESSION,
-                                          self.tr('Set the JPEG compression level'),
-                                          1, 100, 75))
-        self.addParameter(ParameterNumber(self.ZLEVEL,
-                                          self.tr('Set the DEFLATE compression level'),
-                                          1, 9, 6))
-        self.addParameter(ParameterNumber(self.PREDICTOR,
-                                          self.tr('Set the predictor for LZW or DEFLATE compression'),
-                                          1, 3, 1))
-        self.addParameter(ParameterBoolean(self.TILED,
-                                           self.tr('Create tiled output (only used for the GTiff format)'), False))
-        self.addParameter(ParameterSelection(self.BIGTIFF,
-                                             self.tr('Control whether the created file is a BigTIFF or a classic TIFF'), self.BIGTIFFTYPE, 0))
-        self.addParameter(ParameterBoolean(self.TFW,
-                                           self.tr('Force the generation of an associated ESRI world file (.tfw))'), False))
-        self.addParameter(ParameterString(self.EXTRA,
-                                          self.tr('Additional creation parameters'), '', optional=True))
+
+        params = []
+        params.append(ParameterSelection(self.RTYPE,
+                                         self.tr('Output raster type'), self.TYPE, 5))
+        params.append(ParameterSelection(self.COMPRESS,
+                                         self.tr('GeoTIFF options. Compression type:'), self.COMPRESSTYPE, 4))
+        params.append(ParameterNumber(self.JPEGCOMPRESSION,
+                                      self.tr('Set the JPEG compression level'),
+                                      1, 100, 75))
+        params.append(ParameterNumber(self.ZLEVEL,
+                                      self.tr('Set the DEFLATE compression level'),
+                                      1, 9, 6))
+        params.append(ParameterNumber(self.PREDICTOR,
+                                      self.tr('Set the predictor for LZW or DEFLATE compression'),
+                                      1, 3, 1))
+        params.append(ParameterBoolean(self.TILED,
+                                       self.tr('Create tiled output (only used for the GTiff format)'), False))
+        params.append(ParameterSelection(self.BIGTIFF,
+                                         self.tr('Control whether the created file is a BigTIFF or a classic TIFF'), self.BIGTIFFTYPE, 0))
+        params.append(ParameterBoolean(self.TFW,
+                                       self.tr('Force the generation of an associated ESRI world file (.tfw))'), False))
+        params.append(ParameterString(self.EXTRA,
+                                      self.tr('Additional creation parameters'), '', optional=True))
+
+        for param in params:
+            param.isAdvanced = True
+            self.addParameter(param)
+
         self.addOutput(OutputRaster(self.OUTPUT, self.tr('Converted')))
 
     def getConsoleCommands(self):
         out = self.getOutputValue(translate.OUTPUT)
         outsize = unicode(self.getParameterValue(self.OUTSIZE))
         outsizePerc = unicode(self.getParameterValue(self.OUTSIZE_PERC))
-        noData = unicode(self.getParameterValue(self.NO_DATA))
+        noData = self.getParameterValue(self.NO_DATA)
+        if noData is not None:
+            noData = unicode(noData)
         expand = unicode(self.getParameterFromName(
             self.EXPAND).options[self.getParameterValue(self.EXPAND)])
         projwin = unicode(self.getParameterValue(self.PROJWIN))
         crsId = self.getParameterValue(self.SRS)
         sds = self.getParameterValue(self.SDS)
-        extra = unicode(self.getParameterValue(self.EXTRA))
+        extra = self.getParameterValue(self.EXTRA)
+        if extra is not None:
+            extra = unicode(extra)
         jpegcompression = unicode(self.getParameterValue(self.JPEGCOMPRESSION))
         predictor = unicode(self.getParameterValue(self.PREDICTOR))
         zlevel = unicode(self.getParameterValue(self.ZLEVEL))
@@ -142,24 +152,30 @@ class translate(GdalAlgorithm):
             arguments.append('-outsize')
             arguments.append(outsize)
             arguments.append(outsize)
-        if len(noData) > 0:
+        if noData and len(noData) > 0:
             arguments.append('-a_nodata')
             arguments.append(noData)
         if expand != 'none':
             arguments.append('-expand')
             arguments.append(expand)
         regionCoords = projwin.split(',')
-        arguments.append('-projwin')
-        arguments.append(regionCoords[0])
-        arguments.append(regionCoords[3])
-        arguments.append(regionCoords[1])
-        arguments.append(regionCoords[2])
+        try:
+            projwin = []
+            projwin.append('-projwin')
+            projwin.append(regionCoords[0])
+            projwin.append(regionCoords[3])
+            projwin.append(regionCoords[1])
+            projwin.append(regionCoords[2])
+        except IndexError:
+            projwin = []
+        if projwin:
+            arguments.extend(projwin)
         if crsId:
             arguments.append('-a_srs')
             arguments.append(unicode(crsId))
         if sds:
             arguments.append('-sds')
-        if len(extra) > 0:
+        if extra and len(extra) > 0:
             arguments.append(extra)
         if GdalUtils.getFormatShortNameFromFilename(out) == "GTiff":
             arguments.append("-co COMPRESS=" + compress)
@@ -175,6 +191,7 @@ class translate(GdalAlgorithm):
                 arguments.append("-co TFW=YES")
             if len(bigtiff) > 0:
                 arguments.append("-co BIGTIFF=" + bigtiff)
+
         arguments.append(self.getParameterValue(self.INPUT))
         arguments.append(out)
 
