@@ -66,6 +66,7 @@ class GrassAlgorithm(GeoAlgorithm):
 
     def __init__(self, descriptionfile):
         GeoAlgorithm.__init__(self)
+        self.hardcodedStrings = []
         self.descriptionFile = descriptionfile
         self.defineCharacteristicsFromFile()
         self.numExportedLayers = 0
@@ -76,7 +77,7 @@ class GrassAlgorithm(GeoAlgorithm):
         return newone
 
     def getIcon(self):
-        return QIcon(os.path.join(pluginPath, 'images', 'grass.png'))
+        return QIcon(os.path.join(pluginPath, 'images', 'grass.svg'))
 
     def help(self):
         return False, 'http://grass.osgeo.org/grass64/manuals/' + self.grassName + '.html'
@@ -121,7 +122,9 @@ class GrassAlgorithm(GeoAlgorithm):
         while line != '':
             try:
                 line = line.strip('\n').strip()
-                if line.startswith('Parameter'):
+                if line.startswith('Hardcoded'):
+                    self.hardcodedStrings.append(line[len('Hardcoded|'):])
+                elif line.startswith('Parameter'):
                     parameter = getParameterFromString(line)
                     self.addParameter(parameter)
                     if isinstance(parameter, ParameterVector):
@@ -187,7 +190,7 @@ class GrassAlgorithm(GeoAlgorithm):
                     else:
                         layer = dataobjects.getObjectFromUri(param.value)
                     cellsize = max(cellsize, (layer.extent().xMaximum()
-                                   - layer.extent().xMinimum())
+                                              - layer.extent().xMinimum())
                                    / layer.width())
                 elif isinstance(param, ParameterMultipleInput):
 
@@ -265,7 +268,10 @@ class GrassAlgorithm(GeoAlgorithm):
                         else:
                             self.setSessionProjectionFromLayer(layer, commands)
                             commands.append(self.exportRasterLayer(layer))
-                elif param.datatype == ParameterMultipleInput.TYPE_VECTOR_ANY:
+                elif param.datatype in [ParameterMultipleInput.TYPE_VECTOR_ANY,
+                                        ParameterMultipleInput.TYPE_VECTOR_LINE,
+                                        ParameterMultipleInput.TYPE_VECTOR_POLYGON,
+                                        ParameterMultipleInput.TYPE_VECTOR_POINT]:
                     for layer in layers:
                         if layer in self.exportedLayers.keys():
                             continue
@@ -297,6 +303,8 @@ class GrassAlgorithm(GeoAlgorithm):
         # 2: Set parameters and outputs
 
         command = self.grassName
+        command += ' ' + ' '.join(self.hardcodedStrings)
+
         for param in self.parameters:
             if param.value is None or param.value == '':
                 continue
@@ -448,7 +456,7 @@ class GrassAlgorithm(GeoAlgorithm):
 
     def setSessionProjectionFromProject(self, commands):
         if not GrassUtils.projectionSet:
-            proj4 = iface.mapCanvas().mapRenderer().destinationCrs().toProj4()
+            proj4 = iface.mapCanvas().mapSettings().destinationCrs().toProj4()
             command = 'g.proj'
             command += ' -c'
             command += ' proj4="' + proj4 + '"'
@@ -488,9 +496,7 @@ class GrassAlgorithm(GeoAlgorithm):
         return 'grass:' + self.name[:self.name.find(' ')]
 
     def checkBeforeOpeningParametersDialog(self):
-        msg = GrassUtils.checkGrassIsInstalled()
-        if msg is not None:
-            return msg
+        return GrassUtils.checkGrassIsInstalled()
 
     def checkParameterValuesBeforeExecuting(self):
         name = self.commandLineName().replace('.', '_')[len('grass:'):]
