@@ -43,7 +43,6 @@ class Grass7AlgorithmProvider(AlgorithmProvider):
 
     def __init__(self):
         AlgorithmProvider.__init__(self)
-        self.activate = False
         self.createAlgsList()
 
     def initializeSettings(self):
@@ -53,10 +52,6 @@ class Grass7AlgorithmProvider(AlgorithmProvider):
                 self.getDescription(),
                 Grass7Utils.GRASS_FOLDER, self.tr('GRASS7 folder'),
                 Grass7Utils.grassPath(), valuetype=Setting.FOLDER))
-            ProcessingConfig.addSetting(Setting(
-                self.getDescription(),
-                Grass7Utils.GRASS_WIN_SHELL, self.tr('Msys folder'),
-                Grass7Utils.grassWinShell(), valuetype=Setting.FOLDER))
         ProcessingConfig.addSetting(Setting(
             self.getDescription(),
             Grass7Utils.GRASS_LOG_COMMANDS,
@@ -70,7 +65,6 @@ class Grass7AlgorithmProvider(AlgorithmProvider):
         AlgorithmProvider.unload(self)
         if isWindows() or isMac():
             ProcessingConfig.removeSetting(Grass7Utils.GRASS_FOLDER)
-            ProcessingConfig.removeSetting(Grass7Utils.GRASS_WIN_SHELL)
         ProcessingConfig.removeSetting(Grass7Utils.GRASS_LOG_COMMANDS)
         ProcessingConfig.removeSetting(Grass7Utils.GRASS_LOG_CONSOLE)
 
@@ -103,10 +97,13 @@ class Grass7AlgorithmProvider(AlgorithmProvider):
         return 'grass70'
 
     def getIcon(self):
-        return QIcon(os.path.join(pluginPath, 'images', 'grass.png'))
+        return QIcon(os.path.join(pluginPath, 'images', 'grass.svg'))
 
     def getSupportedOutputVectorLayerExtensions(self):
         return ['shp']
 
     def getSupportedOutputRasterLayerExtensions(self):
         return ['tif']
+
+    def canBeActivated(self):
+        return not bool(Grass7Utils.checkGrass7IsInstalled())
