@@ -45,7 +45,6 @@ class Grass7Utils:
     GRASS_REGION_YMAX = 'GRASS7_REGION_YMAX'
     GRASS_REGION_CELLSIZE = 'GRASS7_REGION_CELLSIZE'
     GRASS_FOLDER = 'GRASS7_FOLDER'
-    GRASS_WIN_SHELL = 'GRASS7_WIN_SHELL'
     GRASS_LOG_COMMANDS = 'GRASS7_LOG_COMMANDS'
     GRASS_LOG_CONSOLE = 'GRASS7_LOG_CONSOLE'
 
@@ -84,14 +83,16 @@ class Grass7Utils:
         if not isWindows() and not isMac():
             return ''
 
-        folder = ProcessingConfig.getSetting(Grass7Utils.GRASS_FOLDER)
+        folder = ProcessingConfig.getSetting(Grass7Utils.GRASS_FOLDER) or ''
+        if not os.path.exists(folder):
+            folder = None
         if folder is None:
             if isWindows():
                 testfolder = os.path.dirname(unicode(QgsApplication.prefixPath()))
-                testfolder = os.path.join(testfolder, 'grass7')
+                testfolder = os.path.join(testfolder, 'grass')
                 if os.path.isdir(testfolder):
                     for subfolder in os.listdir(testfolder):
-                        if subfolder.startswith('grass7'):
+                        if subfolder.startswith('grass-7'):
                             folder = os.path.join(testfolder, subfolder)
                             break
             else:
@@ -101,14 +102,6 @@ class Grass7Utils:
 
         return folder
 
-    @staticmethod
-    def grassWinShell():
-        folder = ProcessingConfig.getSetting(Grass7Utils.GRASS_WIN_SHELL)
-        if folder is None:
-            folder = os.path.dirname(unicode(QgsApplication.prefixPath()))
-            folder = os.path.join(folder, 'msys')
-        return folder
-
     @staticmethod
     def grassDescriptionPath():
         return os.path.join(os.path.dirname(__file__), 'description')
@@ -116,7 +109,6 @@ class Grass7Utils:
     @staticmethod
     def createGrass7Script(commands):
         folder = Grass7Utils.grassPath()
-        shell = Grass7Utils.grassWinShell()
 
         script = Grass7Utils.grassScriptFilename()
         gisrc = userFolder() + os.sep + 'processing.gisrc7'  # FIXME: use temporary file
@@ -135,9 +127,6 @@ class Grass7Utils:
         output = open(script, 'w')
         output.write('set HOME=' + os.path.expanduser('~') + '\n')
         output.write('set GISRC=' + gisrc + '\n')
-        output.write('set GRASS_SH=' + shell + '\\bin\\sh.exe\n')
-        output.write('set PATH=' + shell + os.sep + 'bin;' + shell + os.sep
-                     + 'lib;' + '%PATH%\n')
         output.write('set WINGISBASE=' + folder + '\n')
         output.write('set GISBASE=' + folder + '\n')
         output.write('set GRASS_PROJSHARE=' + folder + os.sep + 'share'
@@ -363,10 +352,10 @@ class Grass7Utils:
             cmdpath = os.path.join(path, 'bin', 'r.out.gdal.exe')
             if not os.path.exists(cmdpath):
                 return Grass7Utils.tr(
-                    'The specified GRASS GIS 7 folder does not contain a valid '
-                    'set of GRASS GIS 7 modules.\nPlease, go to the Processing '
-                    'settings dialog, and check that the GRASS GIS 7\n'
-                    'folder is correctly configured')
+                    'The specified GRASS 7 folder "{}" does not contain '
+                    'a valid set of GRASS 7 modules.\nPlease, go to the '
+                    'Processing settings dialog, and check that the '
+                    'GRASS 7\nfolder is correctly configured'.format(os.path.join(path, 'bin')))
 
         if not ignorePreviousState:
             if Grass7Utils.isGrass7Installed:
