@@ -51,7 +51,7 @@ class CloudMetrics(FusionAlgorithm):
         self.addParameter(ParameterFile(
             self.INPUT, self.tr('Input LAS layer')))
         self.addOutput(OutputFile(
-            self.OUTPUT, self.tr('Output file with tabular metric information'), 'dtm'))
+            self.OUTPUT, self.tr('Output file with tabular metric information'), 'csv'))
         above = ParameterString(self.ABOVE, self.tr('Above'), '', False)
         above.isAdvanced = True
         self.addParameter(above)
@@ -75,10 +75,10 @@ class CloudMetrics(FusionAlgorithm):
             commands.append('/above:' + unicode(above))
         firstImpulse = self.getParameterValue(self.FIRSTIMPULSE)
         if firstImpulse:
-            commands.append('/firstinpulse:' + firstImpulse)
+            commands.append('/firstinpulse')
         firstReturn = self.getParameterValue(self.FIRSTRETURN)
         if firstReturn:
-            commands.append('/firstreturn:' + firstReturn)
+            commands.append('/firstreturn')
         htmin = self.getParameterValue(self.HTMIN)
         if unicode(htmin).strip() != '':
             commands.append('/minht:' + unicode(htmin))
