@@ -59,16 +59,17 @@ class ConcaveHull(GeoAlgorithm):
         self.addOutput(OutputVector(ConcaveHull.OUTPUT, self.tr('Concave hull')))
 
     def processAlgorithm(self, progress):
-        #get parameters
         layer = dataobjects.getObjectFromUri(self.getParameterValue(ConcaveHull.INPUT))
         alpha = self.getParameterValue(self.ALPHA)
         holes = self.getParameterValue(self.HOLES)
         no_multigeom = self.getParameterValue(self.NO_MULTIGEOMETRY)
-        #Delaunay triangulation from input point layer
+
+        # Delaunay triangulation from input point layer
         progress.setText(self.tr('Creating Delaunay triangles...'))
-        delone_triangles = processing.runalg("qgis:delaunaytriangulation", layer, None)['OUTPUT']
+        delone_triangles = processing.runalg("qgis:delaunaytriangulation", layer, None, progress=None)['OUTPUT']
         delaunay_layer = processing.getObject(delone_triangles)
-        #get max edge length from Delaunay triangles
+
+        # Get max edge length from Delaunay triangles
         progress.setText(self.tr('Computing edges max length...'))
         features = delaunay_layer.getFeatures()
         counter = 50. / delaunay_layer.featureCount()
@@ -81,7 +82,8 @@ class ConcaveHull(GeoAlgorithm):
             edges[feat.id()] = max(lengths[-3:])
             progress.setPercentage(feat.id() * counter)
         max_length = max(lengths)
-        #get features with longest edge longer than alpha*max_length
+
+        # Get features with longest edge longer than alpha*max_length
         progress.setText(self.tr('Removing features...'))
         counter = 50. / len(edges)
         i = 0
@@ -91,17 +93,20 @@ class ConcaveHull(GeoAlgorithm):
                 ids.append(id)
             progress.setPercentage(50 + i * counter)
             i += 1
-        #remove features
+
+        # Remove features
         delaunay_layer.setSelectedFeatures(ids)
         delaunay_layer.startEditing()
         delaunay_layer.deleteSelectedFeatures()
         delaunay_layer.commitChanges()
-        #dissolve all Delaunay triangles
+
+        # Dissolve all Delaunay triangles
         progress.setText(self.tr('Dissolving Delaunay triangles...'))
         dissolved = processing.runalg("qgis:dissolve", delaunay_layer,
-                                      True, '', None)['OUTPUT']
+                                      True, None, None, progress=None)['OUTPUT']
         dissolved_layer = processing.getObject(dissolved)
-        #save result
+
+        # Save result
         progress.setText(self.tr('Saving data...'))
         feat = QgsFeature()
         dissolved_layer.getFeatures(QgsFeatureRequest().setFilterFid(0)).nextFeature(feat)
@@ -109,22 +114,22 @@ class ConcaveHull(GeoAlgorithm):
             layer.pendingFields().toList(), QGis.WKBPolygon, layer.crs())
         geom = feat.geometry()
         if no_multigeom and geom.isMultipart():
-            #only singlepart geometries are allowed
+            # Only singlepart geometries are allowed
             geom_list = geom.asMultiPolygon()
             for single_geom_list in geom_list:
                 single_feature = QgsFeature()
                 single_geom = QgsGeometry.fromPolygon(single_geom_list)
                 if not holes:
-                    #delete holes
+                    # Delete holes
                     deleted = True
                     while deleted:
                         deleted = single_geom.deleteRing(1)
                 single_feature.setGeometry(single_geom)
                 writer.addFeature(single_feature)
         else:
-            #multipart geometries are allowed
+            # Multipart geometries are allowed
             if not holes:
-                #delete holes
+                # Delete holes
                 deleted = True
                 while deleted:
                     deleted = geom.deleteRing(1)
