@@ -47,77 +47,6 @@ class Dissolve(GeoAlgorithm):
     #   return QtGui.QIcon(os.path.dirname(__file__) + "/icons/dissolve.png")
     #==========================================================================
 
-    def processAlgorithm(self, progress):
-        useField = not self.getParameterValue(Dissolve.DISSOLVE_ALL)
-        fieldname = self.getParameterValue(Dissolve.FIELD)
-        vlayerA = dataobjects.getObjectFromUri(
-            self.getParameterValue(Dissolve.INPUT))
-        field = vlayerA.fieldNameIndex(fieldname)
-        vproviderA = vlayerA.dataProvider()
-        fields = vproviderA.fields()
-        writer = self.getOutputFromName(
-            Dissolve.OUTPUT).getVectorWriter(fields,
-                                             vproviderA.geometryType(),
-                                             vproviderA.crs())
-        outFeat = QgsFeature()
-        nElement = 0
-        nFeat = vproviderA.featureCount()
-        if not useField:
-            first = True
-            features = vector.features(vlayerA)
-            for inFeat in features:
-                nElement += 1
-                progress.setPercentage(int(nElement / nFeat * 100))
-                if first:
-                    attrs = inFeat.attributes()
-                    tmpInGeom = QgsGeometry(inFeat.geometry())
-                    outFeat.setGeometry(tmpInGeom)
-                    first = False
-                else:
-                    tmpInGeom = QgsGeometry(inFeat.geometry())
-                    tmpOutGeom = QgsGeometry(outFeat.geometry())
-                    try:
-                        tmpOutGeom = QgsGeometry(tmpOutGeom.combine(tmpInGeom))
-                        outFeat.setGeometry(tmpOutGeom)
-                    except:
-                        raise GeoAlgorithmExecutionException(
-                            self.tr('Geometry exception while dissolving'))
-            outFeat.setAttributes(attrs)
-            writer.addFeature(outFeat)
-        else:
-            unique = vector.getUniqueValues(vlayerA, int(field))
-            nFeat = nFeat * len(unique)
-            for item in unique:
-                first = True
-                add = True
-                features = vector.features(vlayerA)
-                for inFeat in features:
-                    nElement += 1
-                    progress.setPercentage(int(nElement / nFeat * 100))
-                    atMap = inFeat.attributes()
-                    tempItem = atMap[field]
-                    if unicode(tempItem).strip() == unicode(item).strip():
-                        if first:
-                            QgsGeometry(inFeat.geometry())
-                            tmpInGeom = QgsGeometry(inFeat.geometry())
-                            outFeat.setGeometry(tmpInGeom)
-                            first = False
-                            attrs = inFeat.attributes()
-                        else:
-                            tmpInGeom = QgsGeometry(inFeat.geometry())
-                            tmpOutGeom = QgsGeometry(outFeat.geometry())
-                            try:
-                                tmpOutGeom = QgsGeometry(
-                                    tmpOutGeom.combine(tmpInGeom))
-                                outFeat.setGeometry(tmpOutGeom)
-                            except:
-                                raise GeoAlgorithmExecutionException(
-                                    self.tr('Geometry exception while dissolving'))
-                if add:
-                    outFeat.setAttributes(attrs)
-                    writer.addFeature(outFeat)
-        del writer
-
     def defineCharacteristics(self):
         self.name = 'Dissolve'
         self.group = 'Vector geometry tools'
@@ -129,3 +58,83 @@ class Dissolve(GeoAlgorithm):
         self.addParameter(ParameterTableField(Dissolve.FIELD,
                                               self.tr('Unique ID field'), Dissolve.INPUT, optional=True))
         self.addOutput(OutputVector(Dissolve.OUTPUT, self.tr('Dissolved')))
+
+    def processAlgorithm(self, progress):
+        useField = not self.getParameterValue(Dissolve.DISSOLVE_ALL)
+        fieldname = self.getParameterValue(Dissolve.FIELD)
+        vlayerA = dataobjects.getObjectFromUri(
+            self.getParameterValue(Dissolve.INPUT))
+        vproviderA = vlayerA.dataProvider()
+        fields = vlayerA.fields()
+        writer = self.getOutputFromName(
+            Dissolve.OUTPUT).getVectorWriter(fields,
+                                             vproviderA.geometryType(),
+                                             vproviderA.crs())
+        outFeat = QgsFeature()
+        features = vector.features(vlayerA)
+        total = 100.0 / len(features)
+
+        if not useField:
+            first = True
+            for current, inFeat in enumerate(features):
+                progress.setPercentage(int(current * total))
+                if first:
+                    attrs = inFeat.attributes()
+                    tmpInGeom = QgsGeometry(inFeat.geometry())
+                    if tmpInGeom.isGeosEmpty() or not tmpInGeom.isGeosValid():
+                        continue
+                    outFeat.setGeometry(tmpInGeom)
+                    first = False
+                else:
+                    tmpInGeom = QgsGeometry(inFeat.geometry())
+                    if tmpInGeom.isGeosEmpty() or not tmpInGeom.isGeosValid():
+                        continue
+                    tmpOutGeom = QgsGeometry(outFeat.geometry())
+                    try:
+                        tmpOutGeom = QgsGeometry(tmpOutGeom.combine(tmpInGeom))
+                        outFeat.setGeometry(tmpOutGeom)
+                    except:
+                        raise GeoAlgorithmExecutionException(
+                            self.tr('Geometry exception while dissolving'))
+            outFeat.setAttributes(attrs)
+            writer.addFeature(outFeat)
+        else:
+            fieldIdx = vlayerA.fieldNameIndex(fieldname)
+            unique = vector.getUniqueValues(vlayerA, int(fieldIdx))
+            nFeat = len(unique)
+            myDict = {}
+            attrDict = {}
+            for item in unique:
+                myDict[unicode(item).strip()] = []
+                attrDict[unicode(item).strip()] = None
+
+            unique = None
+
+            for inFeat in features:
+                attrs = inFeat.attributes()
+                tempItem = attrs[fieldIdx]
+                tmpInGeom = QgsGeometry(inFeat.geometry())
+                if tmpInGeom.isGeosEmpty() or not tmpInGeom.isGeosValid():
+                    continue
+
+                if attrDict[unicode(tempItem).strip()] == None:
+                    # keep attributes of first feature
+                    attrDict[unicode(tempItem).strip()] = attrs
+
+                myDict[unicode(tempItem).strip()].append(tmpInGeom)
+
+            features = None
+
+            for key, value in myDict.items():
+                nElement += 1
+                progress.setPercentage(int(nElement * 100 / nFeat))
+                try:
+                    tmpOutGeom = QgsGeometry.unaryUnion(value)
+                except:
+                    raise GeoAlgorithmExecutionException(
+                        self.tr('Geometry exception while dissolving'))
+                outFeat.setGeometry(tmpOutGeom)
+                outFeat.setAttributes(attrDict[key])
+                writer.addFeature(outFeat)
+
+        del writer
