@@ -54,11 +54,9 @@ class LinesToPolygons(GeoAlgorithm):
         )
 
         outFeat = QgsFeature()
-
-        current = 0
         features = vector.features(layer)
-        total = 100.0 / float(len(features))
-        for f in features:
+        total = 100.0 / len(features)
+        for current, f in enumerate(features):
             outGeomList = []
             if f.geometry().isMultipart():
                 outGeomList = f.geometry().asMultiPolyline()
@@ -72,7 +70,6 @@ class LinesToPolygons(GeoAlgorithm):
                 outFeat.setAttributes(attrs)
                 writer.addFeature(outFeat)
 
-            current += 1
             progress.setPercentage(int(current * total))
 
         del writer
