@@ -28,7 +28,8 @@ __revision__ = '$Format:%H$'
 import random
 
 from PyQt4.QtCore import QVariant
-from qgis.core import QGis, QgsGeometry, QgsFields, QgsField, QgsSpatialIndex, QgsPoint, QgsFeature, QgsFeatureRequest
+from qgis.core import (QGis, QgsGeometry, QgsFields, QgsField, QgsSpatialIndex,
+                       QgsPoint, QgsFeature, QgsFeatureRequest)
 
 from processing.core.GeoAlgorithm import GeoAlgorithm
 from processing.core.ProcessingLog import ProcessingLog
