@@ -26,7 +26,7 @@ __copyright__ = '(C) 2010, Michael Minn'
 __revision__ = '$Format:%H$'
 
 from PyQt4.QtCore import QVariant
-from qgis.core import QgsExpression
+from qgis.core import QgsExpression, QgsFeatureRequest
 from processing.core.GeoAlgorithm import GeoAlgorithm
 from processing.core.GeoAlgorithmExecutionException import GeoAlgorithmExecutionException
 from processing.core.parameters import ParameterVector
@@ -95,38 +95,26 @@ class SelectByAttribute(GeoAlgorithm):
                 self.tr('Operators %s can be used only with string fields.' % op))
 
         if fieldType in [QVariant.Int, QVariant.Double]:
-            progress.setInfo(self.tr('Numeric field'))
             expr = '"%s" %s %s' % (fieldName, operator, value)
-            progress.setInfo(expr)
         elif fieldType == QVariant.String:
-            progress.setInfo(self.tr('String field'))
             if operator not in self.OPERATORS[-2:]:
                 expr = """"%s" %s '%s'""" % (fieldName, operator, value)
             elif operator == 'begins with':
                 expr = """"%s" LIKE '%s%%'""" % (fieldName, value)
             elif operator == 'contains':
                 expr = """"%s" LIKE '%%%s%%'""" % (fieldName, value)
-            progress.setInfo(expr)
         elif fieldType in [QVariant.Date, QVariant.DateTime]:
-            progress.setInfo(self.tr('Date field'))
             expr = """"%s" %s '%s'""" % (fieldName, operator, value)
-            progress.setInfo(expr)
         else:
             raise GeoAlgorithmExecutionException(
                 self.tr('Unsupported field type "%s"' % fields[idx].typeName()))
 
-        expression = QgsExpression(expr)
-        expression.prepare(fields)
-
-        features = vector.features(layer)
-
-        selected = []
-        count = len(features)
-        total = 100.0 / float(count)
-        for count, f in enumerate(features):
-            if expression.evaluate(f, fields):
-                selected.append(f.id())
-            progress.setPercentage(int(count * total))
+        qExp = QgsExpression(expr)
+        if not qExp.hasParserError():
+            qReq = QgsFeatureRequest(qExp)
+        else:
+            raise GeoAlgorithmExecutionException(qExp.parserErrorString())
+        selected = [f.id() for f in layer.getFeatures(qReq)]
 
         layer.setSelectedFeatures(selected)
         self.setOutputValue(self.OUTPUT, fileName)
