@@ -36,20 +36,20 @@ from processing.core.outputs import OutputRaster
 from processing.tools import dataobjects
 from qgis.utils import iface
 
+
 class SetRasterStyle(GeoAlgorithm):
 
     INPUT = 'INPUT'
     STYLE = 'STYLE'
     OUTPUT = 'OUTPUT'
 
-
     def defineCharacteristics(self):
-        self.name = 'Set style for raster layer'
-        self.group = 'Raster general tools'
+        self.name, self.i18n_name = self.trAlgorithm('Set style for raster layer')
+        self.group, self.i18n_group = self.trAlgorithm('Raster general tools')
         self.addParameter(ParameterRaster(self.INPUT,
-            self.tr('Raster layer')))
+                                          self.tr('Raster layer')))
         self.addParameter(ParameterFile(self.STYLE,
-            self.tr('Style file'), False, False, 'qml'))
+                                        self.tr('Style file'), False, False, 'qml'))
         self.addOutput(OutputRaster(self.OUTPUT, self.tr('Styled'), True))
 
     def processAlgorithm(self, progress):
