@@ -62,17 +62,11 @@ class SplitLinesWithLines(GeoAlgorithm):
 
         spatialIndex = vector.spatialindex(layerB)
 
-        inFeatA = QgsFeature()
-        inFeatB = QgsFeature()
         outFeat = QgsFeature()
-        inGeom = QgsGeometry()
-        splitGeom = QgsGeometry()
-
         features = vector.features(layerA)
-        current = 0
         total = 100.0 / float(len(features))
 
-        for inFeatA in features:
+        for current, inFeatA in enumerate(features):
             inGeom = inFeatA.geometry()
             attrsA = inFeatA.attributes()
             outFeat.setAttributes(attrsA)
@@ -109,7 +103,7 @@ class SplitLinesWithLines(GeoAlgorithm):
 
                                 # splitGeometry: If there are several intersections
                                 # between geometry and splitLine, only the first one is considered.
-                                if result == 0:  # split occured
+                                if result == 0:  # split occurred
 
                                     if inPoints == vector.extractPoints(inGeom):
                                         # bug in splitGeometry: sometimes it returns 0 but
@@ -131,7 +125,6 @@ class SplitLinesWithLines(GeoAlgorithm):
                 outFeat.setGeometry(aLine)
                 writer.addFeature(outFeat)
 
-            current += 1
             progress.setPercentage(int(current * total))
 
         del writer
