@@ -25,7 +25,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 __revision__ = '$Format:%H$'
 
-from qgis.core import QgsFeatureRequest, QgsFeature, QgsGeometry, QgsWKBTypes
+from qgis.core import QGis, QgsFeatureRequest, QgsFeature, QgsGeometry, QgsWKBTypes
 from processing.core.GeoAlgorithm import GeoAlgorithm
 from processing.core.ProcessingLog import ProcessingLog
 from processing.core.GeoAlgorithmExecutionException import GeoAlgorithmExecutionException
@@ -33,6 +33,19 @@ from processing.core.parameters import ParameterVector
 from processing.core.outputs import OutputVector
 from processing.tools import dataobjects, vector
 
+wkbTypeGroups = {
+    'Point': (QGis.WKBPoint, QGis.WKBMultiPoint, QGis.WKBPoint25D, QGis.WKBMultiPoint25D,),
+    'LineString': (QGis.WKBLineString, QGis.WKBMultiLineString, QGis.WKBLineString25D, QGis.WKBMultiLineString25D,),
+    'Polygon': (QGis.WKBPolygon, QGis.WKBMultiPolygon, QGis.WKBPolygon25D, QGis.WKBMultiPolygon25D,),
+}
+for key, value in wkbTypeGroups.items():
+    for const in value:
+        wkbTypeGroups[const] = key
+
+GEOM_25D = [QGis.WKBPoint25D, QGis.WKBLineString25D, QGis.WKBPolygon25D,
+            QGis.WKBMultiPoint25D, QGis.WKBMultiLineString25D,
+            QGis.WKBMultiPolygon25D]
+
 
 class Union(GeoAlgorithm):
 
@@ -40,18 +53,29 @@ class Union(GeoAlgorithm):
     INPUT2 = 'INPUT2'
     OUTPUT = 'OUTPUT'
 
+    def defineCharacteristics(self):
+        self.name, self.i18n_name = self.trAlgorithm('Union')
+        self.group, self.i18n_group = self.trAlgorithm('Vector overlay tools')
+        self.addParameter(ParameterVector(Union.INPUT,
+                                          self.tr('Input layer'), [ParameterVector.VECTOR_TYPE_ANY]))
+        self.addParameter(ParameterVector(Union.INPUT2,
+                                          self.tr('Input layer 2'), [ParameterVector.VECTOR_TYPE_ANY]))
+        self.addOutput(OutputVector(Union.OUTPUT, self.tr('Union')))
+
     def processAlgorithm(self, progress):
         vlayerA = dataobjects.getObjectFromUri(self.getParameterValue(Union.INPUT))
         vlayerB = dataobjects.getObjectFromUri(self.getParameterValue(Union.INPUT2))
-        GEOS_EXCEPT = True
-        FEATURE_EXCEPT = True
+
         vproviderA = vlayerA.dataProvider()
 
+        geomType = vproviderA.geometryType()
+        if geomType in GEOM_25D:
+            raise GeoAlgorithmExecutionException(
+                self.tr('Input layer has unsupported geometry type {}').format(geomType))
+
         fields = vector.combineVectorFields(vlayerA, vlayerB)
-        names = [field.name() for field in fields]
-        ProcessingLog.addToLog(ProcessingLog.LOG_INFO, unicode(names))
         writer = self.getOutputFromName(Union.OUTPUT).getVectorWriter(fields,
-                                                                      vproviderA.geometryType(), vproviderA.crs())
+                                                                      geomType, vproviderA.crs())
         inFeatA = QgsFeature()
         inFeatB = QgsFeature()
         outFeat = QgsFeature()
@@ -77,8 +101,8 @@ class Union(GeoAlgorithm):
                 except:
                     # This really shouldn't happen, as we haven't
                     # edited the input geom at all
-                    raise GeoAlgorithmExecutionException(
-                        self.tr('Feature exception while computing union'))
+                    ProcessingLog.addToLog(ProcessingLog.LOG_INFO,
+                                           self.tr('Feature geometry error: One or more output features ignored due to invalid geometry.'))
             else:
                 for id in intersects:
                     count += 1
@@ -93,9 +117,9 @@ class Union(GeoAlgorithm):
 
                         if int_geom is None:
                            # There was a problem creating the intersection
-                            raise GeoAlgorithmExecutionException(
-                                self.tr('Geometry exception while computing '
-                                        'intersection'))
+                            ProcessingLog.addToLog(ProcessingLog.LOG_INFO,
+                                                   self.tr('GEOS geoprocessing error: One or more input features have invalid geometry.'))
+                            int_geom = QgsGeometry()
                         else:
                             int_geom = QgsGeometry(int_geom)
 
@@ -105,38 +129,52 @@ class Union(GeoAlgorithm):
                             for i in temp_list:
                                 if i.type() == geom.type():
                                     int_geom = QgsGeometry(i)
-                        try:
-                            outFeat.setGeometry(int_geom)
-                            attrs = []
-                            attrs.extend(atMapA)
-                            attrs.extend(atMapB)
-                            outFeat.setAttributes(attrs)
-                            writer.addFeature(outFeat)
-                        except Exception as err:
-                            raise GeoAlgorithmExecutionException(
-                                self.tr('Feature exception while computing union'))
+                                    try:
+                                        outFeat.setGeometry(int_geom)
+                                        outFeat.setAttributes(atMapA + atMapB)
+                                        writer.addFeature(outFeat)
+                                    except:
+                                        ProcessingLog.addToLog(ProcessingLog.LOG_INFO,
+                                                               self.tr('Feature geometry error: One or more output features ignored due to invalid geometry.'))
+                        else:
+                            # Geometry list: prevents writing error
+                            # in geometries of different types
+                            # produced by the intersection
+                            # fix #3549
+                            if int_geom.wkbType() in wkbTypeGroups[wkbTypeGroups[int_geom.wkbType()]]:
+                                try:
+                                    outFeat.setGeometry(int_geom)
+                                    outFeat.setAttributes(atMapA + atMapB)
+                                    writer.addFeature(outFeat)
+                                except:
+                                    ProcessingLog.addToLog(ProcessingLog.LOG_INFO,
+                                                           self.tr('Feature geometry error: One or more output features ignored due to invalid geometry.'))
 
+                # the remaining bit of inFeatA's geometry
+                # if there is nothing left, this will just silently fail and we're good
+                diff_geom = QgsGeometry(geom)
+                if len(lstIntersectingB) != 0:
+                    intB = QgsGeometry.unaryUnion(lstIntersectingB)
+                    diff_geom = diff_geom.difference(intB)
+                    if diff_geom.isGeosEmpty() or not diff_geom.isGeosValid():
+                        ProcessingLog.addToLog(ProcessingLog.LOG_ERROR,
+                                               self.tr('GEOS geoprocessing error: One or more input features have invalid geometry.'))
+
+                if diff_geom.wkbType() == 0 or QgsWKBTypes.flatType(diff_geom.geometry().wkbType()) == QgsWKBTypes.GeometryCollection:
+                    temp_list = diff_geom.asGeometryCollection()
+                    for i in temp_list:
+                        if i.type() == geom.type():
+                            diff_geom = QgsGeometry(i)
                 try:
-                    # the remaining bit of inFeatA's geometry
-                    # if there is nothing left, this will just silently fail and we're good
-                    diff_geom = QgsGeometry(geom)
-                    if len(lstIntersectingB) != 0:
-                        intB = QgsGeometry.unaryUnion(lstIntersectingB)
-                        diff_geom = diff_geom.difference(intB)
-
-                    if diff_geom.wkbType() == 0 or QgsWKBTypes.flatType(int_geom.geometry().wkbType()) == QgsWKBTypes.GeometryCollection:
-                        temp_list = diff_geom.asGeometryCollection()
-                        for i in temp_list:
-                            if i.type() == geom.type():
-                                diff_geom = QgsGeometry(i)
                     outFeat.setGeometry(diff_geom)
                     outFeat.setAttributes(atMapA)
                     writer.addFeature(outFeat)
-                except Exception as err:
-                    raise GeoAlgorithmExecutionException(
-                        self.tr('Feature exception while computing union'))
+                except:
+                    ProcessingLog.addToLog(ProcessingLog.LOG_INFO,
+                                           self.tr('Feature geometry error: One or more output features ignored due to invalid geometry.'))
 
         length = len(vproviderA.fields())
+        atMapA = [None] * length
 
         featuresA = vector.features(vlayerB)
         nFeat = len(featuresA)
@@ -154,53 +192,41 @@ class Union(GeoAlgorithm):
                     outFeat.setGeometry(geom)
                     outFeat.setAttributes(atMap)
                     writer.addFeature(outFeat)
-                except Exception as err:
-                    raise GeoAlgorithmExecutionException(
-                        self.tr('Feature exception while computing union'))
+                except:
+                    ProcessingLog.addToLog(ProcessingLog.LOG_INFO,
+                                           self.tr('Feature geometry error: One or more output features ignored due to invalid geometry.'))
             else:
                 for id in intersects:
                     request = QgsFeatureRequest().setFilterFid(id)
                     inFeatB = vlayerA.getFeatures(request).next()
                     atMapB = inFeatB.attributes()
                     tmpGeom = QgsGeometry(inFeatB.geometry())
-                    try:
-                        if diff_geom.intersects(tmpGeom):
-                            add = True
-                            diff_geom = QgsGeometry(
-                                diff_geom.difference(tmpGeom))
-                        else:
+
+                    if diff_geom.intersects(tmpGeom):
+                        add = True
+                        diff_geom = QgsGeometry(diff_geom.difference(tmpGeom))
+                        if diff_geom.isGeosEmpty() or not diff_geom.isGeosValid():
+                            ProcessingLog.addToLog(ProcessingLog.LOG_ERROR,
+                                                   self.tr('GEOS geoprocessing error: One or more input features have invalid geometry.'))
+                    else:
+                        try:
                             # Ihis only happends if the bounding box
                             # intersects, but the geometry doesn't
                             outFeat.setGeometry(diff_geom)
                             outFeat.setAttributes(atMap)
                             writer.addFeature(outFeat)
-                    except Exception as err:
-                        raise GeoAlgorithmExecutionException(
-                            self.tr('Geometry exception while computing intersection'))
+                        except:
+                            ProcessingLog.addToLog(ProcessingLog.LOG_INFO,
+                                                   self.tr('Feature geometry error: One or more output features ignored due to invalid geometry.'))
 
             if add:
                 try:
                     outFeat.setGeometry(diff_geom)
                     outFeat.setAttributes(atMap)
                     writer.addFeature(outFeat)
-                except Exception as err:
-                    raise err
-                    FEATURE_EXCEPT = False
+                except:
+                    ProcessingLog.addToLog(ProcessingLog.LOG_INFO,
+                                           self.tr('Feature geometry error: One or more output features ignored due to invalid geometry.'))
             nElement += 1
 
         del writer
-        if not GEOS_EXCEPT:
-            ProcessingLog.addToLog(ProcessingLog.LOG_WARNING,
-                                   self.tr('Geometry exception while computing intersection'))
-        if not FEATURE_EXCEPT:
-            ProcessingLog.addToLog(ProcessingLog.LOG_WARNING,
-                                   self.tr('Feature exception while computing intersection'))
-
-    def defineCharacteristics(self):
-        self.name, self.i18n_name = self.trAlgorithm('Union')
-        self.group, self.i18n_group = self.trAlgorithm('Vector overlay tools')
-        self.addParameter(ParameterVector(Union.INPUT,
-                                          self.tr('Input layer'), [ParameterVector.VECTOR_TYPE_ANY]))
-        self.addParameter(ParameterVector(Union.INPUT2,
-                                          self.tr('Input layer 2'), [ParameterVector.VECTOR_TYPE_ANY]))
-        self.addOutput(OutputVector(Union.OUTPUT, self.tr('Union')))
