@@ -63,7 +63,6 @@ class VoronoiPolygons(GeoAlgorithm):
         writer = self.getOutputFromName(self.OUTPUT).getVectorWriter(
             layer.pendingFields().toList(), QGis.WKBPolygon, layer.crs())
 
-        inFeat = QgsFeature()
         outFeat = QgsFeature()
         extent = layer.extent()
         extraX = extent.height() * (buf / 100.0)
@@ -76,7 +75,8 @@ class VoronoiPolygons(GeoAlgorithm):
         ptNdx = -1
 
         features = vector.features(layer)
-        for inFeat in features:
+        total = 100.0 / len(features)
+        for current, inFeat in enumerate(features):
             geom = QgsGeometry(inFeat.geometry())
             point = geom.asPoint()
             x = point.x() - extent.xMinimum()
@@ -84,6 +84,7 @@ class VoronoiPolygons(GeoAlgorithm):
             pts.append((x, y))
             ptNdx += 1
             ptDict[ptNdx] = inFeat.id()
+            progress.setPercentage(int(current * total))
 
         if len(pts) < 3:
             raise GeoAlgorithmExecutionException(
@@ -93,12 +94,12 @@ class VoronoiPolygons(GeoAlgorithm):
         uniqueSet = Set(item for item in pts)
         ids = [pts.index(item) for item in uniqueSet]
         sl = voronoi.SiteList([voronoi.Site(i[0], i[1], sitenum=j) for (j,
-                              i) in enumerate(uniqueSet)])
+                                                                        i) in enumerate(uniqueSet)])
         voronoi.voronoi(sl, c)
         inFeat = QgsFeature()
 
         current = 0
-        total = 100.0 / float(len(c.polygons))
+        total = 100.0 / len(c.polygons)
 
         for (site, edges) in c.polygons.iteritems():
             request = QgsFeatureRequest().setFilterFid(ptDict[ids[site]])
@@ -223,9 +224,9 @@ class VoronoiPolygons(GeoAlgorithm):
                 )
             if x1 or x2 or y1 or y2:
                 lines.append(QgsPoint(x1 + extent.xMinimum(), y1
-                             + extent.yMinimum()))
+                                      + extent.yMinimum()))
                 lines.append(QgsPoint(x2 + extent.xMinimum(), y2
-                             + extent.yMinimum()))
+                                      + extent.yMinimum()))
                 if 0 - exX in (x1, x2):
                     hasXMin = True
                 if 0 - exY in (y1, y2):
@@ -237,15 +238,15 @@ class VoronoiPolygons(GeoAlgorithm):
         if hasXMin:
             if hasYMax:
                 lines.append(QgsPoint(extent.xMinimum() - exX, height
-                             + extent.yMinimum() + exY))
+                                      + extent.yMinimum() + exY))
             if hasYMin:
                 lines.append(QgsPoint(extent.xMinimum() - exX,
-                             extent.yMinimum() - exY))
+                                      extent.yMinimum() - exY))
         if hasXMax:
             if hasYMax:
                 lines.append(QgsPoint(width + extent.xMinimum() + exX, height
-                             + extent.yMinimum() + exY))
+                                      + extent.yMinimum() + exY))
             if hasYMin:
                 lines.append(QgsPoint(width + extent.xMinimum() + exX,
-                             extent.yMinimum() - exY))
+                                      extent.yMinimum() - exY))
         return lines
