@@ -2,14 +2,18 @@
 ##input=vector
 ##class_field=field input
 ##value_field=field input
-##N unique values=output vector
+##N_unique_values=output vector
+
+from PyQt4.QtCore import QVariant
+from qgis.core import QgsFeature, QgsField
+from processing.tools.vector import VectorWriter
 
 layer = processing.getObject(input)
 provider = layer.dataProvider()
 fields = provider.fields()
 fields.append(QgsField('UNIQ_COUNT', QVariant.Int))
-writer = processing.VectorWriter(output, None, fields, provider.geometryType(),
-                                 layer.crs())
+writer = VectorWriter(N_unique_values, None, fields, provider.geometryType(),
+                      layer.crs())
 
 class_field_index = layer.fieldNameIndex(class_field)
 value_field_index = layer.fieldNameIndex(value_field)
