@@ -74,7 +74,7 @@ class RAlgorithm(GeoAlgorithm):
             self.defineCharacteristicsFromFile()
 
     def getIcon(self):
-        return QIcon(os.path.dirname(__file__) + '/../../images/r.png')
+        return QIcon(os.path.dirname(__file__) + '/../../images/r.svg')
 
     def defineCharacteristicsFromScript(self):
         lines = self.script.split('\n')
@@ -342,7 +342,7 @@ class RAlgorithm(GeoAlgorithm):
                     commands.append(param.name + ' <- read.csv("' + value
                                     + '", head=TRUE, sep=",")')
             elif isinstance(param, (ParameterTableField, ParameterString,
-                            ParameterFile)):
+                                    ParameterFile)):
                 commands.append(param.name + '="' + param.value + '"')
             elif isinstance(param, (ParameterNumber, ParameterSelection)):
                 commands.append(param.name + '=' + unicode(param.value))
