@@ -60,7 +60,7 @@ class DropAnalysis(GeoAlgorithm):
     STEPS = ['Logarithmic', 'Linear']
 
     def getIcon(self):
-        return QIcon(os.path.dirname(__file__) + '/../../images/taudem.png')
+        return QIcon(os.path.dirname(__file__) + '/../../images/taudem.svg')
 
     def defineCharacteristics(self):
         self.name, self.i18n_name = self.trAlgorithm('Stream Drop Analysis')
