@@ -54,7 +54,7 @@ class GridNet(GeoAlgorithm):
     STRAHLER_GRID = 'STRAHLER_GRID'
 
     def getIcon(self):
-        return QIcon(os.path.dirname(__file__) + '/../../images/taudem.png')
+        return QIcon(os.path.dirname(__file__) + '/../../images/taudem.svg')
 
     def defineCharacteristics(self):
         self.name, self.i18n_name = self.trAlgorithm('Grid Network')
