@@ -51,13 +51,9 @@ class AlgorithmProvider(object):
 
     def loadAlgorithms(self):
         self.algs = []
-        name = 'ACTIVATE_' + self.getName().upper().replace(' ', '_')
-        if not ProcessingConfig.getSetting(name):
-            return
-        else:
-            self._loadAlgorithms()
-            for alg in self.algs:
-                alg.provider = self
+        self._loadAlgorithms()
+        for alg in self.algs:
+            alg.provider = self
 
     # Methods to be overridden.
     def _loadAlgorithms(self):
@@ -78,7 +74,7 @@ class AlgorithmProvider(object):
         ProcessingConfig.settingIcons[self.getDescription()] = self.getIcon()
         name = 'ACTIVATE_' + self.getName().upper().replace(' ', '_')
         ProcessingConfig.addSetting(Setting(self.getDescription(), name,
-                                    self.tr('Activate'), self.activate))
+                                            self.tr('Activate'), self.activate))
 
     def unload(self):
         """Do here anything that you want to be done when the provider
@@ -124,6 +120,9 @@ class AlgorithmProvider(object):
     def supportsNonFileBasedOutput(self):
         return False
 
+    def canBeActivated(self):
+        return True
+
     def tr(self, string, context=''):
         if context == '':
             context = self.__class__.__name__
