@@ -29,12 +29,13 @@ import os
 
 from PyQt4.QtCore import QPyNullVariant, QCoreApplication, QSettings
 from PyQt4.QtGui import QIcon
-from processing.tools.system import tempFolder
+from processing.tools.system import defaultOutputFolder
+import processing.tools.dataobjects
 
 
 class ProcessingConfig:
 
-    OUTPUT_FOLDER = 'OUTPUT_FOLDER'
+    OUTPUT_FOLDER = 'OUTPUTS_FOLDER'
     RASTER_STYLE = 'RASTER_STYLE'
     VECTOR_POINT_STYLE = 'VECTOR_POINT_STYLE'
     VECTOR_LINE_STYLE = 'VECTOR_LINE_STYLE'
@@ -49,6 +50,9 @@ class ProcessingConfig:
     POST_EXECUTION_SCRIPT = 'POST_EXECUTION_SCRIPT'
     SHOW_CRS_DEF = 'SHOW_CRS_DEF'
     WARN_UNMATCHING_CRS = 'WARN_UNMATCHING_CRS'
+    DEFAULT_OUTPUT_RASTER_LAYER_EXT = 'DEFAULT_OUTPUT_RASTER_LAYER_EXT'
+    DEFAULT_OUTPUT_VECTOR_LAYER_EXT = 'DEFAULT_OUTPUT_VECTOR_LAYER_EXT'
+    SHOW_PROVIDERS_TOOLTIP = "SHOW_PROVIDERS_TOOLTIP"
 
     settings = {}
     settingIcons = {}
@@ -77,10 +81,14 @@ class ProcessingConfig:
             ProcessingConfig.tr('General'),
             ProcessingConfig.SHOW_RECENT_ALGORITHMS,
             ProcessingConfig.tr('Show recently executed algorithms'), True))
+        ProcessingConfig.addSetting(Setting(
+            ProcessingConfig.tr('General'),
+            ProcessingConfig.SHOW_PROVIDERS_TOOLTIP,
+            ProcessingConfig.tr('Show tooltip when there are disabled providers'), True))
         ProcessingConfig.addSetting(Setting(
             ProcessingConfig.tr('General'),
             ProcessingConfig.OUTPUT_FOLDER,
-            ProcessingConfig.tr('Output folder'), tempFolder(),
+            ProcessingConfig.tr('Output folder'), defaultOutputFolder(),
             valuetype=Setting.FOLDER))
         ProcessingConfig.addSetting(Setting(
             ProcessingConfig.tr('General'),
@@ -93,35 +101,49 @@ class ProcessingConfig:
         ProcessingConfig.addSetting(Setting(
             ProcessingConfig.tr('General'),
             ProcessingConfig.RASTER_STYLE,
-            ProcessingConfig.tr('Style for raster layers'), ''))
+            ProcessingConfig.tr('Style for raster layers'), '',
+            valuetype=Setting.FILE))
         ProcessingConfig.addSetting(Setting(
             ProcessingConfig.tr('General'),
             ProcessingConfig.VECTOR_POINT_STYLE,
-            ProcessingConfig.tr('Style for point layers'), ''))
+            ProcessingConfig.tr('Style for point layers'), '',
+            valuetype=Setting.FILE))
         ProcessingConfig.addSetting(Setting(
             ProcessingConfig.tr('General'),
             ProcessingConfig.VECTOR_LINE_STYLE,
-            ProcessingConfig.tr('Style for line layers'), ''))
+            ProcessingConfig.tr('Style for line layers'), '',
+            valuetype=Setting.FILE))
         ProcessingConfig.addSetting(Setting(
             ProcessingConfig.tr('General'),
             ProcessingConfig.VECTOR_POLYGON_STYLE,
-            ProcessingConfig.tr('Style for polygon layers'), ''))
-        ProcessingConfig.addSetting(Setting(
-            ProcessingConfig.tr('General'),
-            ProcessingConfig.VECTOR_POLYGON_STYLE,
-            ProcessingConfig.tr('Style for polygon layers'), ''))
+            ProcessingConfig.tr('Style for polygon layers'), '',
+            valuetype=Setting.FILE))
         ProcessingConfig.addSetting(Setting(
             ProcessingConfig.tr('General'),
             ProcessingConfig.PRE_EXECUTION_SCRIPT,
-            ProcessingConfig.tr('Pre-execution script'), ''))
+            ProcessingConfig.tr('Pre-execution script'), '',
+            valuetype=Setting.FILE))
         ProcessingConfig.addSetting(Setting(
             ProcessingConfig.tr('General'),
             ProcessingConfig.POST_EXECUTION_SCRIPT,
-            ProcessingConfig.tr('Post-execution script'), ''))
+            ProcessingConfig.tr('Post-execution script'), '',
+            valuetype=Setting.FILE))
         ProcessingConfig.addSetting(Setting(
             ProcessingConfig.tr('General'),
             ProcessingConfig.RECENT_ALGORITHMS,
             ProcessingConfig.tr('Recent algs'), '', hidden=True))
+        extensions = processing.tools.dataobjects.getSupportedOutputVectorLayerExtensions()
+        ProcessingConfig.addSetting(Setting(
+            ProcessingConfig.tr('General'),
+            ProcessingConfig.DEFAULT_OUTPUT_VECTOR_LAYER_EXT,
+            ProcessingConfig.tr('Default output vector layer extension'), extensions[0],
+            valuetype=Setting.SELECTION, options=extensions))
+        extensions = processing.tools.dataobjects.getSupportedOutputRasterLayerExtensions()
+        ProcessingConfig.addSetting(Setting(
+            ProcessingConfig.tr('General'),
+            ProcessingConfig.DEFAULT_OUTPUT_RASTER_LAYER_EXT,
+            ProcessingConfig.tr('Default output raster layer extension'), extensions[0],
+            valuetype=Setting.SELECTION, options=extensions))
 
     @staticmethod
     def setGroupIcon(group, icon):
@@ -175,7 +197,7 @@ class ProcessingConfig:
     @staticmethod
     def setSettingValue(name, value):
         if name in ProcessingConfig.settings.keys():
-            ProcessingConfig.settings[name].value = value
+            ProcessingConfig.settings[name].setValue(value)
             ProcessingConfig.settings[name].save()
 
     @staticmethod
@@ -192,16 +214,53 @@ class Setting:
     STRING = 0
     FILE = 1
     FOLDER = 2
+    SELECTION = 3
+    FLOAT = 4
+    INT = 5
 
-    def __init__(self, group, name, description, default, hidden=False, valuetype=None):
+    def __init__(self, group, name, description, default, hidden=False, valuetype=None,
+                 validator=None, options=None):
         self.group = group
         self.name = name
         self.qname = "Processing/Configuration/" + self.name
         self.description = description
         self.default = default
-        self.value = default
         self.hidden = hidden
+        if valuetype is None:
+            if isinstance(default, (int, long)):
+                valuetype = self.INT
+            elif isinstance(default, float):
+                valuetype = self.FLOAT
         self.valuetype = valuetype
+        self.options = options
+        if validator is None:
+            if valuetype == self.FLOAT:
+                def checkFloat(v):
+                    try:
+                        float(v)
+                    except ValueError:
+                        raise ValueError(self.tr('Wrong parameter value:\n%s') % unicode(v))
+                validator = checkFloat
+            elif valuetype == self.INT:
+                def checkInt(v):
+                    try:
+                        int(v)
+                    except ValueError:
+                        raise ValueError(self.tr('Wrong parameter value:\n%s') % unicode(v))
+                validator = checkInt
+            elif valuetype in [self.FILE, self.FOLDER]:
+                def checkFileOrFolder(v):
+                    if v and not os.path.exists(v):
+                        raise ValueError(self.tr('Specified path does not exist:\n%s') % unicode(v))
+                validator = checkFileOrFolder
+            else:
+                validator = lambda x: True
+        self.validator = validator
+        self.value = default
+
+    def setValue(self, value):
+        self.validator(value)
+        self.value = value
 
     def read(self):
         qsettings = QSettings()
@@ -216,3 +275,8 @@ class Setting:
 
     def __str__(self):
         return self.name + '=' + unicode(self.value)
+
+    def tr(self, string, context=''):
+        if context == '':
+            context = 'ProcessingConfig'
+        return QCoreApplication.translate(context, string)
