@@ -39,13 +39,13 @@ from processing.tools import dataobjects
 
 def getParameterFromString(s):
     tokens = s.split("|")
-    params = [t if unicode(t) != "None" else None for t in tokens[1:]]
+    params = [t if unicode(t) != unicode(None) else None for t in tokens[1:]]
     clazz = getattr(sys.modules[__name__], tokens[0])
     return clazz(*params)
 
 
 def parseBool(s):
-    if s == unicode(None):
+    if s is None or s == unicode(None).lower():
         return None
     return unicode(s).lower() == unicode(True).lower()
 
@@ -57,10 +57,11 @@ class Parameter:
     take as input.
     """
 
-    def __init__(self, name='', description=''):
+    def __init__(self, name='', description='', default=None, optional=False):
         self.name = name
         self.description = description
-        self.value = None
+        self.default = default
+        self.value = default
 
         self.isAdvanced = False
 
@@ -69,6 +70,8 @@ class Parameter:
         # shown to the user
         self.hidden = False
 
+        self.optional = parseBool(optional)
+
     def setValue(self, obj):
         """
         Sets the value of the parameter.
@@ -76,9 +79,24 @@ class Parameter:
         Returns true if the value passed is correct for the type
         of parameter.
         """
+        if obj is None:
+            if not self.optional:
+                return False
+            self.value = None
+            return True
+
         self.value = unicode(obj)
         return True
 
+    def setDefaultValue(self):
+        """
+        Sets the value of the parameter to the default one
+
+        Returns true if the default value is correct for the type
+        of parameter.
+        """
+        return self.setValue(self.default)
+
     def __str__(self):
         return u'{} <{}>'.format(self.name, self.__class__.__name__)
 
@@ -104,36 +122,40 @@ class Parameter:
 
 class ParameterBoolean(Parameter):
 
-    def __init__(self, name='', description='', default=True):
-        Parameter.__init__(self, name, description)
-        self.default = parseBool(default)
-        self.value = None
+    def __init__(self, name='', description='', default=None, optional=False):
+        Parameter.__init__(self, name, description, parseBool(default), optional)
 
     def setValue(self, value):
         if value is None:
-            self.value = self.default
+            if not self.optional:
+                return False
+            self.value = None
             return True
+
         if isinstance(value, basestring):
             self.value = unicode(value).lower() == unicode(True).lower()
         else:
             self.value = bool(value)
         return True
 
+    def getAsScriptCode(self):
+        return '##' + self.name + '=boolean ' + str(self.default)
+
 
 class ParameterCrs(Parameter):
 
-    def __init__(self, name='', description='', default='EPSG:4326'):
+    def __init__(self, name='', description='', default=None, optional=False):
         '''The value is a string that uniquely identifies the
         coordinate reference system. Typically it is the auth id of the CRS
         (if the authority is EPSG) or proj4 string of the CRS (in case
         of other authorities or user defined projections).'''
-        Parameter.__init__(self, name, description)
-        self.value = None
-        self.default = default
+        Parameter.__init__(self, name, description, default, optional)
 
     def setValue(self, value):
-        if value is None:
-            self.value = self.default
+        if value is None or value.strip() == '':
+            if not self.optional:
+                return False
+            self.value = None if value is None else value.strip()
             return True
 
         # TODO: check it is a valid authid
@@ -143,6 +165,9 @@ class ParameterCrs(Parameter):
     def getValueAsCommandLineParameter(self):
         return '"' + unicode(self.value) + '"'
 
+    def getAsScriptCode(self):
+        return '##' + self.name + '=crs ' + str(self.default)
+
 
 class ParameterDataObject(Parameter):
 
@@ -159,17 +184,18 @@ class ParameterExtent(Parameter):
 
     USE_MIN_COVERING_EXTENT = 'USE_MIN_COVERING_EXTENT'
 
-    def __init__(self, name='', description='', default='0,1,0,1'):
-        Parameter.__init__(self, name, description)
-        self.default = default
+    def __init__(self, name='', description='', default=None, optional=False):
+        Parameter.__init__(self, name, description, default, optional)
         # The value is a string in the form "xmin, xmax, ymin, ymax"
-        self.value = None
 
     def setValue(self, text):
         if text is None:
-            self.value = self.default
+            if not self.optional:
+                return False
+            self.value = None
             return True
-        tokens = text.split(',')
+
+        tokens = unicode(text).split(',')
         if len(tokens) != 4:
             return False
         try:
@@ -185,28 +211,30 @@ class ParameterExtent(Parameter):
     def getValueAsCommandLineParameter(self):
         return '"' + unicode(self.value) + '"'
 
+    def getAsScriptCode(self):
+        return '##' + self.name + '=extent'
+
 
 class ParameterFile(Parameter):
 
     def __init__(self, name='', description='', isFolder=False, optional=True, ext=None):
-        Parameter.__init__(self, name, description)
-        self.value = None
+        Parameter.__init__(self, name, description, None, parseBool(optional))
         self.ext = ext
         self.isFolder = parseBool(isFolder)
-        self.optional = parseBool(optional)
 
     def getValueAsCommandLineParameter(self):
         return '"' + unicode(self.value) + '"'
 
     def setValue(self, obj):
-        self.value = unicode(obj)
-        if self.value.strip() == '' or self.value is None:
+        if obj is None or obj.strip() == '':
             if not self.optional:
                 return False
-            else:
-                self.value = ''
-        if self.ext is not None and self.value != '':
-            return self.value.endswith(self.ext)
+            self.value = None if obj is None else obj.strip()
+            return True
+
+        if self.ext is not None and obj != '' and not obj.endswith(self.ext):
+            return False
+        self.value = unicode(obj)
         return True
 
     def typeName(self):
@@ -215,20 +243,31 @@ class ParameterFile(Parameter):
         else:
             return 'file'
 
+    def getAsScriptCode(self):
+        if self.isFolder:
+            return '##' + self.name + '=folder'
+        else:
+            return '##' + self.name + '=file'
+
 
 class ParameterFixedTable(Parameter):
 
     def __init__(self, name='', description='', numRows=3,
-                 cols=['value'], fixedNumOfRows=False):
-        Parameter.__init__(self, name, description)
+                 cols=['value'], fixedNumOfRows=False, optional=False):
+        Parameter.__init__(self, name, description, None, optional)
         self.cols = cols
         if isinstance(cols, basestring):
             self.cols = self.cols.split(";")
         self.numRows = int(numRows)
-        self.fixedNumOfRows = fixedNumOfRows
-        self.value = None
+        self.fixedNumOfRows = parseBool(fixedNumOfRows)
 
     def setValue(self, obj):
+        if obj is None:
+            if not self.optional:
+                return False
+            self.value = None
+            return True
+
         # TODO: check that it contains a correct number of elements
         if isinstance(obj, (str, unicode)):
             self.value = obj
@@ -267,20 +306,17 @@ class ParameterMultipleInput(ParameterDataObject):
     TYPE_FILE = 4
 
     def __init__(self, name='', description='', datatype=-1, optional=False):
-        ParameterDataObject.__init__(self, name, description)
+        ParameterDataObject.__init__(self, name, description, None, optional)
         self.datatype = int(float(datatype))
-        self.optional = parseBool(optional)
-        self.value = None
         self.exported = None
 
     def setValue(self, obj):
         self.exported = None
         if obj is None:
-            if self.optional:
-                self.value = None
-                return True
-            else:
+            if not self.optional:
                 return False
+            self.value = None
+            return True
 
         if isinstance(obj, list):
             if len(obj) == 0:
@@ -393,18 +429,31 @@ class ParameterMultipleInput(ParameterDataObject):
         else:
             return 'any vectors'
 
+    def getAsScriptCode(self):
+        if self.datatype == self.TYPE_RASTER:
+            return '##' + self.name + '=multiple raster'
+        if self.datatype == self.TYPE_FILE:
+            return '##' + self.name + '=multiple file'
+        else:
+            return '##' + self.name + '=multiple vector'
+
 
 class ParameterNumber(Parameter):
 
     def __init__(self, name='', description='', minValue=None, maxValue=None,
-                 default=0.0):
-        Parameter.__init__(self, name, description)
-        try:
-            self.default = int(unicode(default))
-            self.isInteger = True
-        except:
-            self.default = float(default)
+                 default=None, optional=False):
+        Parameter.__init__(self, name, description, default, optional)
+
+        if default is not None:
+            try:
+                self.default = int(unicode(default))
+                self.isInteger = True
+            except ValueError:
+                self.default = float(default)
+                self.isInteger = False
+        else:
             self.isInteger = False
+
         if minValue is not None:
             self.min = int(float(minValue)) if self.isInteger else float(minValue)
         else:
@@ -413,12 +462,15 @@ class ParameterNumber(Parameter):
             self.max = int(float(maxValue)) if self.isInteger else float(maxValue)
         else:
             self.max = None
-        self.value = None
+        self.value = self.default
 
     def setValue(self, n):
         if n is None:
-            self.value = self.default
+            if not self.optional:
+                return False
+            self.value = None
             return True
+
         try:
             if float(n) - int(float(n)) == 0:
                 value = int(float(n))
@@ -435,26 +487,33 @@ class ParameterNumber(Parameter):
         except:
             return False
 
+    def getAsScriptCode(self):
+        return '##' + self.name + '=number ' + str(self.default)
+
 
 class ParameterRange(Parameter):
 
-    def __init__(self, name='', description='', default='0,1'):
-        Parameter.__init__(self, name, description)
-        self.default = default
-        self.value = None
+    def __init__(self, name='', description='', default=None, optional=False):
+        Parameter.__init__(self, name, description, default, optional)
 
-        values = default.split(',')
-        try:
-            int(values[0])
-            int(values[1])
-            self.isInteger = True
-        except:
+        if default is not None:
+            values = default.split(',')
+            try:
+                int(values[0])
+                int(values[1])
+                self.isInteger = True
+            except:
+                self.isInteger = False
+        else:
             self.isInteger = False
 
     def setValue(self, text):
         if text is None:
-            self.value = self.default
+            if not self.optional:
+                return False
+            self.value = None
             return True
+
         tokens = text.split(',')
         if len(tokens) != 2:
             return False
@@ -467,16 +526,14 @@ class ParameterRange(Parameter):
             return False
 
     def getValueAsCommandLineParameter(self):
-        return '"' + unicode(self.value) + '"'
+        return '"' + unicode(self.value) + '"' if self.value is not None else unicode(None)
 
 
 class ParameterRaster(ParameterDataObject):
 
     def __init__(self, name='', description='', optional=False, showSublayersDialog=True):
-        ParameterDataObject.__init__(self, name, description)
+        ParameterDataObject.__init__(self, name, description, None, optional)
         self.showSublayersDialog = parseBool(showSublayersDialog)
-        self.optional = parseBool(optional)
-        self.value = None
         self.exported = None
 
     def getSafeExportedLayer(self):
@@ -510,11 +567,11 @@ class ParameterRaster(ParameterDataObject):
     def setValue(self, obj):
         self.exported = None
         if obj is None:
-            if self.optional:
-                self.value = None
-                return True
-            else:
+            if not self.optional:
                 return False
+            self.value = None
+            return True
+
         if isinstance(obj, QgsRasterLayer):
             self.value = unicode(obj.dataProvider().dataSourceUri())
             return True
@@ -528,11 +585,16 @@ class ParameterRaster(ParameterDataObject):
             exts[i] = self.tr('%s files(*.%s)', 'ParameterRaster') % (exts[i].upper(), exts[i].lower())
         return ';;'.join(exts)
 
+    def getAsScriptCode(self):
+        return '##' + self.name + '=raster'
+
 
 class ParameterSelection(Parameter):
 
-    def __init__(self, name='', description='', options=[], default=0, isSource=False):
-        Parameter.__init__(self, name, description)
+    def __init__(self, name='', description='', options=[], default=None, isSource=False,
+                 optional=False):
+        Parameter.__init__(self, name, description, default, optional)
+        isSource = parseBool(isSource)
         self.options = options
         if isSource:
             self.options = []
@@ -547,13 +609,21 @@ class ParameterSelection(Parameter):
                     pass
         elif isinstance(self.options, basestring):
             self.options = self.options.split(";")
-        self.value = None
-        self.default = int(default)
+
+        if default is not None:
+            try:
+                self.default = int(default)
+            except:
+                self.default = 0
+            self.value = self.default
 
     def setValue(self, n):
         if n is None:
-            self.value = self.default
+            if not self.optional:
+                return False
+            self.value = 0
             return True
+
         try:
             n = int(n)
             self.value = n
@@ -567,21 +637,18 @@ class ParameterString(Parameter):
     NEWLINE = '\n'
     ESCAPED_NEWLINE = '\\n'
 
-    def __init__(self, name='', description='', default='', multiline=False,
+    def __init__(self, name='', description='', default=None, multiline=False,
                  optional=False):
-        Parameter.__init__(self, name, description)
-        self.default = default
-        self.value = None
+        Parameter.__init__(self, name, description, default, optional)
         self.multiline = parseBool(multiline)
-        self.optional = parseBool(optional)
 
     def setValue(self, obj):
         if obj is None:
-            if self.optional:
-                self.value = ''
-                return True
-            self.value = self.default
+            if not self.optional:
+                return False
+            self.value = None
             return True
+
         self.value = unicode(obj).replace(
             ParameterString.ESCAPED_NEWLINE,
             ParameterString.NEWLINE
@@ -589,26 +656,28 @@ class ParameterString(Parameter):
         return True
 
     def getValueAsCommandLineParameter(self):
-        return '"' + unicode(self.value.replace(ParameterString.NEWLINE,
-                             ParameterString.ESCAPED_NEWLINE)) + '"'
+        return ('"' + unicode(self.value.replace(ParameterString.NEWLINE,
+                                                 ParameterString.ESCAPED_NEWLINE)) + '"'
+                if self.value is not None else unicode(None))
+
+    def getAsScriptCode(self):
+        return '##' + self.name + '=string ' + self.default
 
 
 class ParameterTable(ParameterDataObject):
 
     def __init__(self, name='', description='', optional=False):
-        ParameterDataObject.__init__(self, name, description)
-        self.optional = parseBool(optional)
-        self.value = None
+        ParameterDataObject.__init__(self, name, description, None, optional)
         self.exported = None
 
     def setValue(self, obj):
         self.exported = None
         if obj is None:
-            if self.optional:
-                self.value = None
-                return True
-            else:
+            if not self.optional:
                 return False
+            self.value = None
+            return True
+
         if isinstance(obj, QgsVectorLayer):
             source = unicode(obj.source())
             self.value = source
@@ -659,6 +728,9 @@ class ParameterTable(ParameterDataObject):
             exts[i] = self.tr('%s files(*.%s)', 'ParameterTable') % (exts[i].upper(), exts[i].lower())
         return ';;'.join(exts)
 
+    def getAsScriptCode(self):
+        return '##' + self.name + '=table'
+
 
 class ParameterTableField(Parameter):
 
@@ -668,22 +740,23 @@ class ParameterTableField(Parameter):
 
     def __init__(self, name='', description='', parent=None, datatype=-1,
                  optional=False):
-        Parameter.__init__(self, name, description)
+        Parameter.__init__(self, name, description, None, optional)
         self.parent = parent
-        self.value = None
         self.datatype = int(datatype)
-        self.optional = parseBool(optional)
 
     def getValueAsCommandLineParameter(self):
-        return '"' + unicode(self.value) + '"'
+        return '"' + unicode(self.value) + '"' if self.value is not None else unicode(None)
 
     def setValue(self, value):
         if value is None:
-            return self.optional
-        elif len(value) > 0:
-            self.value = unicode(value)
-        else:
-            return self.optional
+            if not self.optional:
+                return False
+            self.value = None
+            return True
+
+        elif len(value) == 0 and not self.optional:
+            return False
+        self.value = unicode(value)
         return True
 
     def __str__(self):
@@ -698,6 +771,9 @@ class ParameterTableField(Parameter):
         else:
             return 'any'
 
+    def getAsScriptCode(self):
+        return '##' + self.name + '=field ' + self.parent
+
 
 class ParameterVector(ParameterDataObject):
 
@@ -708,24 +784,22 @@ class ParameterVector(ParameterDataObject):
 
     def __init__(self, name='', description='', shapetype=[-1],
                  optional=False):
-        ParameterDataObject.__init__(self, name, description)
-        self.optional = parseBool(optional)
+        ParameterDataObject.__init__(self, name, description, None, optional)
         if isinstance(shapetype, int):
             shapetype = [shapetype]
         elif isinstance(shapetype, basestring):
             shapetype = [int(t) for t in shapetype.split(',')]
         self.shapetype = shapetype
-        self.value = None
         self.exported = None
 
     def setValue(self, obj):
         self.exported = None
         if obj is None:
-            if self.optional:
-                self.value = None
-                return True
-            else:
+            if not self.optional:
                 return False
+            self.value = None
+            return True
+
         if isinstance(obj, QgsVectorLayer):
             self.value = unicode(obj.source())
             return True
@@ -785,6 +859,9 @@ class ParameterVector(ParameterDataObject):
 
         return types[:-2]
 
+    def getAsScriptCode(self):
+        return '##' + self.name + '=vector'
+
 
 class ParameterGeometryPredicate(Parameter):
 
@@ -799,12 +876,10 @@ class ParameterGeometryPredicate(Parameter):
 
     def __init__(self, name='', description='', left=None, right=None,
                  optional=False, enabledPredicates=None):
-        Parameter.__init__(self, name, description)
+        Parameter.__init__(self, name, description, None, optional)
         self.left = left
         self.right = right
         self.value = None
-        self.default = []
-        self.optional = parseBool(optional)
         self.enabledPredicates = enabledPredicates
         if self.enabledPredicates is None:
             self.enabledPredicates = self.predicates
@@ -814,9 +889,13 @@ class ParameterGeometryPredicate(Parameter):
 
     def setValue(self, value):
         if value is None:
-            return self.optional
-        elif len(value) == 0:
-            return self.optional
+            if not self.optional:
+                return False
+            self.value = None
+            return True
+        elif len(value) == 0 and not self.optional:
+            return False
+
         if isinstance(value, unicode):
             self.value = value.split(';') # relates to ModelerAlgorithm.resolveValue
         else:
