@@ -29,6 +29,8 @@ from PyQt4.QtCore import Qt
 from PyQt4.QtGui import QMessageBox, QApplication, QCursor, QColor, QPalette, QPushButton, QWidget,\
     QVBoxLayout
 
+from qgis.core import *
+
 from processing.core.ProcessingLog import ProcessingLog
 from processing.core.ProcessingConfig import ProcessingConfig
 
@@ -75,15 +77,17 @@ class AlgorithmDialog(AlgorithmDialogBase):
         layout = QVBoxLayout()
         layout.setContentsMargins(0, 0, 0, 5)
         self.tabWidget.setStyleSheet("QTabBar::tab { height: 30px; }")
-        runAsBatchButton = QPushButton("Run as batch process...")
+        runAsBatchButton = QPushButton(self.tr("Run as batch process..."))
         runAsBatchButton.clicked.connect(self.runAsBatch)
         layout.addWidget(runAsBatchButton)
         cornerWidget.setLayout(layout)
         self.tabWidget.setCornerWidget(cornerWidget)
 
+        QgsMapLayerRegistry.instance().layerWasAdded.connect(self.mainWidget.layerAdded)
+        QgsMapLayerRegistry.instance().layersWillBeRemoved.connect(self.mainWidget.layersWillBeRemoved)
+
     def runAsBatch(self):
         dlg = BatchAlgorithmDialog(self.alg)
-        dlg.show()
         dlg.exec_()
 
     def setParamValues(self):
@@ -256,3 +260,8 @@ class AlgorithmDialog(AlgorithmDialogBase):
                 self.setInfo(
                     self.tr('HTML output has been generated by this algorithm.'
                             '\nOpen the results dialog to check it.'))
+
+    def closeEvent(self, evt):
+        QgsMapLayerRegistry.instance().layerWasAdded.disconnect(self.mainWidget.layerAdded)
+        QgsMapLayerRegistry.instance().layersWillBeRemoved.disconnect(self.mainWidget.layersWillBeRemoved)
+        super(AlgorithmDialog, self).closeEvent(evt)
