@@ -26,9 +26,11 @@ __copyright__ = '(C) 2014, Alexander Bruy'
 __revision__ = '$Format:%H$'
 
 import os
+import json
 
 from PyQt4 import uic
-from PyQt4.QtGui import QWidget, QIcon, QTableWidgetItem, QComboBox, QLineEdit, QHeaderView
+from PyQt4.QtGui import (QWidget, QIcon, QTableWidgetItem, QComboBox, QLineEdit,
+                         QHeaderView, QFileDialog, QMessageBox)
 
 from qgis.core import QgsApplication
 
@@ -59,6 +61,9 @@ WIDGET, BASE = uic.loadUiType(
 
 class BatchPanel(BASE, WIDGET):
 
+    PARAMETERS = "PARAMETERS"
+    OUTPUTS = "OUTPUTS"
+
     def __init__(self, parent, alg):
         super(BatchPanel, self).__init__(None)
         self.setupUi(self)
@@ -68,6 +73,8 @@ class BatchPanel(BASE, WIDGET):
         # Set icons
         self.btnAdd.setIcon(QgsApplication.getThemeIcon('/symbologyAdd.svg'))
         self.btnRemove.setIcon(QgsApplication.getThemeIcon('/symbologyRemove.svg'))
+        self.btnOpen.setIcon(QgsApplication.getThemeIcon('/mActionFileOpen.svg'))
+        self.btnSave.setIcon(QgsApplication.getThemeIcon('/mActionFileSave.svg'))
         self.btnAdvanced.setIcon(QIcon(os.path.join(pluginPath, 'images', 'alg.png')))
 
         self.alg = alg
@@ -75,6 +82,8 @@ class BatchPanel(BASE, WIDGET):
 
         self.btnAdd.clicked.connect(self.addRow)
         self.btnRemove.clicked.connect(self.removeRows)
+        self.btnOpen.clicked.connect(self.load)
+        self.btnSave.clicked.connect(self.save)
         self.btnAdvanced.toggled.connect(self.toggleAdvancedMode)
         self.tblParameters.horizontalHeader().sectionDoubleClicked.connect(
             self.fillParameterValues)
@@ -164,6 +173,145 @@ class BatchPanel(BASE, WIDGET):
 
         return item
 
+    def load(self):
+        filename = unicode(QFileDialog.getOpenFileName(self,
+                                                       self.tr('Open batch'), None,
+                                                       self.tr('JSON files (*.json)')))
+        if filename:
+            with open(filename) as f:
+                values = json.load(f)
+        else:
+            # If the user clicked on the cancel button.
+            return
+
+        self.tblParameters.setRowCount(0)
+        try:
+            for row, alg in enumerate(values):
+                self.addRow()
+                params = alg[self.PARAMETERS]
+                outputs = alg[self.OUTPUTS]
+                column = 0
+                for param in self.alg.parameters:
+                    if param.hidden:
+                        continue
+                    widget = self.tblParameters.cellWidget(row, column)
+                    if param.name in params:
+                        value = params[param.name]
+                        self.setValueInWidget(widget, value)
+                    column += 1
+
+                for out in self.alg.outputs:
+                    if out.hidden:
+                        continue
+                    widget = self.tblParameters.cellWidget(row, column)
+                    if out.name in outputs:
+                        value = outputs[out.name]
+                        self.setValueInWidget(widget, value)
+                    column += 1
+        except TypeError:
+            QMessageBox.critical(
+                self,
+                self.tr('Error'),
+                self.tr('An error occured while reading your file.'))
+
+    def setValueInWidget(self, widget, value):
+        if isinstance(widget, (BatchInputSelectionPanel, QLineEdit, FileSelectionPanel)):
+            widget.setText(unicode(value))
+        elif isinstance(widget, (BatchOutputSelectionPanel, GeometryPredicateSelectionPanel)):
+            widget.setValue(unicode(value))
+
+        elif isinstance(widget, QComboBox):
+            idx = widget.findText(unicode(value))
+            if idx != -1:
+                widget.setCurrentIndex(idx)
+        elif isinstance(widget, ExtentSelectionPanel):
+            if value is not None:
+                widget.setExtentFromString(value)
+            else:
+                widget.setExtentFromString('')
+        elif isinstance(widget, CrsSelectionPanel):
+            widget.setAuthId(value)
+
+    def save(self):
+        toSave = []
+        for row in range(self.tblParameters.rowCount()):
+            algParams = {}
+            algOutputs = {}
+            col = 0
+            alg = self.alg.getCopy()
+            for param in alg.parameters:
+                if param.hidden:
+                    continue
+                if isinstance(param, ParameterExtent):
+                    col += 1
+                    continue
+                widget = self.tblParameters.cellWidget(row, col)
+                if not self.setParamValue(param, widget, alg):
+                    self.parent.lblProgress.setText(
+                        self.tr('<b>Missing parameter value: %s (row %d)</b>') % (param.description, row + 1))
+                    return
+                algParams[param.name] = param.getValueAsCommandLineParameter()
+                col += 1
+            col = 0
+            for param in alg.parameters:
+                if param.hidden:
+                    continue
+                if isinstance(param, ParameterExtent):
+                    widget = self.tblParameters.cellWidget(row, col)
+                    if not self.setParamValue(param, widget, alg):
+                        self.parent.lblProgress.setText(
+                            self.tr('<b>Missing parameter value: %s (row %d)</b>') % (param.description, row + 1))
+                        return
+                    algParams[param.name] = unicode(param.value())
+                col += 1
+            for out in alg.outputs:
+                if out.hidden:
+                    continue
+                widget = self.tblParameters.cellWidget(row, col)
+                text = widget.getValue()
+                if text.strip() != '':
+                    algOutputs[out.name] = text.strip()
+                    col += 1
+                else:
+                    self.parent.lblProgress.setText(
+                        self.tr('<b>Wrong or missing parameter value: %s (row %d)</b>') % (out.description, row + 1))
+                    return
+            toSave.append({self.PARAMETERS: algParams, self.OUTPUTS: algOutputs})
+
+        filename = unicode(QFileDialog.getSaveFileName(self,
+                                                       self.tr('Save batch'),
+                                                       None,
+                                                       self.tr('JSON files (*.json)')))
+        if filename:
+            if not filename.endswith('.json'):
+                filename += '.json'
+            with open(filename, 'w') as f:
+                json.dump(toSave, f)
+
+    def setParamValue(self, param, widget, alg=None):
+        if isinstance(param, (ParameterRaster, ParameterVector, ParameterTable,
+                              ParameterMultipleInput)):
+            value = widget.getText()
+            if unicode(value).strip() == '':
+                value = None
+            return param.setValue(value)
+        elif isinstance(param, ParameterBoolean):
+            return param.setValue(widget.currentIndex() == 0)
+        elif isinstance(param, ParameterSelection):
+            return param.setValue(widget.currentIndex())
+        elif isinstance(param, ParameterFixedTable):
+            return param.setValue(widget.table)
+        elif isinstance(param, ParameterExtent):
+            if alg is not None:
+                widget.useNewAlg(alg)
+            return param.setValue(widget.getValue())
+        elif isinstance(param, (ParameterCrs, ParameterFile)):
+            return param.setValue(widget.getValue())
+        elif isinstance(param, ParameterGeometryPredicate):
+            return param.setValue(widget.value())
+        else:
+            return param.setValue(widget.text())
+
     def addRow(self):
         self.tblParameters.setRowCount(self.tblParameters.rowCount() + 1)
 
