@@ -92,6 +92,9 @@ class ModelerParameterDefinitionDialog(QDialog):
         self.horizontalLayout3 = QHBoxLayout(self)
         self.horizontalLayout3.setSpacing(2)
         self.horizontalLayout3.setMargin(0)
+        self.horizontalLayout4 = QHBoxLayout(self)
+        self.horizontalLayout4.setSpacing(2)
+        self.horizontalLayout4.setMargin(0)
 
         if isinstance(self.param, Parameter):
             self.nameTextBox.setText(self.param.description)
@@ -103,11 +106,11 @@ class ModelerParameterDefinitionDialog(QDialog):
             self.state.setChecked(False)
             if self.param is not None:
                 self.state.setChecked(True if self.param.value else False)
-            self.horizontalLayout2.addWidget(self.state)
-            self.verticalLayout.addLayout(self.horizontalLayout2)
+            self.horizontalLayout3.addWidget(self.state)
+            self.verticalLayout.addLayout(self.horizontalLayout3)
         elif self.paramType == ModelerParameterDefinitionDialog.PARAMETER_TABLE_FIELD or \
                 isinstance(self.param, ParameterTableField):
-            self.horizontalLayout2.addWidget(QLabel(self.tr('Parent layer')))
+            self.horizontalLayout3.addWidget(QLabel(self.tr('Parent layer')))
             self.parentCombo = QComboBox()
             idx = 0
             for param in self.alg.inputs.values():
@@ -117,37 +120,10 @@ class ModelerParameterDefinitionDialog(QDialog):
                         if self.param.parent == param.param.name:
                             self.parentCombo.setCurrentIndex(idx)
                     idx += 1
-            self.horizontalLayout2.addWidget(self.parentCombo)
-            self.verticalLayout.addLayout(self.horizontalLayout2)
-        elif self.paramType == ModelerParameterDefinitionDialog.PARAMETER_RASTER or \
-                isinstance(self.param, ParameterRaster):
-            self.horizontalLayout2.addWidget(QLabel(self.tr('Required')))
-            self.yesNoCombo = QComboBox()
-            self.yesNoCombo.addItem(self.tr('Yes'))
-            self.yesNoCombo.addItem(self.tr('No'))
-            if self.param is not None:
-                self.yesNoCombo.setCurrentIndex(
-                    1 if self.param.optional else 0)
-            self.horizontalLayout2.addWidget(self.yesNoCombo)
-            self.verticalLayout.addLayout(self.horizontalLayout2)
-        elif self.paramType == ModelerParameterDefinitionDialog.PARAMETER_TABLE or \
-                isinstance(self.param, ParameterTable):
-            self.horizontalLayout2.addWidget(QLabel(self.tr('Required')))
-            self.yesNoCombo = QComboBox()
-            self.yesNoCombo.addItem(self.tr('Yes'))
-            self.yesNoCombo.addItem(self.tr('No'))
-            if self.param is not None:
-                self.yesNoCombo.setCurrentIndex(
-                    1 if self.param.optional else 0)
-            self.horizontalLayout2.addWidget(self.yesNoCombo)
-            self.verticalLayout.addLayout(self.horizontalLayout2)
+            self.horizontalLayout3.addWidget(self.parentCombo)
+            self.verticalLayout.addLayout(self.horizontalLayout3)
         elif self.paramType == ModelerParameterDefinitionDialog.PARAMETER_VECTOR or \
                 isinstance(self.param, ParameterVector):
-            self.horizontalLayout2.addWidget(QLabel(self.tr('Required')))
-            self.yesNoCombo = QComboBox()
-            self.yesNoCombo.addItem(self.tr('Yes'))
-            self.yesNoCombo.addItem(self.tr('No'))
-            self.horizontalLayout2.addWidget(self.yesNoCombo)
             self.horizontalLayout3.addWidget(QLabel(self.tr('Shape type')))
             self.shapetypeCombo = QComboBox()
             self.shapetypeCombo.addItem(self.tr('Any'))
@@ -155,19 +131,11 @@ class ModelerParameterDefinitionDialog(QDialog):
             self.shapetypeCombo.addItem(self.tr('Line'))
             self.shapetypeCombo.addItem(self.tr('Polygon'))
             if self.param is not None:
-                self.yesNoCombo.setCurrentIndex(
-                    1 if self.param.optional else 0)
                 self.shapetypeCombo.setCurrentIndex(self.param.shapetype[0] + 1)
             self.horizontalLayout3.addWidget(self.shapetypeCombo)
             self.verticalLayout.addLayout(self.horizontalLayout3)
-            self.verticalLayout.addLayout(self.horizontalLayout2)
         elif self.paramType == ModelerParameterDefinitionDialog.PARAMETER_MULTIPLE or \
                 isinstance(self.param, ParameterMultipleInput):
-            self.horizontalLayout2.addWidget(QLabel(self.tr('Mandatory')))
-            self.yesNoCombo = QComboBox()
-            self.yesNoCombo.addItem(self.tr('Yes'))
-            self.yesNoCombo.addItem(self.tr('No'))
-            self.horizontalLayout2.addWidget(self.yesNoCombo)
             self.horizontalLayout3.addWidget(QLabel(self.tr('Data type')))
             self.datatypeCombo = QComboBox()
             self.datatypeCombo.addItem(self.tr('Vector (any)'))
@@ -177,24 +145,21 @@ class ModelerParameterDefinitionDialog(QDialog):
             self.datatypeCombo.addItem(self.tr('Raster'))
             self.datatypeCombo.addItem(self.tr('Table'))
             if self.param is not None:
-                self.yesNoCombo.setCurrentIndex(
-                    1 if self.param.optional else 0)
                 self.datatypeCombo.setCurrentIndex(self.param.datatype + 1)
             self.horizontalLayout3.addWidget(self.datatypeCombo)
             self.verticalLayout.addLayout(self.horizontalLayout3)
-            self.verticalLayout.addLayout(self.horizontalLayout2)
         elif self.paramType == ModelerParameterDefinitionDialog.PARAMETER_NUMBER or \
                 isinstance(self.param, ParameterNumber):
-            self.horizontalLayout2.addWidget(QLabel(self.tr('Min/Max values')))
+            self.horizontalLayout3.addWidget(QLabel(self.tr('Min/Max values')))
             self.minTextBox = QLineEdit()
             self.maxTextBox = QLineEdit()
             if self.param is not None:
                 self.minTextBox.setText(unicode(self.param.min))
                 self.maxTextBox.setText(unicode(self.param.max))
-            self.horizontalLayout2.addWidget(self.minTextBox)
-            self.horizontalLayout2.addWidget(self.maxTextBox)
-            self.verticalLayout.addLayout(self.horizontalLayout2)
-            self.horizontalLayout3.addWidget(QLabel(self.tr('Default value')))
+            self.horizontalLayout3.addWidget(self.minTextBox)
+            self.horizontalLayout3.addWidget(self.maxTextBox)
+            self.verticalLayout.addLayout(self.horizontalLayout3)
+            self.horizontalLayout4.addWidget(QLabel(self.tr('Default value')))
             self.defaultTextBox = QLineEdit()
             self.defaultTextBox.setText(self.tr('0'))
             if self.param is not None:
@@ -202,27 +167,37 @@ class ModelerParameterDefinitionDialog(QDialog):
                 if self.param.isInteger:
                     default = int(math.floor(default))
                 self.defaultTextBox.setText(unicode(default))
-            self.horizontalLayout3.addWidget(self.defaultTextBox)
-            self.verticalLayout.addLayout(self.horizontalLayout3)
+            self.horizontalLayout4.addWidget(self.defaultTextBox)
+            self.verticalLayout.addLayout(self.horizontalLayout4)
         elif self.paramType == ModelerParameterDefinitionDialog.PARAMETER_STRING or \
                 isinstance(self.param, ParameterString):
-            self.horizontalLayout2.addWidget(QLabel(self.tr('Default value')))
+            self.horizontalLayout3.addWidget(QLabel(self.tr('Default value')))
             self.defaultTextBox = QLineEdit()
             if self.param is not None:
                 self.defaultTextBox.setText(self.param.default)
-            self.horizontalLayout2.addWidget(self.defaultTextBox)
-            self.verticalLayout.addLayout(self.horizontalLayout2)
+            self.horizontalLayout3.addWidget(self.defaultTextBox)
+            self.verticalLayout.addLayout(self.horizontalLayout3)
         elif self.paramType == ModelerParameterDefinitionDialog.PARAMETER_FILE or \
                 isinstance(self.param, ParameterFile):
-            self.horizontalLayout2.addWidget(QLabel(self.tr('Type')))
+            self.horizontalLayout3.addWidget(QLabel(self.tr('Type')))
             self.fileFolderCombo = QComboBox()
             self.fileFolderCombo.addItem(self.tr('File'))
             self.fileFolderCombo.addItem(self.tr('Folder'))
             if self.param is not None:
                 self.fileFolderCombo.setCurrentIndex(
                     1 if self.param.isFolder else 0)
-            self.horizontalLayout2.addWidget(self.fileFolderCombo)
-            self.verticalLayout.addLayout(self.horizontalLayout2)
+            self.horizontalLayout3.addWidget(self.fileFolderCombo)
+            self.verticalLayout.addLayout(self.horizontalLayout3)
+
+        self.horizontalLayout2.addWidget(QLabel(self.tr('Required')))
+        self.yesNoCombo = QComboBox()
+        self.yesNoCombo.addItem(self.tr('Yes'))
+        self.yesNoCombo.addItem(self.tr('No'))
+        self.horizontalLayout2.addWidget(self.yesNoCombo)
+        if self.param is not None:
+            self.yesNoCombo.setCurrentIndex(
+                1 if self.param.optional else 0)
+        self.verticalLayout.addLayout(self.horizontalLayout2)
 
         self.buttonBox = QDialogButtonBox(self)
         self.buttonBox.setOrientation(Qt.Horizontal)
@@ -246,8 +221,10 @@ class ModelerParameterDefinitionDialog(QDialog):
             validChars = \
                 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789'
             safeName = ''.join(c for c in description if c in validChars)
-            name = self.paramType.upper().replace(' ', '') + '_' \
-                + safeName.upper()
+            name = safeName.lower()
+            i = 2
+            while name in self.alg.inputs:
+                name = safeName.lower() + str(i)
         else:
             name = self.param.name
         if self.paramType \
@@ -315,6 +292,7 @@ class ModelerParameterDefinitionDialog(QDialog):
                 isinstance(self.param, ParameterFile):
             isFolder = self.fileFolderCombo.currentIndex() == 1
             self.param = ParameterFile(name, description, isFolder=isFolder)
+        self.param.optional = self.yesNoCombo.currentIndex() == 1
         self.close()
 
     def cancelPressed(self):
