@@ -91,8 +91,10 @@ class QgsPluginInstaller(QObject):
                 updateAvailablePlugins()
                 settings = QSettings()
                 if settings.value("/PythonPlugins/" + key, False, type=bool):
+                    settings.setValue("/PythonPlugins/watchDog/" + key, True)
                     loadPlugin(key)
                     startPlugin(key)
+                    settings.remove("/PythonPlugins/watchDog/" + key)
 
     # ----------------------------------------- #
     def fetchAvailablePlugins(self, reloadMode):
@@ -427,6 +429,7 @@ class QgsPluginInstaller(QObject):
             reposName = reposName + "(2)"
         # add to settings
         settings.setValue(reposName + "/url", reposURL)
+        settings.setValue(reposName + "/authcfg", dlg.editAuthCfg.text().strip())
         settings.setValue(reposName + "/enabled", bool(dlg.checkBoxEnabled.checkState()))
         # refresh lists and populate widgets
         plugins.removeRepository(reposName)
@@ -442,6 +445,7 @@ class QgsPluginInstaller(QObject):
         dlg = QgsPluginInstallerRepositoryDialog(iface.mainWindow())
         dlg.editName.setText(reposName)
         dlg.editURL.setText(repositories.all()[reposName]["url"])
+        dlg.editAuthCfg.setText(repositories.all()[reposName]["authcfg"])
         dlg.editParams.setText(repositories.urlParams())
         dlg.checkBoxEnabled.setCheckState(checkState[repositories.all()[reposName]["enabled"]])
         if repositories.all()[reposName]["valid"]:
@@ -465,7 +469,10 @@ class QgsPluginInstaller(QObject):
         if newName in repositories.all() and newName != reposName:
             newName = newName + "(2)"
         settings.setValue(newName + "/url", dlg.editURL.text().strip())
+        settings.setValue(newName + "/authcfg", dlg.editAuthCfg.text().strip())
         settings.setValue(newName + "/enabled", bool(dlg.checkBoxEnabled.checkState()))
+        if dlg.editAuthCfg.text().strip() != repositories.all()[reposName]["authcfg"]:
+            repositories.all()[reposName]["authcfg"] = dlg.editAuthCfg.text().strip()
         if dlg.editURL.text().strip() == repositories.all()[reposName]["url"] and dlg.checkBoxEnabled.checkState() == checkState[repositories.all()[reposName]["enabled"]]:
             repositories.rename(reposName, newName)
             self.exportRepositoriesToManager()
